@@ -1,8 +1,11 @@
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 1/12/2015	ELL
 // This file is intended for web developers to create their own custom code.  It will never be included in updates after this date
 // and is thus upgrade safe.
 
+function OnShowPasswordReset()
+{
+}
\ No newline at end of file
