@@ -19,14 +19,25 @@
 // Added table prefix handling.
 // Revised: 2/13/2013	ELL
 // Added handling of new class/ID dropdown as class_prefix.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
+// Modified: 11/14/2017	ELL
+// Added checking between class prefix and class to avoid redundancy and inconsistency.
 // 
 // 
 	include ("check_session.php");
 
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 
-	$class = $_POST['class_prefix'] . trim($_POST['class']);
+	$class = trim($_POST['class']);
+	$class_prefix = $_POST['class_prefix'];
+	
+	if (isset($class_prefix) && ($class_prefix != "") && (substr($class, 0, 1) != "#") && (substr($class, 0, 1) != "."))
+		$class = $class_prefix . $class;
+	elseif (isset($class_prefix) && ($class_prefix != "") && ((substr($class, 0, 1) == "#") || (substr($class, 0, 1) == ".")))
+		$class = $class_prefix . substr($class, 1);
+		
 	$search = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$replace = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
 	$class_str = str_replace($search, $replace, $class);
@@ -35,7 +46,7 @@
 	$sort_order = $_POST['sort_order'];
 	
 	//First check to see if user exists.
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class` = '$class'";
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' AND `class` = '$class'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$tmp_class = $row["class"];
@@ -47,7 +58,7 @@
 	
 	
 	// Add class to database.
-	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . $class_table . "` SET `class` = '$class', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
+	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
 	$cnt = $bwb_dbh->exec($query);
 	
 	echo 1;
