@@ -20,8 +20,7 @@
 	else
 		$head_name = "head_" . $suffix;
 	
-	$today = date("Y-m-d H:i:s");
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name = '" . $head_name . "', head_content='<!-- Page Content Divider -->', revised='$today'";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name = '" . $head_name . "', head_content='<!-- Page Content Divider -->'";
 	$cnt = $bwb_dbh->exec($query);
 	
 	if ($assign_head == 1)	{
