@@ -27,6 +27,26 @@
 // Implemented new plugin field custom_css_sql.
 // Revised: 6/19/2017	ELL
 // Moved 'deployed' field to new table plugins_deployed.
+// Revised: 9/27/2018	ELL
+// Added addition of touchscreen styles to style sheet list.
+// Fixed bug with mobile style sheet description not getting updated to say "Mobile".
+// Revised: 3/29/2019	ELL
+// Added ability to set $show_custom_styles = 1 even if there is no custom SQL in the plugin by looking for 1@@@@ in $custom_css_sql.
+// Added ability to set $show_custom_styles = 0 even if there is custom SQL in the plugin by looking for 0@@@@ in $custom_css_sql.
+// Revised: 4/29/2019	ELL
+// Converted referenceing of deployed plugins from using 'plugin_id' to 'name'. This is because the SQL REPLACE command used to update aftermarket plugin records 
+// causes the id field to increment in the 'plugins' table only, making it out-of-sync with the 'plugins_deployed' table.
+// Revised:	10/2/2019	ELL
+// Changed "parent" from using parent plugin name to using parent plugin ID.
+// Added checking for parent plugin deployed if any child plugin has been selected.  If the parent plugin has NOT been deployed, then run any CSS SOL it has, 
+// any plugin SQL it has, and marked it as deployed.
+// Modified: 1/30/2020	ELL
+// Added handling of plugin field 'cookie_session_code'.
+// Modified: 7/7/2020	ELL
+// Added ability to detect and treat custom (advanced) plugin CSS as either CSS or SQL.  This was added to allow web developers to paste CSS directly into
+// Plugin SDK plugin record tool directly without forming into SQL statement.
+// Revised: 11/10/2020	ELL
+// Added handling of new plugin fields "version" and "css_important_sql".
 // 
 
 include ("check_session.php");
@@ -67,7 +87,29 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-
+function CheckForSQL($sql_string)
+{
+	$line_arr = array();
+	// Split SQL input into lines.
+	$line_arr = preg_split("[\n|\r]", $sql_string);
+	
+	// Search for INSERT or REPLACE commands.
+	for ($i = 0; $i < count($line_arr); $i++)
+	{
+		// Test for comment line.
+		$curr_line = trim($line_arr[$i]);
+		$first_chars = substr($curr_line, 0, 2);
+		if (($first_chars == "--") || ($first_chars == "//") || ($first_chars == "/*") || ($first_chars == ""))
+			continue;
+		elseif ((substr($curr_line, 0, 6) == "INSERT") || (substr($curr_line, 0, 7) == "REPLACE"))
+			return true;
+		else
+			return false;
+	}
+}
+		
+////////////////////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////////////////////
 	if (($page_name == "-not selected-") || ($plugin == "-not selected-") || ($page_name == "") || ($plugin == ""))
 	{
 		echo ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " .  ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG;
@@ -79,6 +121,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$plugin_id = $row["id"];
 	$plugin_name = $row["name"];
+	$plugin_version = $row["version"];
+	$parent = $row["parent"];
+	$cookie_session_code = $row["cookie_session_code"];
 	$head_code = $row["head_code"];
 	$head_html = $row["head_html"];
 	$header_code = $row["header_code"];
@@ -100,6 +145,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	$class_sql = $row["class_sql"];
 	$css_sql = $row["css_sql"];
 	$custom_css_sql = $row["custom_css_sql"];
+	$css_important_sql = $row["css_important_sql"];
 	$plugin_sql = $row["plugin_sql"];
 	$body_onload = $row["body_onload"];
 	if (isset($row["body_onload_function"]) && ($row["body_onload_function"] != ""))	{
@@ -116,7 +162,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	else
 		$body_onload_function = $page_name . "_load();";
 		
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE `plugin_id` = $plugin";
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE (`plugin_id` = $plugin) OR (`name` = '$plugin_name')";
 	$result = $bwb_dbh->query($query);
 	if ($result->rowCount() > 0)	{
 		$row = $result->fetch(PDO::FETCH_ASSOC);
@@ -124,9 +170,33 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	}
 	else
 		$deployed = 0;
+		
+	$parent_deployed = -1;
+	if (isset($parent) && ($parent!= "") && ($parent != $plugin_name))	{
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE (`plugin_id` = '$parent')";
+		$result = $bwb_dbh->query($query);
+		if ($result->rowCount() > 0)	{
+			$row = $result->fetch(PDO::FETCH_ASSOC);
+			$parent_deployed = $row["deployed"];
+		}
+		else
+			$parent_deployed = 0;
+
+		if ($parent_deployed == 0)	{
+			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `id` = $parent";
+			$result = $bwb_dbh->query($query);
+			$row = $result->fetch(PDO::FETCH_ASSOC);
+			$parent_name = $row["name"];
+			$parent_style_sheet = $row["style_sheet"];
+			$parent_style_sheet_description = $row["style_sheet_description"];
+			$parent_class_sql = $row["class_sql"];
+			$parent_css_sql = $row["css_sql"];
+			$parent_custom_css_sql = $row["custom_css_sql"];
+			$parent_plugin_sql = $row["plugin_sql"];
+		}
+	}
 	
 	//Get page content from database.
-	$today = date("Y-m-d H:i:s");
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
@@ -148,11 +218,10 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		$plugin_ids = $plugin_id;
 	
 	//Update page content in database.
-	$today = date("Y-m-d H:i:s");
 	if ($body_onload == 1)
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', revised='$today', plugins='$plugin_ids', body_onload=1, body_onload_function='$body_onload_function' WHERE page_name='$page_name'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', plugins='$plugin_ids', body_onload=1, body_onload_function='$body_onload_function' WHERE page_name='$page_name'";
 	else
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', revised='$today', plugins='$plugin_ids' WHERE page_name='$page_name'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', plugins='$plugin_ids' WHERE page_name='$page_name'";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 
@@ -160,9 +229,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$page_name'";
 	$result = $bwb_dbh->query($query);
 	if ($result->rowCount() < 1)
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$page_content', revised='$today', `source`=0";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$page_content', `source`=0";
 	else
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$page_content', revised='$today', `source`=0 WHERE page_name='$page_name'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$page_content', `source`=0 WHERE page_name='$page_name'";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -189,6 +258,14 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			exit;
 		}
 	}
+	
+	//If plugin is selected, then insert cookie/session code snippet after //cookie_session_code// comment.
+	if (($plugin != "-not selected-") && ($cookie_session_code != ""))
+	{
+		$page_temp_arr = explode("//cookie_session_code//", $page_template, 2);
+		$page_template = $page_temp_arr[0] . $cookie_session_code . "\n\n//cookie_session_code//\n" . $page_temp_arr[1];
+		unset($page_temp_arr);
+	}
 		
 	//If plugin is selected, then insert head code snippet after <!--head_code--> comment.
 	if (($plugin != "-not selected-") && ($head_code != ""))
@@ -370,9 +447,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new head into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', head_name = '" . $head_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', plugins = '" . $plugin_ids . "', head_name = '" . $head_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE head_name = '" . $head_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', plugins = '" . $plugin_ids . "' WHERE head_name = '" . $head_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -405,9 +482,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new header into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $header_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $header_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $header_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $header_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -440,9 +517,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new footer into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $footer_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $footer_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $footer_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $footer_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -475,9 +552,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new top into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $top_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $top_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $top_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $top_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -510,9 +587,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new top into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $left_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $left_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $left_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $left_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -545,9 +622,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new top into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $right_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $right_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $right_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $right_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -580,9 +657,9 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		// Insert new top into table.
 		if ($new === true)
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $bottom_name . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', plugins = '" . $plugin_ids . "', page_name = '" . $bottom_name . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $bottom_name . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $bottom_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -597,38 +674,72 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() < 1)
 			{
+				$css_already_in_use = false;
 				$query = "SELECT MAX(sort_order) AS sort_order FROM " . BWB_TABLE_PREFIX . "style_sheets";
 				$result = $bwb_dbh->query($query);
 				$row = $result->fetch(PDO::FETCH_ASSOC);
 				$sort_order = $row['sort_order'] + 10;
 				
-				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				if ((isset($custom_css_sql) && ($custom_css_sql != "") && (strpos($custom_css_sql, "0@@@@@") === false)) || (strpos($custom_css_sql, "1@@@@@") == 0))
 				 	$show_custom_styles = 1;
-				else
-					$show_custom_styles = 0;
+				elseif (!isset($custom_css_sql) || ($custom_css_sql == "") || (strpos($custom_css_sql, "0@@@@@") == 0))
+				 	$show_custom_styles = 0;
+				if (isset($custom_css_sql) && (strpos($custom_css_sql, "@@@@@") == 1))	{
+					$custom_css_sql = str_replace("0@@@@@", "", $custom_css_sql);
+					$custom_css_sql = str_replace("1@@@@@", "", $custom_css_sql);
+				}
 				
 				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
 				
 				$sort_order = $sort_order + 10;
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_mobile', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$style_sheet_desc_arr = explode("Styles", $style_sheet_description);
+				if (count($style_sheet_desc_arr) > 1)	{
+					$mobile_style_sheet_desc = $style_sheet_desc_arr[0] . "Mobile Styles" . $style_sheet_desc_arr[1];
+					$touchscreen_style_sheet_desc = $style_sheet_desc_arr[0] . "Touchscreen Styles" . $style_sheet_desc_arr[1];
+				}
+				else	{
+					$mobile_style_sheet_desc = $style_sheet_description . " Mobile Styles";
+					$touchscreen_style_sheet_desc = $style_sheet_description . " Touchscreen Styles";
+				}
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_mobile', `description`='" . $mobile_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_touchscreen', `description`='" . $touchscreen_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
 			}
+			else
+				$css_already_in_use = true;
 		}
 		
 		if (isset($class_sql) && ($class_sql != ""))
 		{
-			$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+			$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
-		if (isset($css_sql) && ($css_sql != ""))
+		if (isset($css_sql) && ($css_sql != "") && !$css_already_in_use)
 		{
-			$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+			$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+		}
+		
+		if (isset($css_important_sql) && ($css_important_sql != "") && !$css_already_in_use)
+		{
+			$result = RunSQL($css_important_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 				
-		if (isset($custom_css_sql) && ($custom_css_sql != ""))
+		if (isset($custom_css_sql) && ($custom_css_sql != "") && !$css_already_in_use)
 		{
-			$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+			if (!CheckForSQL($custom_css_sql))	{
+				$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+				$result = $bwb_dbh->exec($sql);
+				$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "_mobile', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+				$result = $bwb_dbh->exec($sql);
+				$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "_touchscreen', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+				$result = $bwb_dbh->exec($sql);
+			}
+			else
+				$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
 		if ((isset($css_sql) && ($css_sql != "")) || (isset($custom_css_sql) && ($custom_css_sql != "")))
@@ -684,10 +795,172 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		
 		if (isset($plugin_sql) && ($plugin_sql != ""))
 		{
-			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
-		$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
+		if (isset($plugin_name) && ($plugin_name != ""))
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `name`='$plugin_name', `deployed`=1";
+		else
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
+		$cnt = $bwb_dbh->exec($query);
+	}
+	
+	// Create parent plugin tables if plugin selected and table not existing.
+	if (($plugin != "-not selected-") && ($parent_deployed < 1))
+	{
+		if (isset($parent_style_sheet) && ($parent_style_sheet != ""))
+		{
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name`='" . $parent_style_sheet . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() < 1)
+			{
+				$css_already_in_use = false;
+				$query = "SELECT MAX(sort_order) AS sort_order FROM " . BWB_TABLE_PREFIX . "style_sheets";
+				$result = $bwb_dbh->query($query);
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$sort_order = $row['sort_order'] + 10;
+				
+				if ((isset($parent_custom_css_sql) && ($parent_custom_css_sql != "") && (strpos($parent_custom_css_sql, "0@@@@@") === false)) || (strpos($parent_custom_css_sql, "1@@@@@") == 0))
+				 	$show_custom_styles = 1;
+				elseif (!isset($parent_custom_css_sql) || ($parent_custom_css_sql == "") || (strpos($parent_custom_css_sql, "0@@@@@") == 0))
+				 	$show_custom_styles = 0;
+				if (isset($parent_custom_css_sql) && (strpos($parent_custom_css_sql, "@@@@@") == 1))	{
+					$parent_custom_css_sql = str_replace("0@@@@@", "", $parent_custom_css_sql);
+					$parent_custom_css_sql = str_replace("1@@@@@", "", $parent_custom_css_sql);
+				}
+				
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "', `description`='" . $parent_style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$style_sheet_desc_arr = explode("Styles", $parent_style_sheet_description);
+				if (count($style_sheet_desc_arr) > 1)	{
+					$mobile_style_sheet_desc = $style_sheet_desc_arr[0] . "Mobile Styles" . $style_sheet_desc_arr[1];
+					$touchscreen_style_sheet_desc = $style_sheet_desc_arr[0] . "Touchscreen Styles" . $style_sheet_desc_arr[1];
+				}
+				else	{
+					$mobile_style_sheet_desc = $parent_style_sheet_description . " Mobile Styles";
+					$touchscreen_style_sheet_desc = $parent_style_sheet_description . " Touchscreen Styles";
+				}
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "_mobile', `description`='" . $mobile_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "_touchscreen', `description`='" . $touchscreen_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+			}
+			else
+				$css_already_in_use = true;
+			
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T1.style_sheet = '" . $parent_style_sheet . "' AND T2.deployed = 1";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() < 1)
+			{
+				if (isset($parent_class_sql) && ($parent_class_sql != ""))
+				{
+					$result = RunSQL($parent_class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if (isset($parent_css_sql) && ($parent_css_sql != "") && !$css_already_in_use)
+				{
+					$result = RunSQL($parent_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if (isset($parent_custom_css_sql) && ($parent_custom_css_sql != "") && !$css_already_in_use)
+				{
+					if (!CheckForSQL($parent_custom_css_sql))	{
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "_mobile', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "_touchscreen', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+					}
+					else
+						$result = RunSQL($parent_custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if ((isset($parent_css_sql) && ($parent_css_sql != "")) || (isset($parent_custom_css_sql) && ($parent_custom_css_sql != "")))
+				{	
+					$css_string = BuildCSSString($parent_style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					////////////////////////////////////////////////////////
+					/// Write menu items to menu.css file /////////////
+					//Test to see if file already exists.
+					if (BWB_BASE_DIR == '')
+						$userfiles = '';
+					else
+						$userfiles = "/" . BWB_BASE_DIR;
+						
+					$css_file = $parent_style_sheet . ".css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build mobile style sheet
+					$css_string = BuildCSSString($parent_style_sheet . "_mobile", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $parent_style_sheet . "_mobile.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build touchscreen only style sheet
+					$css_string = BuildCSSString($parent_style_sheet . "_touchscreen", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $parent_style_sheet . "_touchscreen.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+				}
+			}
+		}
+		if (isset($parent_plugin_sql) && ($parent_plugin_sql != ""))
+		{
+			$result = RunSQL($parent_plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+		}
+	
+		if (isset($parrent_name) && ($parrent_name != ""))
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$parent, `name`='$parrent_name', `deployed`=1";
+		else
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$parent, `deployed`=1";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -792,10 +1065,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	
 	//Go to edit page.
 	$domain = $_SERVER['HTTP_HOST'];
-	if (BWB_REQUIRE_SSL == 1)
-		$web_path = "https://" . $domain;
-	else
-		$web_path = "http://" . $domain;
+	$web_path = $http . $domain;
 	$php_self = $_SERVER['PHP_SELF'];
 	$this_file = substr(strrchr($php_self, "/"), 1);
 	$app_dir = substr($php_self, 0, (strlen($php_self)- strlen($this_file)));
