@@ -17,7 +17,6 @@
 	
 	$border_area = $_REQUEST['border_area'];
 	$menu_name = $_REQUEST['menu_name'];
-	$menu_type = $_REQUEST['menu_type'];
 	
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
 	$result = $bwb_dbh->query($query);
@@ -37,18 +36,6 @@
 			$query2 = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
 		$cnt = $bwb_dbh->exec($query2);
 	}
-	///////////////////////////////////////////////////////////////////////////////////
-	if ($menu_type == 1)
-	{
-		if ($menu_name != "-not assigned-")
-		{
-			$suffix = substr($menu_name, 4);
-			include("add_menu_code.php");
-		}
-		else
-			include("remove_menu_code.php");
-	}
-	///////////////////////////////////////////////////////////////////////////////////
-	
-	header("Location: manage_menu.php?menu_name=$menu_name&border_area=$border_area&menu_type=$menu_type");
+
+	header("Location: manage_menu.php?menu_name=$menu_name&border_area=$border_area");
 ?>
\ No newline at end of file
