@@ -42,6 +42,8 @@
 	position:inherit;
 }
 #select_backup_to_upload_btn	{	width:500px;	}
+
+#backup_restore_heading	{	margin-left: 10%;	}
 </style>
 
 <script src="js/hash.js"> </script>
@@ -63,6 +65,8 @@
 	echo "	var BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG . "\";\n";
 	echo "	var BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG . "\";\n";
 	echo "	var BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR = \"" . BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -141,9 +145,7 @@
 		{
 ?>
 
-<table width="80%" align="center" border="0"><tr><td>
-<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
+<div class="button_heading_sub_level_1" id="backup_restore_heading"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
 
 <center>
 <div class='button_console' id="backup_btn" onClick="window.location='backup_site.php?password=<?php echo $password; ?>';"><span class='button_console_text'><?php echo BACKUP_WORD; ?></span></div>
