@@ -12,6 +12,7 @@
 // Added insertion of salt into password before encrypting.
 //
 	include ("check_session.php");
+	include ("encrypt_decrypt.php");
 
 	$user_name = $_POST['user_name'];
 	$password = $_POST['password'];
@@ -48,54 +49,4 @@
 	$_SESSION['last_user'] = $user_name;
 	
 	echo "user_name=$user_name@@@@@password=$password";
-	
-	exit;
-/////////////////////////////////
-function doEncrypt($Data, $Key)
-{
-// encrypting  a[] with key k[] into e[]
-// a[] = array to be encrypted
-// k[] = key of truly random gibberish
-// e[] = encrypted data
-
-	for( $i = 0; $i < strlen($Data); $i++)
-	{
-		$c = substr($Data, $i, 1);
-		$a[$i] = ord($c);
-	}
-	
-	for( $i = 0; $i < strlen($Data); $i++)
-	{
-		if ($i < strlen($Key))
-		{
-			$c = substr($Key, $i, 1);
-			$k[$i] = ord($c);
-		}
-		else
-			$k[$i] = 65 + $i;
-	}
-	
-	for ( $i=0; $i < strlen($Data); $i++ )
-   	{
-   		$e[$i] = $k[$i] ^ $a[$i];
-   	}
-	
-	$encrypted = "";
-	for ( $i = 0; $i < strlen($Data); $i++ )
-	{
-		$encrypted = $encrypted. decToHex($e[$i]);
-	}
-	return($encrypted);
-	
-}
-
-function decToHex($dec)
-{
-	$hexStr = "0123456789ABCDEF";
-	$low = $dec % 16;
-	$high = ($dec - $low)/16;
-	$hex = "";
-	$hex = substr($hexStr, $high, 1) . substr($hexStr, $low, 1);
-	return $hex;
-}
 ?>
