@@ -12,20 +12,44 @@
 // Security enhancements for PDO.
 // Revised: 7/31/2014	ELL
 // Added checking and setting of session path in case not set by default.
+// Revised: 7/5/2019	ELL
+// Added ability to switch between different sites in one Breeze installation utilizing cofig_sites.php file and user selection on login.
 //
 	error_reporting (E_ALL ^ E_NOTICE);
 	
-	include ("../connect/config.php");
+	$connect_dir = "connect";
+	if (file_exists("../connect/config_sites.php"))	{
+		include ("../connect/config_sites.php");
+		if (BWB_ACTIVE_SITE != 1)
+			$connect_dir .= BWB_ACTIVE_SITE;
+	}
+	else
+		define('BWB_ACTIVE_SITE', 1);
 	
 	$sess_save_path = session_save_path();
-	if (!isset($sess_save_path) || ($sess_save_path == ""))
-		session_save_path(SESSION_SAVE_PATH);
+	if (!isset($sess_save_path) || ($sess_save_path == ""))	{
+		if (defined('SESSION_SAVE_PATH'))
+			session_save_path(SESSION_SAVE_PATH);
+		else
+			session_save_path('/tmp');
+	}
 	
 	session_start();
 	$userid = $_SESSION['userid'];
 	$curr_session = md5(session_id());
 	
-	include ("../connect/db_connect.php");
+	if (isset($_SESSION['site_under_edit']) && ($_SESSION['site_under_edit'] != BWB_ACTIVE_SITE))	{
+		$site_under_edit = $_SESSION['site_under_edit'];
+		if ($site_under_edit == 1)
+			$connect_dir = "connect";
+		else
+			$connect_dir = "connect" . $site_under_edit;
+	}
+	else
+		$site_under_edit = BWB_ACTIVE_SITE;
+
+	include ("../$connect_dir/config.php");
+	include ("../$connect_dir/db_connect.php");
 	
 	$query = "SELECT `Session`, `IP`, `AccessLevel`, `first_name`, `last_name` FROM `" . BWB_TABLE_PREFIX . "users` WHERE `UserID`=:userid";
 	$stmt = $bwb_dbh->prepare($query);
@@ -56,4 +80,11 @@
 	}
 	else
 		$theme = "classic";
+		
+	if (BWB_REQUIRE_SSL == 1)
+		$http = "https://";
+	elseif (isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] == 1) || isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')
+		$http = "https://";
+	else
+		$http = "http://";
 ?>
\ No newline at end of file
