@@ -150,6 +150,8 @@
 	echo "var CLASSES_DELETE_CLASS_COMPLETE_MSG = \"" . CLASSES_DELETE_CLASS_COMPLETE_MSG . "\";\n";
 	echo "var CLASSES_NO_CUSTOM_CLASSES_DEFINED = \"" . CLASSES_NO_CUSTOM_CLASSES_DEFINED . "\";\n";
 	echo "var CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG = \"" . CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 
 var style_sheet = '<?php echo $style_sheet; ?>';
@@ -211,6 +213,21 @@ var style_sheet = '<?php echo $style_sheet; ?>';
     </select>
     </form>
 </td>
+<td>
+<?php
+	$style_sheet_type = "Desktop";
+	$style_sheet_type_class = "type_desktop";
+	if (strpos($style_sheet, "touchscreen"))	{
+		$style_sheet_type = "Touchscreen";
+		$style_sheet_type_class = "type_touchscreen";
+	}
+	elseif (strpos($style_sheet, "mobile"))	{
+		$style_sheet_type = "Mobile";
+		$style_sheet_type_class = "type_mobile";
+	}
+  	echo "<span class='" . $style_sheet_type_class . "'>" . TYPE_WORD . ": " . $style_sheet_type . "</span>";
+?>
+</td>
 <td align="right">
   <div class='button_console_go_back' style="width:210px;" onClick="window.location.href='edit_css.php?style_sheet=<?php echo $style_sheet; ?>'"><span class='button_console_text_w_icon'><?php echo CLASSES_BACK_TO_EDIT_CSS; ?></span></div>
 </td></tr></table>
