@@ -9,7 +9,22 @@ $kfm_db_port     = '';
 $use_kfm_security=false;
 //////////////////////// Special Beeze Website Builder Code for auto-config ////////////////////////////////////
 $doc_root = getenv('DOCUMENT_ROOT');
-$bwb_config_path = $doc_root . "/connect/config.php";
+$connect_dir = "connect";
+if (file_exists($doc_root . "/connect/config_sites.php"))	{
+	include ($doc_root . "/connect/config_sites.php");
+	if (BWB_ACTIVE_SITE != 1)
+		$connect_dir .= BWB_ACTIVE_SITE;
+}
+
+session_start();
+if (isset($_SESSION['site_under_edit']) && ($_SESSION['site_under_edit'] != BWB_ACTIVE_SITE))	{
+	if ($_SESSION['site_under_edit'] == 1)
+		$connect_dir = "connect";
+	else
+		$connect_dir = "connect" . $_SESSION['site_under_edit'];
+}
+		
+$bwb_config_path = $doc_root . "/" . $connect_dir . "/config.php";
 include($bwb_config_path);
 $kfm_userfiles_address = $doc_root . '/' . BWB_BASE_DIR;
 if (BWB_BASE_DIR == "")
