@@ -21,7 +21,7 @@
 		$to_style_sheet = $_POST['to_style_sheet'];
 	else
 		$to_style_sheet = $_POST['style_sheet'];
-	if (mode == "rename")
+	if ($mode == "rename")
 		$css_file = $style_sheet . ".css";
 	else
 		$css_file = $to_style_sheet . ".css";
@@ -75,7 +75,7 @@
 	$result = $bwb_dbh->query($query);
 	if ($result->rowCount() < 1)
 	{
-		echo "-no data-";
+		echo "-no attributes set-";
 		return;
 	}
 	if ($mode == "copy")
