@@ -164,7 +164,7 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
         <script language="javascript" type="text/ecmascript">
 		function OpenHelpWindow()
 		{
-			window.open("http://breezewebsitebuilder.com/docs/cms/help.html#copy_rename_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+			window.open("<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#copy_rename_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 		}
 		</script>
         </head>
@@ -260,12 +260,16 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 				$template = $row["option_value"];
 			}
 			
+			if ((isset($revised)) && ($revised != ""))
+				$revised_str = " `revised`='$revised',";
+			else
+				$revised_str = "";
 			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name`='$new_name'";
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() > 0)
-				$query = "UPDATE `" . BWB_TABLE_PREFIX . "page_data` SET `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer' WHERE `page_name`='$new_name'";
+				$query = "UPDATE `" . BWB_TABLE_PREFIX . "page_data` SET `page_content`='$page_content', `template`='$template',$revised_str `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer' WHERE `page_name`='$new_name'";
 			else
-				$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "page_data` SET `page_name`='$new_name', `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer'";
+				$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "page_data` SET `page_name`='$new_name', `page_content`='$page_content', `template`='$template',$revised_str `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer'";
 			$cnt = $bwb_dbh->exec($query);
 
 			// Clear any old junk in draft table.
