@@ -64,6 +64,10 @@
 <script src="js/mouse_position.js"></script>
 <script src="js/popup_msg.js"></script>
 <script src="js/copy_rename_page_select.js"></script>
+
+<script>
+<?php echo "\n	var http = '$http';\n"; ?>
+</script>
 </head>
 
 <body>
@@ -97,7 +101,8 @@
 			}
 		?>
 	  </select>
-		<?php echo TO_WORD; ?>	
+		<?php echo TO_WORD; ?>
+        <span style="display:inline; font-size:24px; cursor:pointer;" onClick="TransferPageName();">&raquo;</span>
 		<input type="text" name="new_name" id="new_name" onKeyUp="CheckPageName(this.value);" onSelect="CheckPageName(this.value);"<?php if (isset($new_name) && ($new_name != "")) echo "value='$new_name'"; ?> />
 	      <br>
           <label id="create_new_template_label">
