@@ -22,10 +22,10 @@
 	
 	$body_html = "\n<p>" . CREATE_PAGE_DEFAULT_CONTENT . "</p>\n";
 	$today = date("Y-m-d H:i:s");
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='" . $page_name . "', page_content='" . $body_html . "', revised='" . $today . "'";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='" . $page_name . "', page_content='" . $body_html . "'";
 	$cnt = $bwb_dbh->exec($query);
 	// Copy page data to draft table.
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='" . $page_name . "', page_content='" . $body_html . "', revised='" . $today . "', `source`=1";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='" . $page_name . "', page_content='" . $body_html . "', `source`=1";
 	$cnt = $cnt + $bwb_dbh->exec($query);
 	
 	$query = "UPDATE " . BWB_TABLE_PREFIX . "menu_items SET mega_menu = '" . $page_name . "' WHERE `menu`='" . $menu . "' AND item_text = '" . $menu_item . "'";
