@@ -70,6 +70,31 @@
 // Added hook to allow to be called without going to editor.  This facilitates creating child plugin pages when creating a group of pages out of a plugin group.
 // Revised: 6/19/2017	ELL
 // Moved 'deployed' field to new table plugins_deployed.
+// Revised: 9/27/2018	ELL
+// Added addition of touchscreen styles to style sheet list.
+// Revised: 3/29/2019	ELL
+// Added ability to set $show_custom_styles = 1 even if there is no custom SQL in the plugin by looking for 1@@@@ in $custom_css_sql.
+// Added ability to set $show_custom_styles = 0 even if there is custom SQL in the plugin by looking for 0@@@@ in $custom_css_sql.
+// Revised: 4/29/2019	ELL
+// Converted referenceing of deployed plugins from using 'plugin_id' to 'name'. This is because the SQL REPLACE command used to update aftermarket plugin records 
+// causes the id field to increment in the 'plugins' table only, making it out-of-sync with the 'plugins_deployed' table.
+// Revised: 7/13/2019	ELL
+// Added reading of option of how to handle file aready exists error from options and either dissallowing creation of page (default),
+// keeping existing file and continuing, or overwriting existing file and continuing.
+// Added creation of touchscreen only CSS files for plugins.
+// Revised:	10/2/2019	ELL
+// Changed "parent" from using parent plugin name to using parent plugin ID.
+// Added checking for parent plugin deployed if any child plugin has been selected.  If the parent plugin has NOT been deployed, then run any CSS SOL it has, 
+// any plugin SQL it has, and marked it as deployed.
+// Modified: 11/26/2019	ELL
+// Added creation of sitemap.xml and robots.txt file upon creating page.
+// Modified: 1/30/2020	ELL
+// Added handling of plugin field 'cookie_session_code'.
+// Modified: 7/7/2020	ELL
+// Added ability to detect and treat custom (advanced) plugin CSS as either CSS or SQL.  This was added to allow web developers to paste CSS directly into
+// Plugin SDK plugin record tool directly without forming into SQL statement.
+// Revised: 11/10/2020	ELL
+// Added handling of new plugin fields "version" and "css_important_sql".
 //
 
 include ("check_session.php");
@@ -113,6 +138,30 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	return 1;
 }
 
+////////////////////////////////////////////////////////////////////////////////////////////////
+function CheckForSQL($sql_string)
+{
+	$line_arr = array();
+	// Split SQL input into lines.
+	$line_arr = preg_split("[\n|\r]", $sql_string);
+	
+	// Search for INSERT or REPLACE commands.
+	for ($i = 0; $i < count($line_arr); $i++)
+	{
+		// Test for comment line.
+		$curr_line = trim($line_arr[$i]);
+		$first_chars = substr($curr_line, 0, 2);
+		if (($first_chars == "--") || ($first_chars == "//") || ($first_chars == "/*") || ($first_chars == ""))
+			continue;
+		elseif ((substr($curr_line, 0, 6) == "INSERT") || (substr($curr_line, 0, 7) == "REPLACE"))
+			return true;
+		else
+			return false;
+	}
+}
+		
+////////////////////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////////////////////
 	if ($page_name == "")
 	{
 		echo CREATE_PAGE_PAGE_NAME_BLANK_1_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_NAME_BLANK_2_ERR;
@@ -140,8 +189,14 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$UseTableStructureMobile = $row["option_value"];
+	// Check if OK to continue to cerate page if page template file already exists, an whether to keep existing or overwrite.
+	// Useful if creating new pages on second inactive site, but don't want to change folder of page files, .i.e. webroot.
+	$query = "SELECT `option_value` FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name`='CreatePageFileExistsHandling'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$CreatePageFileExistsHandling = $row["option_value"];
 	
-	//First check to see if file is alrready in database.
+	//First check to see if page is already in database.
 	$query = "SELECT `page_name` FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name`='$page_name'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
@@ -159,14 +214,21 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	else
 		$file_name = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/" . $page_name . ".php";
 //	echo "File Name: $file_name<br>";
+	$skip_file_create = false;
 	if (file_exists($file_name))
 	{
 		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == '') && ($page_name == "index"))	// Special case, getting rid of stock forwarder to /userfiles/file/
 			unlink($file_name);
 		else
 		{
-			echo $file_name . " " . MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR;
-			exit;
+			if ((strpos($CreatePageFileExistsHandling, "Keep") === false) && (strpos($CreatePageFileExistsHandling, "Overwrite") === false))	{
+				echo $file_name . " " . MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR;
+				exit;
+			}
+			elseif (strpos($CreatePageFileExistsHandling, "Overwrite") !== false)
+				unlink($file_name);
+			elseif (strpos($CreatePageFileExistsHandling, "Keep") !== false)
+				$skip_file_create = true;
 		}
 	}
 	
@@ -181,6 +243,10 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$plugin_id = $row["id"];
+		$plugin_name = $row["name"];
+		$plugin_version = $row["version"];
+		$parent = $row["parent"];
+		$cookie_session_code = $row["cookie_session_code"];
 		$head_code = $row["head_code"];
 		$head_html = $row["head_html"];
 		$header_code = $row["header_code"];
@@ -190,7 +256,10 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		$left_code = $row["left_code"];
 		$left_html = $row["left_html"];
 		$content_code = $row["content_code"];
-		$content_html = $page_content_divider . "\n" . $row["content_html"];
+		if (strpos($row["content_html"], $page_content_divider) === false)
+			$content_html = $page_content_divider . "\n" . $row["content_html"];
+		else
+			$content_html = $row["content_html"];
 		$right_code = $row["right_code"];
 		$right_html = $row["right_html"];
 		$bottom_code = $row["bottom_code"];
@@ -202,6 +271,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		$class_sql = $row["class_sql"];
 		$css_sql = $row["css_sql"];
 		$custom_css_sql = $row["custom_css_sql"];
+		$css_important_sql = $row["css_important_sql"];
 		$plugin_sql = $row["plugin_sql"];
 		$disable_site_styles = $row["disable_site_styles"];
 		$body_onload = $row["body_onload"];
@@ -219,9 +289,8 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		else
 			$body_onload_function = $page_name . "_load();";
 			
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE `plugin_id` = $plugin";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE (`plugin_id` = $plugin) OR (`name` = '$plugin_name')";
 		$result = $bwb_dbh->query($query);
-		$row = $result->fetch(PDO::FETCH_ASSOC);
 		if ($result->rowCount() > 0)	{
 			$row = $result->fetch(PDO::FETCH_ASSOC);
 			$deployed = $row["deployed"];
@@ -229,6 +298,31 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 		else
 			$deployed = 0;
 			
+		$parent_deployed = -1;
+		if (isset($parent) && ($parent!= "") && ($parent != $plugin_name))	{
+			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE (`plugin_id` = '$parent')";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)	{
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$parent_deployed = $row["deployed"];
+			}
+			else
+				$parent_deployed = 0;
+	
+			if ($parent_deployed == 0)	{
+				$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `id` = $parent";
+				$result = $bwb_dbh->query($query);
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$parent_name = $row["name"];
+				$parent_style_sheet = $row["style_sheet"];
+				$parent_style_sheet_description = $row["style_sheet_description"];
+				$parent_class_sql = $row["class_sql"];
+				$parent_css_sql = $row["css_sql"];
+				$parent_custom_css_sql = $row["custom_css_sql"];
+				$parent_plugin_sql = $row["plugin_sql"];
+			}
+		}
+		
 		// Check template compatibility with plugin.
 		if (strpos($template_name, "header_footer_top_bottom_left_right") === false)
 		{
@@ -328,15 +422,14 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	}
 	
 	//Add page name to database.
-	$today = date("Y-m-d H:i:s");
 	$page_content = addslashes(stripslashes($content_html));
 		
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$page_content', template='$template_name', revised='$today', plugins='$plugin_id', disable_site_styles='$disable_site_styles', body_onload='$body_onload', body_onload_function='$body_onload_function', use_table_structure='$UseTableStructure', use_table_structure_mobile='$UseTableStructureMobile'";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$page_content', template='$template_name', plugins='$plugin_id', disable_site_styles='$disable_site_styles', body_onload='$body_onload', body_onload_function='$body_onload_function', use_table_structure='$UseTableStructure', use_table_structure_mobile='$UseTableStructureMobile'";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 
 // Copy page data to draft table.
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$page_content', revised='$today', `source`=0";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$page_content', `source`=0";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 
@@ -370,6 +463,14 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	if ($zzz_found === true)
 		$page_template = str_replace("-ZZZ-", $page_name, $page_template);
 		
+	//If plugin is selected, then insert cookie/session code snippet after //cookie_session_code// comment.
+	if (($plugin != "-not selected-") && ($cookie_session_code != ""))
+	{
+		$page_temp_arr = explode("//cookie_session_code//", $page_template, 2);
+		$page_template = $page_temp_arr[0] . $cookie_session_code . "\n\n//cookie_session_code//\n" . $page_temp_arr[1];
+		unset($page_temp_arr);
+	}
+		
 	//If plugin is selected, then insert head code snippet after <!--head_code--> comment.
 	if (($plugin != "-not selected-") && ($head_code != ""))
 	{
@@ -516,7 +617,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$head_name .= time();
 		
 		// Insert new head into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head (head_name, head_content, `revised`, plugins) VALUES ('" . $head_name . "', '" . $head_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head (head_name, head_content, plugins) VALUES ('" . $head_name . "', '" . $head_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update head name in page record.
@@ -546,7 +647,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$header_name .= time();
 
 		// Insert new header into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $header_name . "', '" . $header_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $header_name . "', '" . $header_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update header name in page record.
@@ -576,7 +677,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$footer_name .= time();
 		
 		// Insert new footer into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $footer_name . "', '" . $footer_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $footer_name . "', '" . $footer_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update footer name in page record.
@@ -606,7 +707,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$top_name .= time();
 		
 		// Insert new top into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $top_name . "', '" . $top_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $top_name . "', '" . $top_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update top name in page record.
@@ -636,7 +737,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$left_name .= time();
 		
 		// Insert new top into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $left_name . "', '" . $left_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $left_name . "', '" . $left_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update left name in page record.
@@ -666,7 +767,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$right_name .= time();
 		
 		// Insert new top into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $right_name . "', '" . $right_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $right_name . "', '" . $right_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update right name in page record.
@@ -696,7 +797,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$bottom_name .= time();
 		
 		// Insert new top into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $bottom_name . "', '" . $bottom_content . "', '" . $today . "', '" . $plugin_id . "')";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, plugins) VALUES ('" . $bottom_name . "', '" . $bottom_content . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
 		// Update bottom name in page record.
@@ -705,10 +806,12 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	}
 			
 	// Create file.
-	$fh = fopen($file_name, 'xb') or die("Can't create $file_name: $php_errormsg");
-	$result = (fwrite($fh, $page_template));
-	fclose($fh) or die($php_errormsg);
-	@chmod($file_name, 0755);
+	if (!$skip_file_create)	{
+		$fh = fopen($file_name, 'xb') or die("Can't create $file_name: $php_errormsg");
+		$result = (fwrite($fh, $page_template));
+		fclose($fh) or die($php_errormsg);
+		@chmod($file_name, 0755);
+	}
 	
 	// Create plugin tables if plugin selected and table not existing.
 	if (($plugin != "-not selected-") && ($deployed != 1))
@@ -719,28 +822,43 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() < 1)
 			{
+				$css_already_in_use = false;
 				$query = "SELECT MAX(sort_order) AS sort_order FROM " . BWB_TABLE_PREFIX . "style_sheets";
 				$result = $bwb_dbh->query($query);
 				$row = $result->fetch(PDO::FETCH_ASSOC);
 				$sort_order = $row['sort_order'] + 10;
 				
-				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				if ((isset($custom_css_sql) && ($custom_css_sql != "") && (strpos($custom_css_sql, "0@@@@@") === false)) || (strpos($custom_css_sql, "1@@@@@") == 0))
 				 	$show_custom_styles = 1;
-				else
-					$show_custom_styles = 0;
+				elseif (!isset($custom_css_sql) || ($custom_css_sql == "") || (strpos($custom_css_sql, "0@@@@@") == 0))
+				 	$show_custom_styles = 0;
+				if (isset($custom_css_sql) && (strpos($custom_css_sql, "@@@@@") == 1))	{
+					$custom_css_sql = str_replace("0@@@@@", "", $custom_css_sql);
+					$custom_css_sql = str_replace("1@@@@@", "", $custom_css_sql);
+				}
 				
 				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
 				
 				$sort_order = $sort_order + 10;
 				$style_sheet_desc_arr = explode("Styles", $style_sheet_description);
-				if (count($style_sheet_desc_arr) > 1)
+				if (count($style_sheet_desc_arr) > 1)	{
 					$mobile_style_sheet_desc = $style_sheet_desc_arr[0] . "Mobile Styles" . $style_sheet_desc_arr[1];
-				else
+					$touchscreen_style_sheet_desc = $style_sheet_desc_arr[0] . "Touchscreen Styles" . $style_sheet_desc_arr[1];
+				}
+				else	{
 					$mobile_style_sheet_desc = $style_sheet_description . " Mobile Styles";
+					$touchscreen_style_sheet_desc = $style_sheet_description . " Touchscreen Styles";
+				}
 				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_mobile', `description`='" . $mobile_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_touchscreen', `description`='" . $touchscreen_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
 			}
+			else
+				$css_already_in_use = true;
 			
 			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T1.style_sheet = '" . $style_sheet . "' AND T2.deployed = 1";
 			$result = $bwb_dbh->query($query);
@@ -748,17 +866,31 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 			{
 				if (isset($class_sql) && ($class_sql != ""))
 				{
-					$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+					$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 				}
 				
-				if (isset($css_sql) && ($css_sql != ""))
+				if (isset($css_sql) && ($css_sql != "") && !$css_already_in_use)
 				{
-					$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+					$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 				}
 				
-				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				if (isset($css_important_sql) && ($css_important_sql != "") && !$css_already_in_use)
 				{
-					$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+					$result = RunSQL($css_important_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if (isset($custom_css_sql) && ($custom_css_sql != "") && !$css_already_in_use)
+				{
+					if (!CheckForSQL($custom_css_sql))	{
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "_mobile', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $style_sheet . "_touchscreen', '" . addslashes(stripslashes($custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+					}
+					else
+						$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 				}
 				
 				if ((isset($css_sql) && ($css_sql != "")) || (isset($custom_css_sql) && ($custom_css_sql != "")))
@@ -809,17 +941,200 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 					$result = (fputs($fh, $css_string));
 					fclose($fh) or die($php_errormsg);
 					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build touchscreen only style sheet
+					$css_string = BuildCSSString($style_sheet . "_touchscreen", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $style_sheet . "_touchscreen.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
 				}
 			}
 		}
 		if (isset($plugin_sql) && ($plugin_sql != ""))
 		{
-			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 	
-		$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
+		if (isset($plugin_name) && ($plugin_name != ""))
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `name`='$plugin_name', `deployed`=1";
+		else
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
 		$cnt = $bwb_dbh->exec($query);
-	}	
+	}
+	
+	// Create parent plugin tables if plugin selected and table not existing.
+	if (($plugin != "-not selected-") && ($parent_deployed < 1))
+	{
+		if (isset($parent_style_sheet) && ($parent_style_sheet != ""))
+		{
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name`='" . $parent_style_sheet . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() < 1)
+			{
+				$css_already_in_use = false;
+				$query = "SELECT MAX(sort_order) AS sort_order FROM " . BWB_TABLE_PREFIX . "style_sheets";
+				$result = $bwb_dbh->query($query);
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$sort_order = $row['sort_order'] + 10;
+				
+				if ((isset($parent_custom_css_sql) && ($parent_custom_css_sql != "") && (strpos($parent_custom_css_sql, "0@@@@@") === false)) || (strpos($parent_custom_css_sql, "1@@@@@") == 0))
+				 	$show_custom_styles = 1;
+				elseif (!isset($parent_custom_css_sql) || ($parent_custom_css_sql == "") || (strpos($parent_custom_css_sql, "0@@@@@") == 0))
+				 	$show_custom_styles = 0;
+				if (isset($parent_custom_css_sql) && (strpos($parent_custom_css_sql, "@@@@@") == 1))	{
+					$parent_custom_css_sql = str_replace("0@@@@@", "", $parent_custom_css_sql);
+					$parent_custom_css_sql = str_replace("1@@@@@", "", $parent_custom_css_sql);
+				}
+				
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "', `description`='" . $parent_style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$style_sheet_desc_arr = explode("Styles", $parent_style_sheet_description);
+				if (count($style_sheet_desc_arr) > 1)	{
+					$mobile_style_sheet_desc = $style_sheet_desc_arr[0] . "Mobile Styles" . $style_sheet_desc_arr[1];
+					$touchscreen_style_sheet_desc = $style_sheet_desc_arr[0] . "Touchscreen Styles" . $style_sheet_desc_arr[1];
+				}
+				else	{
+					$mobile_style_sheet_desc = $parent_style_sheet_description . " Mobile Styles";
+					$touchscreen_style_sheet_desc = $parent_style_sheet_description . " Touchscreen Styles";
+				}
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "_mobile', `description`='" . $mobile_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $parent_style_sheet . "_touchscreen', `description`='" . $touchscreen_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+			}
+			else
+				$css_already_in_use = true;
+			
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T1.style_sheet = '" . $parent_style_sheet . "' AND T2.deployed = 1";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() < 1)
+			{
+				if (isset($parent_class_sql) && ($parent_class_sql != ""))
+				{
+					$result = RunSQL($parent_class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if (isset($parent_css_sql) && ($parent_css_sql != "") && !$css_already_in_use)
+				{
+					$result = RunSQL($parent_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if (isset($parent_custom_css_sql) && ($parent_custom_css_sql != "") && !$css_already_in_use)
+				{
+					if (!CheckForSQL($parent_custom_css_sql))	{
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "_mobile', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+						$sql = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css (`name`, `custom_css`) VALUES ('" . $parent_style_sheet . "_touchscreen', '" . addslashes(stripslashes($parent_custom_css_sql)) . "')";
+						$result = $bwb_dbh->exec($sql);
+					}
+					else
+						$result = RunSQL($parent_custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if ((isset($parent_css_sql) && ($parent_css_sql != "")) || (isset($parent_custom_css_sql) && ($parent_custom_css_sql != "")))
+				{	
+					$css_string = BuildCSSString($parent_style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					////////////////////////////////////////////////////////
+					/// Write menu items to menu.css file /////////////
+					//Test to see if file already exists.
+					if (BWB_BASE_DIR == '')
+						$userfiles = '';
+					else
+						$userfiles = "/" . BWB_BASE_DIR;
+						
+					$css_file = $parent_style_sheet . ".css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build mobile style sheet
+					$css_string = BuildCSSString($parent_style_sheet . "_mobile", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $parent_style_sheet . "_mobile.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build touchscreen only style sheet
+					$css_string = BuildCSSString($parent_style_sheet . "_touchscreen", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $parent_style_sheet . "_touchscreen.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
+				}
+			}
+		}
+		if (isset($parent_plugin_sql) && ($parent_plugin_sql != ""))
+		{
+			$result = RunSQL($parent_plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+		}
+	
+		if (isset($parent_name) && ($parent_name != ""))
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$parent, `name`='$parent_name', `deployed`=1";
+		else
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$parent, `deployed`=1";
+		$cnt = $bwb_dbh->exec($query);
+	}
 	
 	//Go to edit page.
 	if (!isset($no_edit) || ($no_edit != 1))	{
@@ -834,5 +1149,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database, $source_ta
 	}
 	else
 		echo "Child Plugin Page Created";
-	
+		
+	// Re-write sitemap.xml for web crawlers.
+	include("generate_site_map.php");
 ?>
\ No newline at end of file
