@@ -18,6 +18,10 @@
 // Modified: 10/6/2017	ELL
 // Fixed bug with sub categories that have no plugins display div of next sub category.
 // Added message on where to get plugins when category or sub category contions no plugin.
+// Revised:	10/2/2019	ELL
+// Changed "parent" from using parent plugin name to using parent plugin ID.
+// Revised: 11/12/2020	ELL
+// Added display of plugin version number.
 // 
 	
 	include ("check_session.php");
@@ -84,7 +88,7 @@
 <script src="js/create_page_select.js"></script>
 <script src="js/fix_on_mouse_out.js"></script>
 
-<script language="javascript" type="text/javascript">
+<script>
 <?php
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options` WHERE `option_name` = 'Template' ORDER BY `dropdown_sort_order`";
 	$result = $bwb_dbh->query($query);
@@ -100,7 +104,7 @@
 		echo "images[$i] = \"$option_image\";\n";
 	}
 
-	$query = "SELECT `id`, `name`, `description` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `available` = 1";
+	$query = "SELECT `id`, `name`, `description`, `version` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `available` = 1";
 	$result = $bwb_dbh->query($query);
 	$plugin_cnt = $result->rowCount();
 	echo "var plugins = new Array();\n";
@@ -120,6 +124,8 @@
 	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1 . "';\n";
 	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2 . "';\n";
 	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3 . "';\n";
+	
+	echo "var http = '$http';\n";
 ?>
 </script>
 
@@ -182,7 +188,7 @@
 				$j++;
 				$top_border_style = "";
 				
-				$query = "SELECT `id`, `name`, `description`, `parent`, `default_page_name` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE (`available` = 1) AND (`category` = '$category') ORDER BY `sort_order`";
+				$query = "SELECT `id`, `name`, `description`, `parent`, `default_page_name`, `version` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE (`available` = 1) AND (`category` = '$category') ORDER BY `sort_order`";
 				$result3 = $bwb_dbh->query($query);
 				$num_results = $result3->rowCount();
 				if ($num_results > 0)	{
@@ -196,26 +202,29 @@
 					$id = $row3["id"];
 					$plugin_name = $row3["name"];
 					$description = $row3["description"];
+					$version = $row3["version"];
 					if (isset($row3["parent"]))
 						$parent = $row3["parent"];
 					else
-						$parent = "";
+						$parent = -1;
 					$default_page_name = $row3["default_page_name"];
 					if ($description != "")
 						$description = " - " . $description;
+					if ($version != "")
+						$version = " - v. " . $version;
 					$parent_child =  "";
 					$got_parent = 0;
-					if ($plugin_name == $parent)	{
+					if ($id == $parent)	{
 						$parent_child = " parent";
 						$txt_width = 98;
 						$got_parent = 1;
 					}
-					elseif (isset($parent) && ($parent != ""))	{
+					elseif ($parent > -1)	{
 						$parent_child = " child";
 						$txt_width = 96;
 					}
 
-					echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i, $got_parent, '$parent', '$default_page_name');\"><span class='button_text_sub_level_1 $parent_child' style='width:$txt_width%;'>$plugin_name$description</span></div>\n";
+					echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i, $got_parent, '$parent', '$default_page_name');\"><span class='button_text_sub_level_1 $parent_child' style='width:$txt_width%;'>$plugin_name$description$version</span></div>\n";
 					$i++;
 					$top_border_style = "";
 				}
@@ -236,7 +245,7 @@
 					$alt_sub_cat_div_str = "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;' onClick=\"DisplayNoPluginsInSubCatMsg('$sub_category', $cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$sub_category</span></div>\n";
 					$j++;
 					
-					$query = "SELECT `id`, `name`, `description`, `parent`, `default_page_name` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE (`available` = 1) AND (`category` = '$sub_category') ORDER BY `sort_order`";
+					$query = "SELECT `id`, `name`, `description`, `parent`, `default_page_name`, `version` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE (`available` = 1) AND (`category` = '$sub_category') ORDER BY `sort_order`";
 					$result3 = $bwb_dbh->query($query);
 					$num_results = $result3->rowCount();
 					if ($num_results > 0)	{
@@ -253,26 +262,30 @@
 						$id = $row3["id"];
 						$plugin_name = $row3["name"];
 						$description = $row3["description"];
+						$version = $row3["version"];
 						if (isset($row3["parent"]))
 							$parent = $row3["parent"];
 						else
-							$parent = "";
+							$parent = -1;
 						$default_page_name = $row3["default_page_name"];
 						if ($description != "")
 							$description = " - " . $description;
+						if ($version != "")
+							$version = " - v. " . $version;
 						$parent_child = "";
 						$got_parent = 0;
-						if ($plugin_name == $parent)	{
+						
+						if ($id == $parent)	{
 							$parent_child = " parent";
 							$txt_width = 98;
 							$got_parent = 1;
 						}
-						elseif (isset($parent) && ($parent != ""))	{
+						elseif ($parent > -1)	{
 							$parent_child = " child";
 							$txt_width = 96;
 						}
 						
-						echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i, $got_parent, '$parent', '$default_page_name');\"><span class='button_text_sub_level_1$parent_child' style='width:$txt_width%;'>$plugin_name$description</span></div>\n";
+						echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i, $got_parent, '$parent', '$default_page_name');\"><span class='button_text_sub_level_1$parent_child' style='width:$txt_width%;'>$plugin_name$description$version</span></div>\n";
 						$i++;
 						$top_border_style = "";
 					}
@@ -285,7 +298,7 @@
 			$cat_id++;
 			
             ?>
-            <div class='button_sub_level_1' style='width:258px;' ><a href="http://breezewebsitebuilder.com/plugins.php" target="_blank" class="button_console_link"><span class='button_text_sub_level_1'><?php echo GET_MORE_PLUGINS_BTN; ?></span></a></div>
+            <div class='button_sub_level_1' style='width:258px;' ><a href="<?php echo $http; ?>breezewebsitebuilder.com/plugins.php" target="_blank" class="button_console_link"><span class='button_text_sub_level_1'><?php echo GET_MORE_PLUGINS_BTN; ?></span></a></div>
             <div class='button_console_delete' style="width:258px; display:none;" onClick="ClearPlugin();" id="clear_plugin_btn"><span class='button_console_text_w_icon'>Clear Plugin</span></div>
             <input type="hidden" name="plugin" id="plugin" value="-not selected-" />
             <input type="hidden" name="plugin_cnt" id="plugin_cnt" value="<?php echo $plugin_cnt; ?>" />
@@ -311,10 +324,10 @@
 
 	<div id="help_list" style="display:none;" onMouseOut="fixOnMouseOut(this, event, 'CloseHelpList();');">
     	<div id='help_list_close_btn'><img src='theme/<?php echo $theme; ?>/images/close-button.png' alt='Close' onClick="document.getElementById('help_list').style.display='none';" style='cursor:pointer;' /></div>
-    	<span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_CREATING_A_PAGE; ?></span><br />
-		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo PLUGINS_WORD; ?></span><br />
-		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#start', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT; ?></span><br />
-        <hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create_page_tips', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_HELPFUL_TIPS; ?></span>
+    	<span onClick="window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#create', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_CREATING_A_PAGE; ?></span><br />
+		<hr /><span onClick="window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo PLUGINS_WORD; ?></span><br />
+		<hr /><span onClick="window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#start', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT; ?></span><br />
+        <hr /><span onClick="window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#create_page_tips', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_HELPFUL_TIPS; ?></span>
     </div>
     
 <?php include("lib/popup_msg.html"); ?>
