@@ -12,10 +12,6 @@
 	
 	include ("check_session.php");
 	
-	if (BWB_REQUIRE_SSL == 1)
-		$http = "https://";
-	else
-		$http = "http://";
 ?>
 <!DOCTYPE html>
 <html>
@@ -84,6 +80,8 @@ body	{
 	echo "	var INSTALL_UPDATE_NEW_VERSION_AVAILABLE = \"" . INSTALL_UPDATE_NEW_VERSION_AVAILABLE . "\";\n";
 	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
