@@ -16,6 +16,16 @@
 	$area_name = $_REQUEST['area_name'];
 	$redirect = $_REQUEST['redirect'];
 	
+	// Before we go any farther, back this puppy up!
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name='$area_name'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$page_content = addslashes(stripslashes($row["page_content"]));
+	$revised = $row["revised"];
+	$today = date("Y-m-d H:i:s");
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$area_name', page_content='$page_content', `source`=1, revised='$revised', deleted='$today'";
+	$cnt = $bwb_dbh->exec($query);
+	
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '". $area_name . "'";
 	$cnt = $bwb_dbh->exec($query);
 	
