@@ -22,7 +22,10 @@
 	
 	// Delete draft.
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
-	$cnt = $bwb_dbh->exec($query);
+	$cnt2 = $bwb_dbh->exec($query);
 	
-	header("Location: $redirect");
+	if (isset($redirect) && ($redirect != "-no redirect-"))
+		header("Location: $redirect");
+	else
+		echo $cnt . "@@@@@" . $head_name;
 ?>
\ No newline at end of file
