@@ -17,6 +17,5 @@
 	
 	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_items` WHERE `menu`='$menu' AND `ID` = '$ID'";
 	$cnt = $bwb_dbh->exec($query);
-	
-	header("Location: populate_menu_items.php?menu=$menu");	
+	echo $cnt;
 ?>
