@@ -37,18 +37,12 @@
 	
 	$page_content = htmlspecialchars($page_content);
 	$page_content  = str_replace("\n", "<br />", $page_content);
+	echo "<pre>\n";
 	echo $page_content;
+	echo "\n</pre>\n";
 ?>
 </div>
 <div id="preview_close_button"><img src="theme/<?php echo $theme; ?>/images/close-button.png" alt="<?php echo CLOSE_WORD; ?>" onClick="window.close();" style="cursor:pointer;" /></div>
 	
-<script language="javascript" type="text/javascript">
-    if (navigator.appName == "Microsoft Internet Explorer")
-		document.getElementById("preview_frame").height = document.documentElement.clientHeight - 32;
-	else if (navigator.appName == "Opera")
-		document.getElementById("preview_frame").height = window.innerHeight - 32;
-	else
-		document.getElementById("preview_frame").height = window.innerHeight - 32;
-</script>
 </body>
 </html>
\ No newline at end of file
