@@ -9,6 +9,8 @@
 // Added graceful handling of allow_url_fopen not set.
 // Modified: 12/13/2016	ELL
 // Added auto-login and auto-cleanup.
+// Modified: 3/23/2018	ELL
+// Added ability to customize lib dir.
 
 session_start();
 $userid = "admin";
@@ -47,6 +49,7 @@ $media = $_POST["media"];
 $flash = $_POST["flash"];
 $css = $_POST["css"];
 $scripts = $_POST["scripts"];
+$php = $_POST["php"];
 $fonts = $_POST["fonts"];
 
 $password = $_POST['admin_password'];
@@ -76,8 +79,10 @@ $language = $_POST["language"];
 $document_root = $_SERVER['DOCUMENT_ROOT'];
 $stock_connect_file = $document_root . "/install/db_connect.php";
 $stock_config_file = $document_root . "/install/config.php";
+$stock_config_sites_file = $document_root . "/install/config_sites.php";
 $connect_file = $document_root . "/connect/db_connect.php";
 $config_file = $document_root . "/connect/config.php";
+$config_sites_file = $document_root . "/connect/config_sites.php";
 
 if ((ini_get("allow_url_fopen") == 1) || (ini_get("allow_url_fopen") === true) || (strtolower(ini_get("allow_url_fopen")) == "on"))
 {
@@ -270,6 +275,7 @@ $contents = str_replace("define('BWB_CSS_DIR', 'css');", "define('BWB_CSS_DIR',
 $contents = str_replace("define('BWB_FLASH_DIR', 'flash');", "define('BWB_FLASH_DIR', '" . $flash . "');", $contents);
 $contents = str_replace("define('BWB_MEDIA_DIR', 'media');", "define('BWB_MEDIA_DIR', '" . $media . "');", $contents);
 $contents = str_replace("define('BWB_SCRIPTS_DIR', 'scripts');", "define('BWB_SCRIPTS_DIR', '" . $scripts . "');", $contents);
+$contents = str_replace("define('BWB_LIB_DIR', 'php');", "define('BWB_LIB_DIR', '" . $php . "');", $contents);
 $contents = str_replace("define('BWB_FONTS_DIR', 'fonts');", "define('BWB_FONTS_DIR', '" . $fonts . "');", $contents);
 $contents = str_replace("define('BWB_TABLE_PREFIX', 'bwb_');", "define('BWB_TABLE_PREFIX', '" . $table_prefix . "');", $contents);
 $contents = str_replace("define('BWB_REQUIRE_SSL', 0);", "define('BWB_REQUIRE_SSL', '" . $require_ssl . "');", $contents);
@@ -294,6 +300,34 @@ if (!fclose($fh4)) {
 }
 @chmod($config_file, 0644);
 
+
+if (file_exists($stock_config_sites_file))	{
+	if (!($fh5 = fopen($stock_config_sites_file, 'r'))) {
+		echo "Error opening config sites file.  Please contact your system administrator.  Click <a href=\"install.php\" title=\"here\">here</a> to return to the installation start.\n$php_errormsg";
+		exit;
+	}
+	$contents = (fread($fh5, filesize($stock_config_sites_file)));
+	fclose($fh5);
+	
+	$contents = str_replace("define('SESSION_SAVE_PATH', '/tmp');", "define('SESSION_SAVE_PATH', '" . $session_save_path . "');", $contents);
+	
+	if (!($fh6 = fopen($config_sites_file, 'w'))) {
+		echo "Error opening config file.  Please contact your system administrator.  Click <a href=\"install.php\" title=\"here\">here</a> to return to the installation start.\n$php_errormsg";
+		exit;
+	}
+	
+	if (!fwrite($fh6, $contents)) {
+				echo "Error updating config file.  Please contact your system administrator.  Click <a href=\"install.php\" title=\"here\">here</a> to return to the installation start.\n$php_errormsg";
+				exit;
+			}
+	if (!fclose($fh6)) {
+		echo "Error closing config file.  Please contact your system administrator.  Click <a href=\"install.php\" title=\"here\">here</a> to return to the installation start.\n$php_errormsg";
+		exit;
+	}
+	@chmod($config_sites_file, 0644);
+}
+
+
 // Setup table structures.
 echo "Reading SQL file...<br><br>\n";
 
