@@ -16,6 +16,8 @@
 // Updated CKEditor from version 4.4.5 to version 4.4.6.
 // Revised: 11/10/2016	ELL
 // Modified custom CSS editing to allow for any number of custom CSS records associated with custom style sheets.
+// Revised: 5/16/2018	ELL
+// Added hooks for plugin buttons and code.
 // 
 //
 	include ("check_session.php");
@@ -27,6 +29,13 @@
 	else
 		$path = "../" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/index.php";
 		
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CKEditorSkin'";
+	$result = $bwb_dbh->query($query);
+	if ($row = $result->fetch(PDO::FETCH_ASSOC))
+		$CKEditorSkin = $row['option_value'];
+	else
+		$CKEditorSkin = "breeze";
+		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CodeMirrorTheme'";
 	$result = $bwb_dbh->query($query);
 	if ($row = $result->fetch(PDO::FETCH_ASSOC))	{
@@ -39,8 +48,13 @@
 	else	{
 		$CodeMirrorTheme = "rubyblue";
 		$CodeMirrorCSS = "rubyblue";
-	}	
+	}
+	
+	/////////// Determine Plugin Buttons ///////////////////////////
+	$location = "editor";
+	include ("generate_plugin_buttons.php");
 ?>
+<!DOCTYPE html>
 <html>
 <head>
 <title>Custom <?php echo $style_sheet; ?> CSS - Editing | Breeze Website Builder</title>
@@ -50,12 +64,25 @@
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script type="text/javascript" src="js/jquery.min.js"></script>
-<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
-<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
-<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
-<script language="javascript" type="text/javascript" src="js/edit_custom_css.js"></script>
-<script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
+<style>
+<?php
+	if ($plugin_css)
+	{
+		foreach ($plugin_css as $key => $value)
+			echo $value[1];
+	}
+?>
+	#plugin_iframe	{	
+		display:none;
+	}
+</style>
+
+<script src="js/jquery.min.js"></script>
+<script src="js/browser_detect.js"></script>
+<script src="js/mouse_position.js"></script>
+<script src="js/popup_msg.js"></script>
+<script src="js/edit_custom_css.js"></script>
+<script src="../ckeditor/ckeditor.js"></script>
 
 <script>
 	var style_sheet = "<?php echo $style_sheet; ?>";
@@ -70,12 +97,13 @@
 	echo "	var EDITOR_REVERT_CSS_CONFIRM_2_MSG = \"" . EDITOR_REVERT_CSS_CONFIRM_2_MSG . "\";\n";
 	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
 	echo "	var EDITOR_REVERT_COMPLETE_MSG = \"" . EDITOR_REVERT_COMPLETE_MSG . "\";\n";
-	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
 	echo "	var EDITOR_CSS_NOT_SAVED_MSG = \"" . EDITOR_FILE_NOT_SAVED_MSG . "\";\n";
 	echo "	var SAVE_AS_WORD = \"" . SAVE_AS_WORD . "\";\n";
 	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
 	echo "	var CANCEL_WORD = \"" . CANCEL_WORD . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -88,18 +116,23 @@
     
      <div style="height:93%; width:100%;" id="editorContainer" name="editorContainer"></div>
 
-	<script type="text/javascript" language="javascript">
-    //<![CDATA[
-		CKEDITOR_BASEPATH = '../ckeditor/';
-		
-		CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'] });
+<script>
+    var workspace = window.parent.document.getElementById('workspace');
+	var workspace_width = $(workspace).innerWidth();
+	var workspace_height = $(workspace).innerHeight();
+	
+	CKEDITOR_BASEPATH = '../ckeditor/';
+	
+	CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'], removePlugins: 'zoom,letterspacing' });
 
-		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
-		CKEDITOR.config.extraPlugins = 'codemirror';
-		CKEDITOR.config.skin = 'kama';
-		CKEDITOR.config.allowedContent = true;
-		
-		CKEDITOR.config.toolbarGroups = [
+	CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
+</script>
+<?php include("plugins/ckeditor_plugins_no_design_view.php");	?>
+<script>
+	CKEDITOR.config.skin = '<?php echo $CKEditorSkin; ?>';
+	CKEDITOR.config.allowedContent = true;
+	
+	CKEDITOR.config.toolbarGroups = [
     { name: 'document',    groups: [ 'mode', 'document', 'doctools' ] },
     { name: 'editing',     groups: [ 'find', 'selection' ] },
     { name: 'tools' },
@@ -110,17 +143,9 @@
 	CKEDITOR.config.removePlugins = 'newpage,print,templates,showblocks';
 	CKEDITOR.config.removeButtons = 'Source';
 	
-	var editorElem = document.getElementById("editorContainer");
 	CKEDITOR.config.width = '99%';
-
-	if ((browser == "Explorer") && (browser_version <= 7))
-		CKEDITOR.config.height = document.body.clientHeight - 164;
-	else if ((browser == "Opera") && (browser_version < 13))
-		CKEDITOR.config.height = window.innerHeight - 139;
-	else if ((browser == "Explorer") && (browser_version == 8))
-		CKEDITOR.config.height = document.body.clientHeight - 139;
-	else
-		CKEDITOR.config.height = editorElem.clientHeight - 69;
+	CKEDITOR.config.height = workspace_height - 130;
+	CKEDITOR.config.resize_enabled = false;
 	CKEDITOR.config.resize_enabled = false;
 
 	CKEDITOR.config.startupMode = 'source';
@@ -227,36 +252,29 @@
 	
 	bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
 	bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
-	
-//]]>
 </script>
 	   
-   <table width="90%" border="0" cellspacing="0" cellpadding="0" id="btn_table">
-	 <tr>
-	 <td align="left" class="small_message" width="9%">
+<div id="btn_div" style="text-align:center;">
+     <div class="medium_message editor_btns">
 	  <span id="page_name_label"><?php echo EDITOR_STYLE_SHEET; ?>:<br /><?php echo $style_sheet; //echo $custom_site_css_table; ?></span>
-	 </td>
-	 <td align="center">
-		<div class='button_console_preview' style="width:110px;" onClick="PreviewPageSelect();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
-	  </td>
-	   <td align="center">
-		<div class='button_console_save' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
-	   </td>
-	   <td align="center">
-		<div class='button_console_save' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
-	   </td>
-	   <td align="center">
-		<div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
-	   </td>
-	   <td align="center">
-		<div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
-	   </td>
-       <td align="center" style="min-width:100px;">
-      <div class='button_console_back_sm' style="width:140px;" onClick="window.location='edit_css_select.php';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
-      </td>
-		<td align="right" width="10%"><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></td>
-	 </tr>
-   </table>
+     </div>
+		<div class='button_console_preview editor_btns' style="width:110px;" onClick="PreviewPageSelect();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
+		<div class='button_console_save editor_btns' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
+		<div class='button_console_save editor_btns' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
+		<div class='button_console_cancel editor_btns' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
+		<div class='button_console_preview editor_btns' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
+<?php
+	if ($plugin_buttons)
+	{
+		foreach ($plugin_buttons as $plugin_button)	{
+			if (($plugin_button[2] == "all_editors") || ($plugin_button[2] == "code_view_only_editors") || ($plugin_button[2] == "css_editor"))
+				echo $plugin_button[1];
+		}
+	}
+?>
+      <div class='button_console_back_sm editor_btns' style="width:140px;" onClick="window.location='edit_css_select.php';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
+        <div class="help_button editor_btns" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div>
+</div>
    </form>
 
 </div>
@@ -277,6 +295,8 @@
 <div id="preview_go" onClick="Preview(document.getElementById('page_select').value, 0);">&nbsp;</div>
 </div>
 
+<iframe id="plugin_iframe" name="plugin_iframe"></iframe>
+
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
