@@ -10,6 +10,10 @@
 // Updated CKEditor from version 4.4.5 to version 4.4.6.
 // Modified: 9/12/2016	ELL
 // Added basename() around filename tag to accomodate new ability to drill down thru file tree.
+// Revised: 5/16/2018	ELL
+// Added hooks for plugin buttons and code.
+// Revised: 9/28/2018	ELL
+// Added access to WYSIWYG mode if .html or .htm file.
 	
 	include ("check_session.php");
 	
@@ -24,6 +28,10 @@
 	
 	$file_parts = explode(".", strrev($file_name));
 	$ext = strrev($file_parts[0]);
+	$html_exts = array("html", "htm");
+	$got_html = false;
+	if (in_array(strtolower($ext), $html_exts))
+		$got_html = true;
 	
 	if (strpos($file_name, "/") === 0)
 		$file_name = substr($file_name, 1);
@@ -51,6 +59,13 @@
 	$referer = $_SERVER['HTTP_REFERER'];
 	$referer_arr = explode("/manage/", $referer);
 	$redirect = $referer_arr[1];
+	
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CKEditorSkin'";
+	$result = $bwb_dbh->query($query);
+	if ($row = $result->fetch(PDO::FETCH_ASSOC))
+		$CKEditorSkin = $row['option_value'];
+	else
+		$CKEditorSkin = "breeze";
 
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CodeMirrorTheme'";
 	$result = $bwb_dbh->query($query);
@@ -65,7 +80,14 @@
 		$CodeMirrorTheme = "rubyblue";
 		$CodeMirrorCSS = "rubyblue";
 	}
+	
+	$disable_site_styles = 0;
+	
+	/////////// Determine Plugin Buttons ///////////////////////////
+	$location = "editor";
+	include ("generate_plugin_buttons.php");
 ?>
+<!DOCTYPE html>
 <html>
 <head>
 <title><?php echo $file_name; ?> - Editing | Breeze Website Builder</title>
@@ -75,12 +97,25 @@
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script type="text/javascript" src="js/jquery.min.js"></script>
-<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
-<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
-<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
-<script language="javascript" type="text/javascript" src="js/edit_file.js"></script>
-<script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
+<style>
+<?php
+	if ($plugin_css)
+	{
+		foreach ($plugin_css as $key => $value)
+			echo $value[1];
+	}
+?>
+	#plugin_iframe	{	
+		display:none;
+	}
+</style>
+
+<script src="js/jquery.min.js"></script>
+<script src="js/browser_detect.js"></script>
+<script src="js/mouse_position.js"></script>
+<script src="js/popup_msg.js"></script>
+<script src="js/edit_file.js"></script>
+<script src="../ckeditor/ckeditor.js"></script>
 
 <script>
 	var file_name = "<?php echo $file_name; ?>";
@@ -93,6 +128,8 @@
 	
 	var redirect = "<?php echo $redirect; ?>";
 	
+	var disable_site_styles = <?php echo $disable_site_styles; ?>;
+	
 <?php
 	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
 	echo "	var EDITOR_PREPARING_PREVIEW_MSG = \"" . EDITOR_PREPARING_PREVIEW_MSG . "\";\n";
@@ -100,7 +137,6 @@
 	echo "	var EDITOR_REVERT_FILE_CONFIRM_2_MSG = \"" . EDITOR_REVERT_FILE_CONFIRM_2_MSG . "\";\n";
 	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
 	echo "	var EDITOR_REVERT_COMPLETE_MSG = \"" . EDITOR_REVERT_COMPLETE_MSG . "\";\n";
-	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
 	echo "	var EDITOR_FILE_NOT_SAVED_MSG = \"" . EDITOR_FILE_NOT_SAVED_MSG . "\";\n";
 	echo "	var EDITOR_FILE_BLANK_ERR = \"" . EDITOR_FILE_BLANK_ERR . "\";\n";
 	echo "	var EDITOR_FILE_ALREADY_EXISTS_1_ERR = \"" . EDITOR_FILE_ALREADY_EXISTS_1_ERR . "\";\n";
@@ -115,6 +151,8 @@
 	
 	echo "	var BWB_SCRIPTS_DIR = \"" . BWB_SCRIPTS_DIR . "\";\n";
 	echo "	var BWB_LIB_DIR = \"" . BWB_LIB_DIR . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -124,20 +162,109 @@
 <div style='text-align:center;'>
 <form name="frmEditHead" id="frmEditHead" action="save_head.php" method="post">
 
-	<div style="height:93%; width:100%;" id="editorContainer" name="editorContainer"></div>
+<div style="height:93%; width:100%;" id="editorContainer" name="editorContainer"></div>
 
-	<script type="text/javascript" language="javascript">
-    //<![CDATA[
-		CKEDITOR_BASEPATH = '../ckeditor/';
-		
-		CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'] });
+<script>
+	var workspace = window.parent.document.getElementById('workspace');
+	var workspace_width = $(workspace).innerWidth();
+	var workspace_height = $(workspace).innerHeight();
+    
+	CKEDITOR_BASEPATH = '../ckeditor/';
 
-		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
-		CKEDITOR.config.extraPlugins = 'codemirror';
-		CKEDITOR.config.skin = 'kama';
-		CKEDITOR.config.allowedContent = true;
+<?php	if (!$got_html)	{	?>
+	CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'], removePlugins: 'zoom,letterspacing' });
+<?php }	else	{	?>
+	CKEDITOR.replace( 'editorContainer', {
+		filebrowserBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_WEBPAGE_DIR; ?>&langCode=<?php echo BWB_LANG; ?>',
+		filebrowserImageBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_IMAGE_DIR; ?>&type=Images&langCode=<?php echo BWB_LANG; ?>',
+		filebrowserFlashBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_FLASH_DIR; ?>&type=Flash&langCode=<?php echo BWB_LANG; ?>',
+		allowedContent: true,
+<?php 
+	if ($disable_site_styles != 1)
+	{
+		echo "			contentsCss : [";
+									   
+		if (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == "mobile"))
+		{
+			$where = " WHERE (`name` NOT LIKE '%_touchscreen%') AND (exclude <> 1)";
+			$where_clause = "";
+			$and = " AND";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name` LIKE '%_mobile%' ORDER BY sort_order";
+			$result = $bwb_dbh->query($query2);
+			if ($result->rowCount() < 1)
+				$where_clause = $where;
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				$mobile_name = $row["name"];
+				$query3 = "SELECT DISTINCT name FROM " . BWB_TABLE_PREFIX . "style_sheets INNER JOIN " . BWB_TABLE_PREFIX . "site_css ON " . BWB_TABLE_PREFIX . "style_sheets.name = " . BWB_TABLE_PREFIX . "site_css.style_sheet WHERE " . BWB_TABLE_PREFIX . "style_sheets.name = '$mobile_name'";
+				$result3 = $bwb_dbh->query($query3);
+				if ($result3->rowCount() > 0)
+					$name = str_replace("_mobile", "", $mobile_name);
+				else	
+					$name = $mobile_name;
+				$where_clause .= $where . $and . " (`name` <> '" . $name . "')";
+				$where = "";
+			}
+			$query .= $where_clause . " ORDER BY sort_order";
+		}
+		elseif (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == "touchscreen"))
+		{
+			$where = " WHERE (`name` NOT LIKE '%_mobile%') AND (exclude <> 1)";
+			$where_clause = "";
+			$and = " AND";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE (`name` LIKE '%_touchscreen%') ORDER BY sort_order";
+			$result = $bwb_dbh->query($query2);
+			if ($result->rowCount() < 1)
+				$where_clause = $where;
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				$touchscreen_menu_name = $row["name"];
+				$query3 = "SELECT DISTINCT name FROM " . BWB_TABLE_PREFIX . "style_sheets INNER JOIN " . BWB_TABLE_PREFIX . "site_css ON " . BWB_TABLE_PREFIX . "style_sheets.name = " . BWB_TABLE_PREFIX . "site_css.style_sheet WHERE " . BWB_TABLE_PREFIX . "style_sheets.name = '$touchscreen_menu_name'";
+				$result3 = $bwb_dbh->query($query3);
+				if ($result3->rowCount() > 0)
+					$name = str_replace("_touchscreen", "", $touchscreen_menu_name);
+				else	
+					$name = $touchscreen_menu_name;
+				$where_clause .= $where . $and . " (`name` <> '" . $name . "')";
+				$where = "";
+			}
+			$query .= $where_clause . " ORDER BY sort_order";
+		}
+		else
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE (`name` NOT LIKE '%_mobile%') AND (`name` NOT LIKE '%_touchscreen%') AND (exclude <> 1) ORDER BY sort_order";
 		
-		CKEDITOR.config.toolbarGroups = [
+		$result = $bwb_dbh->query($query);
+		$delim = "";
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
+		{
+			$style_sheet = $row["name"] . ".css";
+			echo $delim . "'" . $userfiles . "/" . BWB_CSS_DIR . "/" . $style_sheet . "'";
+			$delim = ",";
+		}
+		echo "]\n";
+	}
+	else
+		echo "			contentsCss : ['/ckeditor/contents.css']\n";
+?>
+		});
+<?php	}	?>
+	
+	
+	
+	
+	
+
+	CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
+</script>
+<?php include("plugins/ckeditor_plugins_no_design_view.php");	?>
+<script>
+	CKEDITOR.config.skin = '<?php echo $CKEditorSkin; ?>';
+	CKEDITOR.config.allowedContent = true;
+
+<?php	if (!$got_html)	{	?>
+	CKEDITOR.config.toolbarGroups = [
     { name: 'document',    groups: [ 'mode', 'document', 'doctools' ] },
     { name: 'editing',     groups: [ 'find', 'selection' ] },
     { name: 'tools' },
@@ -147,18 +274,17 @@
 		
 	CKEDITOR.config.removePlugins = 'newpage,print,templates,showblocks';
 	CKEDITOR.config.removeButtons = 'Source';
+<?php	}	else	{	?>
+	if (disable_site_styles != 1)
+		CKEDITOR.config.stylesSet = 'bwb_styles:/ckeditor/styles.js';
+<?php	}	?>
 	
-	var editorElem = document.getElementById("editorContainer");
 	CKEDITOR.config.width = '99%';
-
-	if ((browser == "Explorer") && (browser_version <= 7))
-		CKEDITOR.config.height = document.body.clientHeight - 169;
-	else if ((browser == "Opera") && (browser_version < 13))
-		CKEDITOR.config.height = window.innerHeight - 144;
-	else if ((browser == "Explorer") && (browser_version == 8))
-		CKEDITOR.config.height = document.body.clientHeight - 144;
-	else
-		CKEDITOR.config.height = editorElem.clientHeight - 74;
+<?php	if (!$got_html)	{	?>
+	CKEDITOR.config.height = workspace_height - 130;
+<?php	}	else	{	?>
+	CKEDITOR.config.height = workspace_height - 175;
+<?php	}	?>
 	CKEDITOR.config.resize_enabled = false;
 
 	CKEDITOR.config.startupMode = 'source';
@@ -286,56 +412,51 @@
 			}
 			bwb_ckeditor.resetDirty();
 		}
+<?php if (!$got_html)	{	?>
 		else if (e.data.name == "source")
 		{
 			e.data.command = null;
 		}
+<?php	}	?>
 	}
 	
 	bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
 	bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
-	
-//]]>
 </script>
  
-  <table width="90%" align="center" id="btn_table"><tr>
-  <td align="left" class="medium_message" width="9%">
+<div id="btn_div" style="text-align:center;">
+ <div class="medium_message editor_btns">
   <span id="page_name_label"><?php echo EDITOR_FILE_NAME; ?>:<br /><?php echo basename($file_name); ?></span>
-  </td>
+ </div>
 <?php if ((strpos($folder, BWB_SCRIPTS_DIR) !== 0) && (strpos($folder, BWB_SCRIPTS_DIR) !== 1) && (strpos($folder, BWB_LIB_DIR) !== 0) && (strpos($folder, BWB_LIB_DIR) !== 1))	{	?>
-  <td align="center">
-  <div class='button_console_preview' style="width:110px;" onClick="Preview();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
-  </td>
+  <div class='button_console_preview editor_btns' style="width:110px;" onClick="Preview();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
 <?php }	?>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
-  </td>
-   <td align="center">
-  <div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_delete' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
-  </td>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="Save('save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="Save('publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
+  <div class='button_console_cancel editor_btns' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
+  <div class='button_console_delete editor_btns' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
 <?php if (strrev($file_parts[1]) != "untitled")	{	?>
-  <td align="center">
-  <div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_FILE; ?></span></div>
-  </td>
-<?php	}	?>
-  <td align="center" style="min-width:125px;">
-  <div class='button_console_back_sm' style="min-width:125px;" onClick="window.location='<?php echo $source; ?>';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
-  </td>
-  <td align="right" width="10%"><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></td>
-  </tr></table>
+  <div class='button_console_preview editor_btns' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_FILE; ?></span></div>
+<?php	}
+
+	if ($plugin_buttons)
+	{
+		foreach ($plugin_buttons as $plugin_button)	{
+			if (($plugin_button[2] == "all_editors") || ($plugin_button[2] == "code_view_only_editors") || ($plugin_button[2] == "file_editor"))
+				echo $plugin_button[1];
+		}
+	}
+?>
+  <div class='button_console_back_sm editor_btns' style="min-width:140px;" onClick="window.location='<?php echo $source; ?>';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
+  <div class="help_button editor_btns" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div>
+</div>
       
 </form>
 </div>
 
+<iframe id="plugin_iframe" name="plugin_iframe"></iframe>
+
 <?php include("lib/popup_msg.html"); ?>
 
 <script>
