@@ -27,6 +27,8 @@
 // Added "Save As"
 // Revised: 1/22/2015	ELL
 // Updated CKEditor from version 4.4.5 to version 4.4.6.
+// Revised: 5/16/2018	ELL
+// Added hooks for plugin buttons and code.
 
 	
 	include ("check_session.php");
@@ -38,6 +40,13 @@
 		$path = "../" . BWB_WEBPAGE_DIR . "/index.php";
 	else
 		$path = "../" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/index.php";
+		
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CKEditorSkin'";
+	$result = $bwb_dbh->query($query);
+	if ($row = $result->fetch(PDO::FETCH_ASSOC))
+		$CKEditorSkin = $row['option_value'];
+	else
+		$CKEditorSkin = "breeze";
 
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CodeMirrorTheme'";
 	$result = $bwb_dbh->query($query);
@@ -52,7 +61,12 @@
 		$CodeMirrorTheme = "rubyblue";
 		$CodeMirrorCSS = "rubyblue";
 	}
+	
+	/////////// Determine Plugin Buttons ///////////////////////////
+	$location = "editor";
+	include ("generate_plugin_buttons.php");
 ?>
+<!DOCTYPE html>
 <html>
 <head>
 <title><?php echo $head_name; ?> - Editing | Breeze Website Builder</title>
@@ -62,12 +76,25 @@
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script type="text/javascript" src="js/jquery.min.js"></script>
-<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
-<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
-<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
-<script language="javascript" type="text/javascript" src="js/edit_head.js"></script>
-<script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
+<style>
+<?php
+	if ($plugin_css)
+	{
+		foreach ($plugin_css as $key => $value)
+			echo $value[1];
+	}
+?>
+	#plugin_iframe	{	
+		display:none;
+	}
+</style>
+
+<script src="js/jquery.min.js"></script>
+<script src="js/browser_detect.js"></script>
+<script src="js/mouse_position.js"></script>
+<script src="js/popup_msg.js"></script>
+<script src="js/edit_head.js"></script>
+<script src="../ckeditor/ckeditor.js"></script>
 
 <script>
 	var head_name = "<?php echo $head_name; ?>";
@@ -84,7 +111,6 @@
 	echo "	var EDITOR_REVERT_HEAD_CONFIRM_2_MSG = \"" . EDITOR_REVERT_HEAD_CONFIRM_2_MSG . "\";\n";
 	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
 	echo "	var EDITOR_REVERT_COMPLETE_MSG = \"" . EDITOR_REVERT_COMPLETE_MSG . "\";\n";
-	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
 	echo "	var EDITOR_HEAD_NOT_SAVED_MSG = \"" . EDITOR_HEAD_NOT_SAVED_MSG . "\";\n";
 	echo "	var EDITOR_HEAD_BLANK_ERR = \"" . EDITOR_HEAD_BLANK_ERR . "\";\n";
 	echo "	var EDITOR_HEAD_ALREADY_EXISTS_1_ERR = \"" . EDITOR_HEAD_ALREADY_EXISTS_1_ERR . "\";\n";
@@ -96,6 +122,8 @@
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
 	echo "	var OK_WORD = \"" . OK_WORD . "\";\n";
 	echo "	var CANCEL_WORD = \"" . CANCEL_WORD . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -107,18 +135,23 @@
 
 	<div style="height:93%; width:100%;" id="editorContainer" name="editorContainer"></div>
 
-	<script type="text/javascript" language="javascript">
-    //<![CDATA[
-		CKEDITOR_BASEPATH = '../ckeditor/';
-		
-		CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'] });
+<script>
+	var workspace = window.parent.document.getElementById('workspace');
+	var workspace_width = $(workspace).innerWidth();
+	var workspace_height = $(workspace).innerHeight();
 
-		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
-		CKEDITOR.config.extraPlugins = 'codemirror';
-		CKEDITOR.config.skin = 'kama';
-		CKEDITOR.config.allowedContent = true;
-		
-		CKEDITOR.config.toolbarGroups = [
+	CKEDITOR_BASEPATH = '../ckeditor/';
+	
+	CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'], removePlugins: 'zoom,letterspacing' } );
+
+	CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
+</script>
+<?php include("plugins/ckeditor_plugins_no_design_view.php");	?>
+<script>	
+	CKEDITOR.config.skin = '<?php echo $CKEditorSkin; ?>';
+	CKEDITOR.config.allowedContent = true;
+	
+	CKEDITOR.config.toolbarGroups = [
     { name: 'document',    groups: [ 'mode', 'document', 'doctools' ] },
     { name: 'editing',     groups: [ 'find', 'selection' ] },
     { name: 'tools' },
@@ -129,17 +162,9 @@
 	CKEDITOR.config.removePlugins = 'newpage,print,templates,showblocks';
 	CKEDITOR.config.removeButtons = 'Source';
 	
-	var editorElem = document.getElementById("editorContainer");
 	CKEDITOR.config.width = '99%';
-
-	if ((browser == "Explorer") && (browser_version <= 7))
-		CKEDITOR.config.height = document.body.clientHeight - 169;
-	else if ((browser == "Opera") && (browser_version < 13))
-		CKEDITOR.config.height = window.innerHeight - 144;
-	else if ((browser == "Explorer") && (browser_version == 8))
-		CKEDITOR.config.height = document.body.clientHeight - 144;
-	else
-		CKEDITOR.config.height = editorElem.clientHeight - 74;
+	CKEDITOR.config.height = workspace_height - 130;
+	CKEDITOR.config.resize_enabled = false;
 	CKEDITOR.config.resize_enabled = false;
 
 	CKEDITOR.config.startupMode = 'source';
@@ -246,43 +271,39 @@
 	
 	bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
 	bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
-	
-//]]>
 </script>
  
-  <table width="90%" align="center" id="btn_table"><tr>
-  <td align="left" class="medium_message" width="9%">
+<div id="btn_div" style="text-align:center;">
+ <div class="medium_message editor_btns">
   <span id="page_name_label"><?php echo EDITOR_HEAD_NAME; ?>:<br /><?php echo $head_name; ?></span>
-  </td>
-  <td align="center">
-  <div class='button_console_preview_sm' style="width:110px;" onClick="Preview('<?php echo $head_name; ?>', 0);"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
-  </td>
-  <td align="center">
-  <div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
-  </td>
+ </div>
+  <div class='button_console_preview editor_btns' style="width:110px;" onClick="Preview('<?php echo $head_name; ?>', 0);"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
+  <div class='button_console_save editor_btns' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
+  <div class='button_console_cancel editor_btns' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
 <?php if (($access_level == "admin") || ($access_level == "power_user")) { ?>
-  <td align="center">
-  <div class='button_console_delete' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
-  </td>
+  <div class='button_console_delete editor_btns' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
 <?php } ?>
-  <td align="center">
-  <div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
-  </td>
-  <td align="right" width="10%"><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></td>
-  </tr></table>
+  <div class='button_console_preview editor_btns' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
+<?php
+	if ($plugin_buttons)
+	{
+		foreach ($plugin_buttons as $plugin_button)	{
+			if (($plugin_button[2] == "all_editors") || ($plugin_button[2] == "code_view_only_editors") || ($plugin_button[2] == "head_code_editor"))
+				echo $plugin_button[1];
+		}
+	}
+?>
+      <div class='button_console_back_sm editor_btns' style="min-width:140px;" onClick="window.location='edit_head_select.php';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
+  <div class="help_button editor_btns" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div>
+</div>
       
 </form>
 </div>
 
+<iframe id="plugin_iframe" name="plugin_iframe"></iframe>
+
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="JavaScript"  type="text/javascript">
