@@ -86,6 +86,10 @@
 	z-index:100;
 }
 #save_metatags_btn	{	width:110px;	}
+.button_heading_sub_level_1	{
+	margin-left: 5%;
+	margin-bottom: 3px;
+}
 </style>
 
 <script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
@@ -93,12 +97,14 @@
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
 <script language="javascript" type="text/javascript" src="js/edit_meta_tags.js"></script>
 
+<script>
+<?php	echo "	var http = '$http';\n";	?>
+</script>
 </head>
 
 <body id="workspace_body">
-<table width="90%" align="center"><tr><td>
+
 <div class="button_heading_sub_level_1" id="edit_metatags_heading"><div class="button_heading_text_sub_level_1"><?php echo EDIT_META_TAGS_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
 
 <form name="formEditMetatags" id="formEditMetatags" method="post" action="save_meta_tags.php">
 <table width="90%" class="group_box_table" align="center">
