@@ -24,8 +24,10 @@
 // Updated CKEditor from version 4.4.5 to version 4.4.6.
 // Revised:	2/2/2012	ELL
 // Fixed bug with "See Site" button not updating to new file after "Save As".
-// Rezised: 4/28/2016	ELL
+// Revised: 4/28/2016	ELL
 // Added ability to use either desktop styles or mobile styles.
+// Revised: 5/14/2018	ELL
+// Added hooks for plugin buttons and code.
 
 
 	include ("check_session.php");
@@ -109,6 +111,13 @@
 		unset($_SESSION['site_styles']);
 	}
 	
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CKEditorSkin'";
+	$result = $bwb_dbh->query($query);
+	if ($row = $result->fetch(PDO::FETCH_ASSOC))
+		$CKEditorSkin = $row['option_value'];
+	else
+		$CKEditorSkin = "breeze";
+	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "options_selected WHERE option_name='CodeMirrorTheme'";
 	$result = $bwb_dbh->query($query);
 	if ($row = $result->fetch(PDO::FETCH_ASSOC))	{
@@ -122,7 +131,12 @@
 		$CodeMirrorTheme = "rubyblue";
 		$CodeMirrorCSS = "rubyblue";
 	}
+	
+	/////////// Determine Plugin Buttons ///////////////////////////
+	$location = "editor";
+	include ("generate_plugin_buttons.php");
 ?>
+<!DOCTYPE html>
 <html>
 <head>
 <title><?php if ($mode == "blog") echo "Blog ID " . $blog_id; else echo $page_name; ?> - Editing | Breeze Website Builder</title>
@@ -132,15 +146,28 @@
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
-<script type="text/javascript" src="js/jquery.min.js"></script>
-<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
-<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
-<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
-<script language="javascript" type="text/javascript" src="js/edit_page.js"></script>
-<script language="javascript" type="text/javascript" src="js/fix_on_mouse_out.js"></script>
+<style>
+<?php
+	if ($plugin_css)
+	{
+		foreach ($plugin_css as $key => $value)
+			echo $value[1];
+	}
+?>
+	#plugin_iframe	{	
+		display:none;
+	}
+</style>
 
-<script type="text/javascript" language="javascript">
+<script src="../ckeditor/ckeditor.js"></script>
+<script src="js/jquery.min.js"></script>
+<script src="js/browser_detect.js"></script>
+<script src="js/mouse_position.js"></script>
+<script src="js/popup_msg.js"></script>
+<script src="js/edit_page.js"></script>
+<script src="js/fix_on_mouse_out.js"></script>
+
+<script>
  var page_name = "<?php echo $page_name; ?>";
  var special = "<?php echo $special; ?>";
  var blog_id = "<?php echo $blog_id; ?>";
@@ -163,9 +190,9 @@
 		echo " help_list_html = help_list_html + \"<span onClick=\\\"window.open('$url', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\\\" style='cursor:pointer'>$name</span><br />\";\n";
 	}
 ?>
-	help_list_html = help_list_html + "<hr /><span onClick=\"window.open('http://breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\" style='cursor:pointer'>Plugins</span><br />";
+	help_list_html = help_list_html + "<hr /><span onClick=\"window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\" style='cursor:pointer'>Plugins</span><br />";
 	
-	help_list_html = help_list_html + "<hr /><span onClick=\"window.open('http://breezewebsitebuilder.com/docs/cms/help.html#edit_page', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\" style='cursor:pointer'>Using Page Editor</span>";
+	help_list_html = help_list_html + "<hr /><span onClick=\"window.open('<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#edit_page', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\" style='cursor:pointer'>Using Page Editor</span>";
 	
 <?php
 	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
@@ -177,7 +204,6 @@
 	echo "	var EDITOR_REVERT_PAGE_CONFIRM_1_MSG = \"" . EDITOR_REVERT_PAGE_CONFIRM_1_MSG . "\";\n";
 	echo "	var EDITOR_REVERT_PAGE_CONFIRM_2_MSG = \"" . EDITOR_REVERT_PAGE_CONFIRM_2_MSG . "\";\n";
 	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
-	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
 	echo "	var EDITOR_PAGE_NOT_SAVED_MSG = \"" . EDITOR_PAGE_NOT_SAVED_MSG . "\";\n";
 	echo "	var EDITOR_PAGE_BLANK_ERR = \"" . EDITOR_PAGE_BLANK_ERR . "\";\n";
 	echo "	var EDITOR_PAGE_ALREADY_EXISTS_1_ERR = \"" . EDITOR_PAGE_ALREADY_EXISTS_1_ERR . "\";\n";
@@ -198,6 +224,8 @@
 	
 	echo "	var BWB_BASE_DIR = \"" . BWB_BASE_DIR . "\";\n";
 	echo "	var BWB_WEBPAGE_DIR = \"" . BWB_WEBPAGE_DIR . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -208,39 +236,73 @@
 <form action="edit_page.php" method="post" name="frmEditPage">
 <div style="height:93%; width:100%;" id="editorContainer" name="editorContainer"></div>
 
-	<script type="text/javascript" language="javascript">
-    //<![CDATA[
-		CKEDITOR_BASEPATH = '../ckeditor/';
-		
-		CKEDITOR.replace( 'editorContainer', {
-			filebrowserBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_WEBPAGE_DIR; ?>&langCode=<?php echo BWB_LANG; ?>',
-			filebrowserImageBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_IMAGE_DIR; ?>&type=Images&langCode=<?php echo BWB_LANG; ?>',
-			filebrowserFlashBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_FLASH_DIR; ?>&type=Flash&langCode=<?php echo BWB_LANG; ?>',
+<script>
+	var workspace = window.parent.document.getElementById('workspace');
+	var workspace_width = $(workspace).innerWidth();
+	var workspace_height = $(workspace).innerHeight();
+	
+	CKEDITOR_BASEPATH = '../ckeditor/';
+	
+	CKEDITOR.replace( 'editorContainer', {
+		filebrowserBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_WEBPAGE_DIR; ?>&langCode=<?php echo BWB_LANG; ?>',
+		filebrowserImageBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_IMAGE_DIR; ?>&type=Images&langCode=<?php echo BWB_LANG; ?>',
+		filebrowserFlashBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_FLASH_DIR; ?>&type=Flash&langCode=<?php echo BWB_LANG; ?>',
+		allowedContent: true,
 <?php 
 	if ($disable_site_styles != 1)
 	{
 		echo "			contentsCss : [";
-									   
-		if (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == 1))
+			
+		if (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == "mobile"))
 		{
-			$where = " WHERE";
+			$where = " WHERE (`name` NOT LIKE '%_touchscreen%') AND (exclude <> 1)";
 			$where_clause = "";
-			$and = "";
+			$and = " AND";
 			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
 			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name` LIKE '%_mobile%' ORDER BY sort_order";
 			$result = $bwb_dbh->query($query2);
+			if ($result->rowCount() < 1)
+				$where_clause = $where;
 			while ($row = $result->fetch(PDO::FETCH_ASSOC))
 			{
-				$name = $row["name"];
-				$name = str_replace("_mobile", "", $name);
+				$mobile_name = $row["name"];
+				$query3 = "SELECT DISTINCT name FROM " . BWB_TABLE_PREFIX . "style_sheets INNER JOIN " . BWB_TABLE_PREFIX . "site_css ON " . BWB_TABLE_PREFIX . "style_sheets.name = " . BWB_TABLE_PREFIX . "site_css.style_sheet WHERE " . BWB_TABLE_PREFIX . "style_sheets.name = '$mobile_name'";
+				$result3 = $bwb_dbh->query($query3);
+				if ($result3->rowCount() > 0)
+					$name = str_replace("_mobile", "", $mobile_name);
+				else	
+					$name = $mobile_name;
+				$where_clause .= $where . $and . " (`name` <> '" . $name . "')";
+				$where = "";
+			}
+			$query .= $where_clause . " ORDER BY sort_order";
+		}
+		elseif (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == "touchscreen"))
+		{
+			$where = " WHERE (`name` NOT LIKE '%_mobile%') AND (exclude <> 1)";
+			$where_clause = "";
+			$and = " AND";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE (`name` LIKE '%_touchscreen%') ORDER BY sort_order";
+			$result = $bwb_dbh->query($query2);
+			if ($result->rowCount() < 1)
+				$where_clause = $where;
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				$touchscreen_menu_name = $row["name"];
+				$query3 = "SELECT DISTINCT name FROM " . BWB_TABLE_PREFIX . "style_sheets INNER JOIN " . BWB_TABLE_PREFIX . "site_css ON " . BWB_TABLE_PREFIX . "style_sheets.name = " . BWB_TABLE_PREFIX . "site_css.style_sheet WHERE " . BWB_TABLE_PREFIX . "style_sheets.name = '$touchscreen_menu_name'";
+				$result3 = $bwb_dbh->query($query3);
+				if ($result3->rowCount() > 0)
+					$name = str_replace("_touchscreen", "", $touchscreen_menu_name);
+				else	
+					$name = $touchscreen_menu_name;
 				$where_clause .= $where . $and . " (`name` <> '" . $name . "')";
-				$and = " AND";
 				$where = "";
 			}
 			$query .= $where_clause . " ORDER BY sort_order";
 		}
 		else
-			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name` NOT LIKE '%_mobile%' ORDER BY sort_order";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE (`name` NOT LIKE '%_mobile%') AND (`name` NOT LIKE '%_touchscreen%') AND (exclude <> 1) ORDER BY sort_order";
 		
 		$result = $bwb_dbh->query($query);
 		$delim = "";
@@ -258,22 +320,15 @@
 		});
 
 		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
-		CKEDITOR.config.extraPlugins = 'zoom,letterspacing,codemirror';
-		CKEDITOR.config.skin = 'kama';
-		CKEDITOR.config.allowedContent = true;
+		CKEDITOR.config.skin = '<?php echo $CKEditorSkin; ?>';
+</script>
+<?php include("plugins/ckeditor_plugins.php");	?>
+<script>
 		if (disable_site_styles != 1)
 			CKEDITOR.config.stylesSet = 'bwb_styles:/ckeditor/styles.js';
-        var editorElem = document.getElementById("editorContainer");
-        CKEDITOR.config.width = '99%';
 
-		if ((browser == "Explorer") && (browser_version <= 7))
-        	CKEDITOR.config.height = document.body.clientHeight - 215;
-		else if ((browser == "Opera") && (browser_version < 13))
-			CKEDITOR.config.height = window.innerHeight - 205;
-		else if ((browser == "Explorer") && (browser_version == 8))
-			CKEDITOR.config.height = document.body.clientHeight - 215;
-		else
-			CKEDITOR.config.height = editorElem.clientHeight - 135;
+        CKEDITOR.config.width = '99%';
+		CKEDITOR.config.height = workspace_height - 175;
         CKEDITOR.config.resize_enabled = false;
 <?php
 		if (isset($_SESSION['editor_mode']) && ($_SESSION['editor_mode'] == 1))
@@ -331,87 +386,71 @@
 		useBeautify: false
 	};
 			
-		var bwb_ckeditor = CKEDITOR.instances['editorContainer'];
-		
-		function somethingChanged()	{
-			if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
-			{
-				saved = false;
-				window.parent.SetWorkSavedNotSaved(saved);
-				try	{
-					bwb_ckeditor.commands.save.enable();
-				}
-				catch(err)	{
-					err = 0;
-				}
+	var bwb_ckeditor = CKEDITOR.instances['editorContainer'];
+	
+	function somethingChanged()	{
+		if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
+		{
+			saved = false;
+			window.parent.SetWorkSavedNotSaved(saved);
+			try	{
+				bwb_ckeditor.commands.save.enable();
+			}
+			catch(err)	{
+				err = 0;
 			}
 		}
+	}
 
-		function somethingHappened(e)	{
-			if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
-				window.parent.SetWorkSavedNotSaved(true);
-				
-			if (e.data.name == "newpage")
-			{
-				e.data.command = null;
-				ClearContent();
-			}
-			else if (e.data.name == "preview")
-			{
-				e.data.command = null;
-				Preview();
-			}
-			else if (e.data.name == "save")
-			{
-				e.data.command = null;
-				Save('save_draft');
-				try	{
-					bwb_ckeditor.commands.save.disable();
-				}
-				catch(err)	{
-					err = 0;
-				}
-				bwb_ckeditor.resetDirty();
-			}
+	function somethingHappened(e)	{
+		if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
+			window.parent.SetWorkSavedNotSaved(true);
+			
+		if (e.data.name == "newpage")
+		{
+			e.data.command = null;
+			ClearContent();
 		}
-		
-		bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
-		bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
-		
-    //]]>
-    </script>
+		else if (e.data.name == "preview")
+		{
+			e.data.command = null;
+			Preview();
+		}
+		else if (e.data.name == "save")
+		{
+			e.data.command = null;
+			Save('save_draft');
+			try	{
+				bwb_ckeditor.commands.save.disable();
+			}
+			catch(err)	{
+				err = 0;
+			}
+			bwb_ckeditor.resetDirty();
+		}
+	}
+	
+	bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
+	bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
+</script>
             
-      
-	  <table width="100%" align="center" id="btn_table"><tr>
-	  <td align="left" class="medium_message" width="9%">
+<div id="btn_div" style="text-align:center;">
+	<div class="medium_message editor_btns">
       <?php echo EDITOR_PAGE_NAME; ?>:<br/><span id="page_name_label"><?php echo $page_name; if ($mode == "blog") echo " $blog_revised"; ?></span>
-	  </td>
+    </div>
 <?php if ($mode != "mega_menu")	{	?>
-      <td align="center" style="min-width:90px;">
-      <div class='button_console_preview_sm' style="min-width:90px;" onClick="Preview('<?php echo $page_name; ?>', 0);"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
-	  </td>
+      <div class='button_console_preview_sm editor_btns' onClick="Preview('<?php echo $page_name; ?>', 0);" style="width:90px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
 <?php }	?>
-      <td align="center" style="min-width:80px;">
-      <div class='button_console_save_sm' style="min-width:80px;" onClick="Save('save_draft');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE; ?></span></div>
-	  </td>
+      <div class='button_console_save_sm editor_btns' onClick="Save('save_draft');" style="width:80px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE; ?></span></div>
 <?php if ($mode != "blog") { ?>
-      <td align="center" style="min-width:90px;">
-      <div class='button_console_save_sm' style="min-width:90px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
-	  </td>
+      <div class='button_console_save_sm editor_btns' onClick="ShowSaveAsMsg();" style="width:90px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
 <?php } ?>
-	  <td align="center" style="min-width:90px;">
-      <div class='button_console_save_sm' style="min-width:90px;" onClick="Save('publish');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
-	  </td>
-      <td align="center" style="min-width:80px;">
-      <div class='button_console_cancel_sm' style="min-width:80px;" onClick="RevertConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_REVERT; ?></span></div>
-	  </td>
+      <div class='button_console_save_sm editor_btns' onClick="Save('publish');" style="width:90px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
+      <div class='button_console_cancel_sm editor_btns' onClick="RevertConfirm('<?php echo $mode; ?>');" style="width:80px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_REVERT; ?></span></div>
 <?php if (($access_level == "admin") || ($access_level == "power_user")) { ?>
-	  <td align="center" style="min-width:80px;">
-      <div class='button_console_delete_sm' style="min-width:80px;" onClick="DeleteConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_DELETE; ?></span></div>
-	  </td>
+      <div class='button_console_delete_sm editor_btns' onClick="DeleteConfirm('<?php echo $mode; ?>');" style="width:80px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_DELETE; ?></span></div>
 <?php } ?>
-      <td align="center">
-      <div class='button_console_preview_sm' id="see_site_btn" style="min-width:90px;"
+      <div class='button_console_preview_sm editor_btns' id="see_site_btn" style="width:95px;"
 <?php
 		echo "onClick=\"window.open('..";
 		echo $userfiles . $website_folder . "/";
@@ -421,42 +460,36 @@
 			echo $page_name;
 		echo ".php', '_blank');\"";
 ?>
-      ><span class='button_console_text_w_sm_icon' style="min-width:90px;"><?php echo EDITOR_SEE_SITE; ?></span></div>
-	  </td>
-      <td align="center" style="min-width:75px;">
-      <div class='button_console_delete_sm' style="min-width:75px;" onClick="ClearContent();"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_CLEAR; ?></span></div>
-      </td>
-	  <td width="2%">&nbsp;
-      
-	  </td>
-      <td align="center" style="min-width:145px;">
-      <div class='button_console_image_sm' style="min-width:145px;" onClick="OptimizeResetImages('optimize');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_OPTIMIZE_IMAGES; ?></span></div>
-      </td>
-      <td align="center" style="min-width:125px;">
-      <div class='button_console_image_sm' style="min-width:125px;" onClick="OptimizeResetImages('reset');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_RESET_IMAGES; ?></span></div>
-      </td>
-      <td style="min-width:115px;">
+      ><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
+      <div class='button_console_delete_sm editor_btns' onClick="ClearContent();" style="width:75px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_CLEAR; ?></span></div>
+      <div class='editor_btns' style="width:25px;">&nbsp;</div>
+      <div class='button_console_image_sm editor_btns' onClick="OptimizeResetImages('optimize');" style="width:145px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_OPTIMIZE_IMAGES; ?></span></div>
+      <div class='button_console_image_sm editor_btns' style="width:125px;" onClick="OptimizeResetImages('reset');" style="width:125px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_RESET_IMAGES; ?></span></div>
 <?php if ($access_level != "restricted") { ?>
-      <div class='button_console_edit_sm' style="min-width:115px;" onClick="window.open('edit_css.php?style_sheet=site','_blank');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_EDIT_STYLES; ?></span></div>
-<?php } else echo "&nbsp;"; ?>
-      </td>
-      <td align="center" style="min-width:125px;">
-      <div class='button_console_back_sm' style="min-width:125px;" onClick="window.location='<?php echo $source; ?>';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
-      </td>
-      <td width="1%">&nbsp;</td>
-      <td align="center" width="2%">
-      <div class="help_button" <?php if (count($plugin_help) > 0) echo "onMouseOver='OpenHelpList(" . count($plugin_help). ");'"; else echo "onClick='OpenHelpWindow();'"; ?>>
+      <div class='button_console_edit_sm editor_btns' onClick="window.open('edit_css.php?style_sheet=site','_blank');" style="width:115px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_EDIT_STYLES; ?></span></div>
+<?php }
+
+	if ($plugin_buttons)
+	{
+		foreach ($plugin_buttons as $plugin_button)	{
+			if (($plugin_button[2] == "all_editors") || ($plugin_button[2] == "design_view_editors"))
+				echo $plugin_button[1];
+		}
+	}
+?>
+      <div class='button_console_back_sm editor_btns' onClick="window.location='<?php echo $source; ?>';" style="width:145px;"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
+      <div class="help_button editor_btns" <?php if (count($plugin_help) > 0) echo "onMouseOver='OpenHelpList(" . count($plugin_help). ");'"; else echo "onClick='OpenHelpWindow();'"; ?>>
 	    &nbsp;
       </div>
-	  </td>
-	  </tr></table>
+</div>
     </form>
     
  	<div id="help_list" style="display:none;" onMouseOut="fixOnMouseOut(this, event, 'CloseHelpList();');">&nbsp;</div>
+    <iframe id="plugin_iframe" name="plugin_iframe"></iframe>
 
 <?php include("lib/popup_msg.html"); ?>
 
-<script language="javascript" type="text/javascript">
+<script>
 	popup_msg.HidePopupMsg();
 	
 <?php 
