@@ -41,6 +41,9 @@
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
 <script language="javascript" type="text/javascript" src="js/edit_title_select.js"></script>
 
+<script>
+<?php	echo "	var http = '$http';\n";	?>
+</script>
 </head>
 
 <body>
