@@ -28,6 +28,8 @@ function ElExists(el)
 {
 	if ((document.getElementById(el) != null) && (typeof document.getElementById(el) != "undefined"))
 		return true;
+	else if ((document.getElementsByName(el) != null) && (typeof document.getElementsByName(el) != "undefined") && (document.getElementsByName(el).length > 0))
+		return document.getElementsByName(el).length;
 	else
 		return false;
 }
@@ -57,77 +59,82 @@ function ShowPasswordReset()
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
 function InitializeForm()
 { 
-	if (ElExists('submit_btn'))
+	if (ElExists('submit_btn') === true)
 		document.getElementById("submit_btn").style.display = "none";
 		
-	if (ElExists('form_div_btn'))
+	if (ElExists('form_div_btn') === true)
 		document.getElementById("form_div_btn").style.display = "inline-block";
 		
-	if (ElExists('create_acct_div_button'))
+	if (ElExists('create_acct_div_button') === true)
 		document.getElementById("create_acct_div_button").style.display = "inline-block";
 		
 	var php_path_rel = php_dir_rel + "formmail.php";
 	if ((login_required === false) || (logged_in === true))	{
-		if (ElExists('frmMailForm'))	{
+		if (ElExists('frmMailForm') === true)	{
 			if (document.getElementById("frmMailForm").action == "")
 				document.getElementById("frmMailForm").action = php_path_rel;
 		}
 	}
-	if (ElExists('frmAccountCreateForm'))	{
+	if (ElExists('frmAccountCreateForm') === true)	{
 		if (document.getElementById("frmAccountCreateForm").action == "")
 			document.getElementById("frmAccountCreateForm").action = php_path_rel;
 	}
 	
 	var redirect_path = document.getElementById("redirect").value;
+	var redirect_not_local = 0;
+	if (ElExists('redirect_not_local') === true)
+		redirect_not_local = document.getElementById("redirect_not_local").value;
 	if (redirect_path == "")
 		redirect_path = redirect;
-	var redirect_path_arr = redirect_path.split("/");
-	var redirect_file = "";
-	for(var i in redirect_path_arr)
-	{
-		if ((redirect_path_arr[i].indexOf(".php")) > 0)
-			redirect_file = redirect_path_arr[i];
+	if (redirect_not_local != 1)	{
+		var redirect_path_arr = redirect_path.split("/");
+		var redirect_file = "";
+		for(var i in redirect_path_arr)
+		{
+			if ((redirect_path_arr[i].indexOf(".php")) > 0)
+				redirect_file = redirect_path_arr[i];
+		}
+		redirect_path = webpage_dir + redirect_file;
 	}
-	redirect_path = webpage_dir + redirect_file;
 	document.getElementById("redirect").value = redirect_path;
 	
 	var alt_go_back = webpage_dir + this_page;
 	if (document.getElementById("alt_go_back").value == "")
 		document.getElementById("alt_go_back").value = alt_go_back;
 		
-	if (ElExists('recaptcha_row'))
+	if (ElExists('recaptcha_row') === true)
 		document.getElementById("recaptcha_row").style.display = "none";
-	if (ElExists('recaptcha2_row'))
+	if (ElExists('recaptcha2_row') === true)
 		document.getElementById("recaptcha2_row").style.display = "none";
-	if (ElExists('wscaptcha_row'))
+	if (ElExists('wscaptcha_row') === true)
 		document.getElementById("wscaptcha_row").style.display = "none";
-	if (ElExists('mollomcaptcha_row'))
+	if (ElExists('mollomcaptcha_row') === true)
 		document.getElementById("mollomcaptcha_row").style.display = "none";
 	if (document.getElementById("use_captcha").value == 1)
 	{
 		var element_type;
-		if ((document.getElementById("captcha_type").value == "recaptcha") && ElExists('recaptcha_row'))	{
+		if ((document.getElementById("captcha_type").value == "recaptcha") && ElExists('recaptcha_row') === true)	{
 			element_type = document.getElementById("recaptcha_row").tagName.toLowerCase();
 			if (element_type == "tr")
 				document.getElementById("recaptcha_row").style.display = "table-row";
 			else
 				document.getElementById("recaptcha_row").style.display = "inline-block";
 		}
-		else if ((document.getElementById("captcha_type").value == "recaptcha2") && ElExists('recaptcha2_row'))	{
+		else if ((document.getElementById("captcha_type").value == "recaptcha2") && ElExists('recaptcha2_row') === true)	{
 			element_type = document.getElementById("recaptcha2_row").tagName.toLowerCase();
 			if (element_type == "tr")
 				document.getElementById("recaptcha2_row").style.display = "table-row";
 			else
 				document.getElementById("recaptcha2_row").style.display = "inline-block";
 		}
-		else if ((document.getElementById("captcha_type").value == "wscaptcha") && ElExists('wscaptcha_row'))	{
+		else if ((document.getElementById("captcha_type").value == "wscaptcha") && ElExists('wscaptcha_row') === true)	{
 			element_type = document.getElementById("wscaptcha_row").tagName.toLowerCase();
 			if (element_type == "tr")
 				document.getElementById("wscaptcha_row").style.display = "table-row";
 			else
 				document.getElementById("wscaptcha_row").style.display = "inline-block";
 		}
-		else if ((document.getElementById("captcha_type").value == "mollom") && ElExists('mollomcaptcha_row'))	{
+		else if ((document.getElementById("captcha_type").value == "mollom") && ElExists('mollomcaptcha_row') === true)	{
 			element_type = document.getElementById("mollomcaptcha_row").tagName.toLowerCase();
 			if (element_type == "tr")
 				document.getElementById("mollomcaptcha_row").style.display = "table-row";
@@ -196,52 +203,120 @@ function InitializeForm()
 	
 	///////////////////////////////////////////////////
 	// Set class on required fields to .required_field
+	var use_classic_required_field_marks = 0;
+	if (ElExists("use_classic_required_field_marks") === true)
+		use_classic_required_field_marks = document.getElementById("use_classic_required_field_marks").value;
+		
 	var required_fields_str = document.getElementById("required_fields").value;
 	var required_fields = required_fields_str.split(",");
-	var field_name;
+	var field_name, required_mark_id;
 	for (i = 0; i < required_fields.length; i++)
 	{
 		field_name = required_fields[i].trim();
-		if (field_name != "")	{
-			if (ElExists(field_name))
-				document.getElementById(field_name).className = document.getElementById(field_name).className + " required_field";
-			else if ((document.getElementsByName(field_name) != null) && (typeof document.getElementsByName(field_name) != "undefined"))	{
-				if ((document.getElementsByName(field_name).item(0).type != null) && (typeof document.getElementsByName(field_name).item(0).type != "undefined") && (document.getElementsByName(field_name).item(0).type == "radio"))	{
-					if (ElExists(field_name + "_div"))
-						document.getElementById(field_name + "_div").className = document.getElementById(field_name + "_div").className + " required_field";
+		required_mark_id = "required_mark_" + field_name;
+		if (field_name != "")
+		{
+			if (use_classic_required_field_marks != 1)
+			{
+				if (ElExists(field_name) === true)
+					document.getElementById(field_name).className = document.getElementById(field_name).className + " required_field";
+				else if ((document.getElementsByName(field_name) != null) && (typeof document.getElementsByName(field_name) != "undefined"))	{
+					if ((document.getElementsByName(field_name).item(0).type != null) && (typeof document.getElementsByName(field_name).item(0).type != "undefined") && (document.getElementsByName(field_name).item(0).type == "radio"))	{
+						if (ElExists(field_name + "_div") === true)
+							document.getElementById(field_name + "_div").className = document.getElementById(field_name + "_div").className + " required_field";
+					}
 				}
-			}
-
-			if (ElExists(field_name))	{
-				if ((document.getElementById(field_name).type != null) && (typeof document.getElementById(field_name).type != "undefined") && (document.getElementById(field_name).type == "checkbox"))	{
-					if (ElExists(field_name + "_div"))
-						document.getElementById(field_name + "_div").className = document.getElementById(field_name + "_div").className + " required_field";
+	
+				if (ElExists(field_name) === true)	{
+					if ((document.getElementById(field_name).type != null) && (typeof document.getElementById(field_name).type != "undefined") && (document.getElementById(field_name).type == "checkbox"))	{
+						if (ElExists(field_name + "_div") === true)
+							document.getElementById(field_name + "_div").className = document.getElementById(field_name + "_div").className + " required_field";
+					}
 				}
 			}
+			
+			if ((ElExists(required_mark_id) === true) && (use_classic_required_field_marks > 0))
+				document.getElementById(required_mark_id).innerHTML = "*";
 		}
 	}
-	if (ElExists("email_required") && (document.getElementById("email_required").value == 1))	{
-		if (ElExists('email'))
-			document.getElementById("email").className = document.getElementById("email").className + " required_field";
-		if (ElExists('email_confirm'))
-			document.getElementById("email_confirm").className = document.getElementById("email_confirm").className + " required_field";
+	if ((ElExists("email_required") === true) && (document.getElementById("email_required").value == 1))	{
+		if (use_classic_required_field_marks != 1)	{
+			if (ElExists('email') === true)
+				document.getElementById("email").className = document.getElementById("email").className + " required_field";
+			if (ElExists('email_confirm') === true)
+				document.getElementById("email_confirm").className = document.getElementById("email_confirm").className + " required_field";
+		}
+		if (use_classic_required_field_marks > 0)	{
+			if (ElExists('required_mark_email') === true)
+				document.getElementById("required_mark_email").innerHTML = "*";
+			if (ElExists('required_mark_email_confirm') === true)
+				document.getElementById("required_mark_email_confirm").innerHTML = "*";
+		}
 	}
-	if (ElExists("password_required") && (document.getElementById("password_required").value == 1))	{
-		if (ElExists('password'))
-			document.getElementById("password").className = document.getElementById("password").className + " required_field";
-		if (ElExists('password_confirm'))
-			document.getElementById("password_confirm").className = document.getElementById("password_confirm").className + " required_field";
+	if ((ElExists("password_required") === true) && (document.getElementById("password_required").value == 1))	{
+		if (use_classic_required_field_marks != 1)	{
+			if (ElExists('password') === true)
+				document.getElementById("password").className = document.getElementById("password").className + " required_field";
+			if (ElExists('password_confirm') === true)
+				document.getElementById("password_confirm").className = document.getElementById("password_confirm").className + " required_field";
+		}
+		if (use_classic_required_field_marks > 0)	{
+			if (ElExists('required_mark_password') === true)
+				document.getElementById("required_mark_password").innerHTML = "*";
+			if (ElExists('required_mark_password_confirm') === true)
+				document.getElementById("required_mark_password_confirm").innerHTML = "*";
+		}
 	}
 	
-	// Hide all reqired marks (not needed if JavaScript is running).
-	var elems = document.getElementsByTagName('*');
-	var matchClass = "required_mark"
-	for (i in elems) {
-		if((' ' + elems[i].className + ' ').indexOf(' ' + matchClass + ' ') > -1) {
-			elems[i].style.display = "none";
+	// Clear all hard-coded required asteriks for non-required fields.
+	if (document.getElementsByClassName("required_mark").length > 0)	{
+		var required_mark_el = document.getElementsByClassName("required_mark");
+		var required_mark_id, field_name;
+		for (i = 0; i < required_mark_el.length; i++)
+		{
+			if (typeof required_mark_el[i] !== 'undefined')	{
+				required_mark_id = required_mark_el[i].id;
+				if ((typeof required_mark_id !== 'undefined') && (required_mark_id != ""))	{
+					field_name = required_mark_id.replace("required_mark_", "");
+					if (required_fields.indexOf(field_name) < 0)
+						required_mark_el[i].innerHTML = "";
+					if (((field_name == "email") || (field_name == "email_confirm")) && (ElExists("email_required") === true) && (document.getElementById("email_required").value == 1))
+						required_mark_el[i].innerHTML = "*";
+					if (((field_name == "password") || (field_name == "password_confirm")) && (ElExists("password_required") === true) && (document.getElementById("password_required").value == 1))
+						required_mark_el[i].innerHTML = "*";
+				}
+			}
 		}
-		if((' ' + elems[i].className + ' ').indexOf(' required_box ') > -1) {
-			elems[i].style.visibility = "visible";
+	}
+	
+	// Hide all reqired asterik marks if not using them.
+	if (use_classic_required_field_marks == 0)	{
+		var elems = document.getElementsByTagName('*');
+		var matchClass = "required_mark";
+		for (i in elems) {
+			if((' ' + elems[i].className + ' ').indexOf(' ' + matchClass + ' ') > -1) {
+				if (use_classic_required_field_marks == 0)
+					elems[i].style.display = "none";
+			}
+		}
+	}
+
+	if (document.getElementsByClassName("required_box").length > 0)	{
+		var required_box_el = document.getElementsByClassName("required_box");
+		if (typeof required_box_el[0] !== 'undefined')	{
+			if (use_classic_required_field_marks == 1)
+				required_box_el[0].style.visibility = "hidden";
+			else
+				required_box_el[0].style.visibility = "visible";
+		}
+	}
+	
+	if ((use_classic_required_field_marks > 0) && (document.getElementsByClassName("required_msg").length > 0))	{
+		var required_msg_el = document.getElementsByClassName("required_msg");
+		if (typeof required_msg_el[0] !== 'undefined')	{
+			var required_msg = required_msg_el[0].innerHTML;
+			required_msg = required_msg.replace(/\*/, "");
+			required_msg_el[0].innerHTML = required_msg;
 		}
 	}
 	
@@ -262,7 +337,7 @@ function InitializeForm()
 		}
 		else if (err == "too_short")	{
 			var password_length = ReadGetVar("password_length");
-			if (ElExists("password_length_msg"))
+			if (ElExists("password_length_msg") === true)
 				document.getElementById("password_length_msg").innerHTML = password_length;
 			document.getElementById("ErrTooShort").style.display = "block";
 			document.getElementById("password").focus();
@@ -272,7 +347,7 @@ function InitializeForm()
 		}
 		else if (err == "too_weak") {
 			var password_strength = ReadGetVar("password_strength");
-			if (ElExists("password_strength_msg"))	{
+			if (ElExists("password_strength_msg") === true)	{
 				if (password_strength == "medium")
 					document.getElementById("password_strength_msg").innerHTML = "Please fill in a password contaning both letters and numbers.";
 				else if (password_strength == "strong")
@@ -364,7 +439,7 @@ function InitializeForm()
 //////////////////////////////////////////////////////////////////////////////
 function CheckForm()
 {
-	if (ElExists('required_fields'))
+	if (ElExists('required_fields') === true)
 	{
 		var required_fields_str = document.getElementById("required_fields").value;
 		var required_fields = required_fields_str.split(",");
@@ -376,13 +451,13 @@ function CheckForm()
 		document.getElementById("ErrRequired").style.display = "none";
 		document.getElementById("ErrEmailBlank").style.display = "none";
 		document.getElementById("ErrEmailNoMatch").style.display = "none";
-		if (ElExists('ErrPassBlank'))
+		if (ElExists('ErrPassBlank') === true)
 			document.getElementById("ErrPassBlank").style.display = "none";
-		if (ElExists('ErrPassNoMatch'))
+		if (ElExists('ErrPassNoMatch') === true)
 			document.getElementById("ErrPassNoMatch").style.display = "none";
-		if (ElExists('ErrTooShort'))
+		if (ElExists('ErrTooShort') === true)
 			document.getElementById("ErrTooShort").style.display = "none";
-		if (ElExists('ErrTooWeak'))
+		if (ElExists('ErrTooWeak') === true)
 			document.getElementById("ErrTooWeak").style.display = "none";
 		for (var i = 0; i < required_fields.length; i++)
 		{
@@ -430,8 +505,8 @@ function CheckForm()
 			document.getElementById("ErrRequired").style.display = "block";
 	}
 
-	if (ElExists('email_required') && (document.getElementById("email_required").value == 1))	{
-		if (ElExists('email') && ((document.getElementById('email').value == "") || (document.getElementById('email').value != document.getElementById('email_confirm').value)))	{
+	if ((ElExists('email_required') === true) && (document.getElementById("email_required").value == 1))	{
+		if ((ElExists('email') === true) && ((document.getElementById('email').value == "") || (document.getElementById('email').value != document.getElementById('email_confirm').value)))	{
 			class_name = document.getElementById('email').className;
 			class_name = class_name.replace(" required_field", "");
 			document.getElementById("email").className = class_name + " field_highlight";
@@ -444,12 +519,12 @@ function CheckForm()
 				OKtoSend = false;
 			}
 		}
-		else if (ElExists('email'))	{	// Clear previous highlights.
+		else if (ElExists('email') === true)	{	// Clear previous highlights.
 			class_name = document.getElementById("email").className;
 			class_name = class_name.replace(" field_highlight", "");
 			document.getElementById("email").className = class_name + " required_field";
 		}
-		if (ElExists('email_confirm') && ((document.getElementById('email_confirm').value == "") || (document.getElementById('email').value != document.getElementById('email_confirm').value)))	{
+		if ((ElExists('email_confirm') === true) && ((document.getElementById('email_confirm').value == "") || (document.getElementById('email').value != document.getElementById('email_confirm').value)))	{
 			class_name = document.getElementById('email_confirm').className;
 			class_name = class_name.replace(" required_field", "");
 			document.getElementById("email_confirm").className = class_name + " field_highlight";
@@ -459,15 +534,15 @@ function CheckForm()
 				document.getElementById("ErrEmailNoMatch").style.display = "block";
 			OKtoSend = false;
 		}
-		else if (ElExists('email_confirm'))	{	// Clear previous highlights.
+		else if (ElExists('email_confirm') === true)	{	// Clear previous highlights.
 			class_name = document.getElementById("email_confirm").className;
 			class_name = class_name.replace(" field_highlight", "");
 			document.getElementById("email_confirm").className = class_name + " required_field";
 		}
 	}
 	
-	if (ElExists('password_required') && (document.getElementById("password_required").value == 1))	{
-		if (ElExists('password') && ((document.getElementById('password').value == "") || (document.getElementById('password').value != document.getElementById('password_confirm').value)))	{
+	if ((ElExists('password_required') === true) && (document.getElementById("password_required").value == 1))	{
+		if ((ElExists('password') === true) && ((document.getElementById('password').value == "") || (document.getElementById('password').value != document.getElementById('password_confirm').value)))	{
 			class_name = document.getElementById('password').className;
 			class_name = class_name.replace(" required_field", "");
 			document.getElementById("password").className = class_name + " field_highlight";
@@ -480,12 +555,12 @@ function CheckForm()
 				OKtoSend = false;
 			}
 		}
-		else if (ElExists('password'))	{	// Clear previous highlights.
+		else if (ElExists('password') === true)	{	// Clear previous highlights.
 				class_name = document.getElementById("password").className;
 				class_name = class_name.replace(" field_highlight", "");
 				document.getElementById("password").className = class_name + " required_field";
 			}
-		if (ElExists('password_confirm') && ((document.getElementById('password_confirm').value == "") || (document.getElementById('password').value != document.getElementById('password_confirm').value)))	{
+		if ((ElExists('password_confirm') === true) && ((document.getElementById('password_confirm').value == "") || (document.getElementById('password').value != document.getElementById('password_confirm').value)))	{
 			class_name = document.getElementById('password_confirm').className;
 			class_name = class_name.replace(" required_field", "");
 			document.getElementById("password_confirm").className = class_name + " field_highlight";
@@ -495,14 +570,14 @@ function CheckForm()
 				document.getElementById("ErrPassNoMatch").style.display = "block";
 			OKtoSend = false;
 		}
-		else if (ElExists('password_confirm'))	{	// Clear previous highlights.
+		else if (ElExists('password_confirm') === true)	{	// Clear previous highlights.
 			class_name = document.getElementById("password_confirm").className;
 			class_name = class_name.replace(" field_highlight", "");
 			document.getElementById("password_confirm").className = class_name + " required_field";
 		}
 	}
 	
-	if ((ElExists('password_length')) && (document.getElementById('password_length').value > 0) && (document.getElementById('password').value != ""))
+	if ((ElExists('password_length') === true) && (document.getElementById('password_length').value > 0) && (document.getElementById('password').value != ""))
 	{
 		class_name = document.getElementById('password').className;
 		var password_length = document.getElementById('password_length').value;
@@ -510,10 +585,10 @@ function CheckForm()
 			if (class_name.indexOf("field_highlight") < 0)	{
 				class_name = class_name.replace(" required_field", "");
 				document.getElementById("password").className = class_name + " field_highlight";
-				if (ElExists("password_confirm"))
+				if (ElExists("password_confirm") === true)
 					document.getElementById("password_confirm").className = class_name + " field_highlight";
 			}
-			if (ElExists("password_length_msg"))
+			if (ElExists("password_length_msg") === true)
 				document.getElementById("password_length_msg").innerHTML = password_length;
 			document.getElementById("ErrTooShort").style.display = "block";
 			if (OKtoSend)	{
@@ -523,12 +598,12 @@ function CheckForm()
 		}
 	}
 
-	if ((ElExists('password_strength')) && (document.getElementById('password_strength').value != "") && (document.getElementById('password').value != ""))
+	if ((ElExists('password_strength') === true) && (document.getElementById('password_strength').value != "") && (document.getElementById('password').value != ""))
 	{
 		class_name = document.getElementById('password').className;
 		
 		var password_strength = document.getElementById('password_strength').value;
-		if (ElExists("password_strength_msg"))	{
+		if (ElExists("password_strength_msg") === true)	{
 			if (password_strength == "medium")
 				document.getElementById("password_strength_msg").innerHTML = "Please fill in a password contaning both letters and numbers.";
 			else if (password_strength == "strong")
@@ -539,7 +614,7 @@ function CheckForm()
 			if  (class_name.indexOf("field_highlight") < 0)	{
 				class_name = class_name.replace(" required_field", "");
 				document.getElementById("password").className = class_name + " field_highlight";
-				if (ElExists("password_confirm"))
+				if (ElExists("password_confirm") === true)
 					document.getElementById("password_confirm").className = class_name + " field_highlight";
 			}
 			document.getElementById("ErrTooWeak").style.display = "block";
