@@ -1,12 +1,12 @@
 <?php
-// FormMailer, copyright 2007-2018, Silver Dolphin Solutions, LLC, Ed Lemmers
+// FormMailer, copyright 2007-2020, Silver Dolphin Solutions, LLC, Ed Lemmers
 // For licensing, see license.txt.
 //
-// This module may be customized to your needs, however, the design is intended to cover all
-// form mailing needs without modification by directing this module through hidden fields
-// from within your form.  Having said that, we know there will always be something else that
-// is required, but we think this module should do a good job of handling most situations
-// without modification.
+// It is highly recommended not to modify this file.  You should be able to control about anything using
+// pre-defined hidden fields in your form.  Check out the Breeze Website Builder documentation for more information.
+// If you do need to build a custom form processing module, consider building your own module to do what it needs
+// to do and adding hidden-field formmail_addon for including it in this module.
+//
 error_reporting (E_ALL ^ E_NOTICE);
 
 if ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != ""))	{
@@ -15,6 +15,13 @@ if ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"]
 	ini_set('memory_limit','512M');
 	ini_set('post_max_size','128M');
 }
+// DB connection for retrieving HTML message format for message back to inquirer, etc.
+include_once("connect_finder.php");
+// Module for performaing actual email operation.
+include("mime_mail.inc");
+include("clean_var.php");
+// List of key fields to ignore (not customer data, but rather configuration hidden fields).
+include("ignore_fields.php");
 
 // Modify the line below for your particular website.  This will eliminate attacks from remote servers.
 //$referers = array('www.example.com', 'example.com');
@@ -22,28 +29,6 @@ $server_name = $_SERVER['SERVER_NAME'];
 $server_name_www = "www." . $server_name;
 $referers = array($server_name_www, $server_name);
 
-// Module for performaing actual email operation.
-include("mime_mail.inc");
-// DB connection for retrieving HTML message format for message back to inquirer, etc.
-$doc_root = $_SERVER['DOCUMENT_ROOT'];
-if (file_exists("../connect/config.php"))	// Default installation
-	$connect_path = "../connect/";
-elseif (file_exists($doc_root . "/connect/config.php"))	// Custom userfile folders
-	$connect_path = $doc_root . "/connect/";
-else	{	// Must be installeed in sub domain or sub folder with non-standard userfile folders.
-	$php_self = $_SERVER["PHP_SELF"];
-	$self_parts = explode('/', $php_self);
-	$this_script = $self_parts[count($self_parts) - 1];
-	$sub_dir = str_replace(array($doc_root, $this_script), "", $php_self);
-	$sub_dir_parts = explode('/', $sub_dir);
-	$connect_path = $doc_root . '/' . $sub_dir_parts[0] . "/connect/";
-}
-include($connect_path . "config.php");
-include($connect_path . "db_connect.php");
-include("clean_var.php");
-// List of key fields to ignore (not customer data, but rather configuration hidden fields).
-include("ignore_fields.php");
-
 // If alternate go back specified, then use that if any errors.  This is usefule if sending page session expires if back button is used.
 if ($_POST['alt_go_back'])
 {
@@ -103,6 +88,10 @@ $stmt->execute(array(':page_name' => $page_name));
 if ($stmt->rowCount() > 0)	{
 	$row = $stmt->fetch(PDO::FETCH_ASSOC, PDO::FETCH_ORI_NEXT);
 	$recipient = $row['recipient'];
+	if ((!isset($recipient) || ($recipient == "")) && isset($_POST['recipient']) && ($_POST['recipient'] != ""))	{
+		$recipient = $_POST['recipient'];
+		$recipient = str_replace("+++++", "@", $recipient);
+	}
 }
 else	{
 	$recipient = $_POST['recipient'];
@@ -166,6 +155,10 @@ $email_confirm = trim($_POST['email_confirm']);
 $password	= trim($_POST['password']);
 $password_confirm = trim($_POST['password_confirm']);
 $use_email_as_userid = $_POST['use_email_as_userid'];
+if ((!isset($password) || ($password == "")) && (!isset($password_confirm) || ($password_confirm == "")) && isset($_POST['password_generated']) && ($_POST['password_generated'] != ""))	{
+	$password	= trim($_POST['password_generated']);
+	$password_confirm = $password;
+}
 
 // If email required flag is sent, then verify that 'email' has been filled in and 'email_confirm'
 // matches 'email'.
@@ -251,7 +244,7 @@ if ($_POST['use_captcha'])
 	
 	if (!isset($_POST['captcha_type']) || ($_POST['captcha_type'] == "recaptcha"))
 	{
-	  include($connect_path . "captchakeys.php");
+	  include($connect_path . $connect_dir . "/captchakeys.php");
 	  require_once('recaptchalib.php');
 	  $resp = recaptcha_check_answer (RECAPTCHA_PRIVATE_KEY,
 									$_SERVER["REMOTE_ADDR"],
@@ -263,7 +256,7 @@ if ($_POST['use_captcha'])
 	}
 	elseif ($_POST['captcha_type'] == "recaptcha2")
 	{
-		include($connect_path . "captchakeys.php");
+		include($connect_path . $connect_dir . "/captchakeys.php");
 		require_once('recaptchalib2.php');
 		// The response from reCAPTCHA
 		$resp = null;
@@ -286,7 +279,7 @@ if ($_POST['use_captcha'])
 	elseif ($_POST['captcha_type'] == "mollom")	// Requires acquisition of public and private keys from http://mollom.com
 	{
 		require_once("mollom.php");
-		include($connect_path . "captchakeys.php");
+		include($connect_path . $connect_dir . "/captchakeys.php");
 		
 		$captcha_response_field = $_POST['captcha_response_field'];
 		$mollom_session = $_POST['mollom_session'];
@@ -322,7 +315,15 @@ if ($_POST['use_captcha'])
 	}
 }
 ///////////////////////////////////////
+// Provided as a method to add plugin funtionality not covered by this form processor.
+// Note: The module specified by formmail_addon must be in the same folder as this module.
+$formmail_addon = $_POST['formmail_addon'];
+if (strpos($formmail_addon,"/") !== false)
+	$formmail_addon = substr($formmail_addon, strrpos($formmail_addon,"/") + 1);
+if (file_exists($formmail_addon))
+	include_once($formmail_addon);
 
+///////////////////////////////////////
 // In many instances, it is desirable to use the email address as the user ID.
 if (isset($use_email_as_userid))
 	$_POST['UserID'] = $email;
@@ -563,8 +564,9 @@ if (isset($table_name) && ($table_name != ""))
 				}
 			}
 		}
-		// Add created field.
+		// Add created and modified fields.
 		$query .= "`created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, ";
+		$query .= "`modified` TIMESTAMP on update CURRENT_TIMESTAMP NULL, ";
 		// Add primary key.
 		$query .= "PRIMARY KEY  (`id`) )";
 		$cnt = $bwb_dbh->exec($query);
@@ -782,7 +784,7 @@ if (isset($table_name) && ($table_name != ""))
 				$cnt = $bwb_dbh->exec($query);
 				
 				// Account activated, now go ahead and log in.
-				session_start();
+//				session_start();
 				if (isset($_POST['UserID']))
 					$userid = $_POST['UserID'];
 				elseif (isset($_POST['userid']))
@@ -926,7 +928,7 @@ function check_referer($referers)
 		if (getenv('HTTP_REFERER')) {
 			$temp = explode('/', getenv('HTTP_REFERER'));
 			$found = false;
-			while (list(,$stored_referer) = each($referers)) {
+			foreach ($referers as $stored_referer)	{
 				if (preg_match('/^' . $stored_referer . '$/i', $temp[2]))
 					$found = true;
 			}
@@ -988,6 +990,7 @@ function doEncrypt($Data, $Key)
 // k[] = key of truly random gibberish
 // e[] = encrypted data
 
+	$Key = strtolower($Key);
 	for( $i = 0; $i < strlen($Data); $i++)
 	{
 		$c = substr($Data, $i, 1);
