@@ -34,14 +34,14 @@ window.parent.document.title = document.title;
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#sitemap", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open("<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#sitemap", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 </script>
 </head>
 
 <body>
 <div id="sub_level_1_buttons">
-	<div class="button_heading_sub_level_1" id="generate_site_map_heading"><div class="button_heading_text_sub_level_1"><?php echo GENERATE_SITE_MAP_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+	<div class="button_heading_sub_level_1" id="generate_site_map_heading"><div class="button_heading_text_sub_level_1"><?php echo GENERATE_SITE_MAP_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
     
     <p><?php echo GENERATE_SITE_MAP_GENERATING; ?></p>
     <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
