@@ -4,12 +4,14 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 11/12/2015
+// Modified: 11/26/2019	ELL
+// Added specification of columns to be returned to reduce query speed and improve reliability by avoiding dealing with page data.
 	
 	include ("check_session.php");
 	
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
 	
-	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
+	$query = "SELECT page_name, template, head_name, header_name, top_name, left_name, right_name, bottom_name, footer_name, active FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
 	$result = $bwb_dbh->query($query);
 	
 	if ($result->rowCount() < 1)
