@@ -4,12 +4,14 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 10/19/2014	ELL
+// Revised: 11/10/2016	ELL
+// Modified custom CSS editing to allow for any number of custom CSS records associated with custom style sheets.
 
 	include ("check_session.php");
 	
-	$custom_site_css_table = $_REQUEST['custom_site_css_table'];
+	$style_sheet = $_REQUEST['style_sheet'];
 	
-	$query = "SELECT page_content, revised FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$custom_site_css_table' AND `source`=3";
+	$query = "SELECT page_content, revised FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$style_sheet' AND `source`=3";
 	$result = $bwb_dbh->query($query);
 	if ($result->rowCount() > 0)
 	{
@@ -18,7 +20,7 @@
 	}
 	else
 	{
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $custom_site_css_table . "`";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "custom_site_css` WHERE `name` = '" . $style_sheet . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		if ($row["custom_css"])
@@ -29,7 +31,7 @@
 	
 	// Before we go any farther, back this puppy up!
 	$revised = $row['revised'];
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$custom_site_css_table', page_content=:custom_css, revised='$revised', source=3";
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$style_sheet', page_content=:custom_css, revised='$revised', source=3";
 	$stmt = $bwb_dbh->prepare($query);
 	$stmt->execute(array(':custom_css' => $custom_css));
 		
