@@ -14,10 +14,11 @@ if(!defined('KFM_BASE_PATH'))define('KFM_BASE_PATH', dirname(__FILE__).'/');
 if(function_exists("date_default_timezone_set") && function_exists("date_default_timezone_get"))@date_default_timezone_set(date_default_timezone_get());
 
 // { load classes and helper functions
-if(!function_exists('__autoload')){
-	function __autoload($class_name) {
+if (!function_exists('KFMAutoloader'))	{
+	function KFMAutoloader($class_name)	{
 		require_once KFM_BASE_PATH . 'classes/' . $class_name . '.php';
 	}
+	spl_autoload_register('KFMAutoloader');	
 }
 require KFM_BASE_PATH.'includes/lang.php';
 require KFM_BASE_PATH.'includes/db.php';
