@@ -12,6 +12,8 @@
 // Modified: 10/6/2017	ELL
 // Fixed bug with sub categories that have no plugins display div of next sub category.
 // Added message on where to get plugins when category or sub category contions no plugin.
+// Modified: 11/26/2019	ELL
+// Added visual indication of inactive pages.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -20,7 +22,7 @@ window.parent.document.title = document.title;
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#install_plugin_into_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#install_plugin_into_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function ElExists(el)
@@ -37,13 +39,22 @@ function SelectPage(page_name, i)
 	
 	var page_name_select_ctl = "";
 	var page_cnt = document.getElementById('page_cnt').value;
+	var old_class;
 	for (var n = 0; n <page_cnt; n++)
 	{
 		page_name_select_ctl = "page_name_select" + n;
-		document.getElementById(page_name_select_ctl).className = "button_sub_level_1";
+		old_class = document.getElementById(page_name_select_ctl).className;
+		if (old_class.indexOf("_disabled") > 0)
+			document.getElementById(page_name_select_ctl).className = "button_sub_level_1 button_sub_level_1_disabled";
+		else
+			document.getElementById(page_name_select_ctl).className = "button_sub_level_1";
 	}
 	page_name_select_ctl = "page_name_select" + i;
-	document.getElementById(page_name_select_ctl).className = "button_sub_level_1 down_sub";
+	old_class = document.getElementById(page_name_select_ctl).className;
+	if (old_class.indexOf("1_disabled") > 0)
+		document.getElementById(page_name_select_ctl).className = "button_sub_level_1 1_disabled down_sub";
+	else
+		document.getElementById(page_name_select_ctl).className = "button_sub_level_1 down_sub";
 	
 	document.getElementById('selected_page').innerHTML = "<b><em>" + page_name + "</em></b> " + ADD_PLUGIN_TO_PAGE_PAGE_SELECTED;
 	CheckForm();
