@@ -53,10 +53,11 @@ function ajaxUpload(form,url_action,id_element,html_show_loading,html_error_http
 		$m(id_element).innerHTML = html_error_http;
 		$m('ajax-temp').src = cross;
 		if(detectWebKit){
-        	remove($m('ajax-temp'));
+// Must have been for older browser versions.  Commenting this out fixes this in Chrome.
+//  	     	remove($m('ajax-temp'));
         }else{
         	setTimeout(function(){ remove($m('ajax-temp'))}, 250);
-        }
+       }
     }
 	addEvent($m('ajax-temp'),"load", doUpload);
 	form.setAttribute("target","ajax-temp");
