@@ -34,7 +34,7 @@ var copy_rename_mode = "copy";
 
 function OpenHelpWindow(topic)
 {
-	var help_url = "http://breezewebsitebuilder.com/docs/cms/help.html#" + topic;
+	var help_url = http + "breezewebsitebuilder.com/docs/cms/help.html#" + topic;
 	window.open(help_url, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
