@@ -13,7 +13,7 @@ var version_file;
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#dashboard", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#dashboard", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function ShowUpdatePopup(version_from_file)
