@@ -11,7 +11,7 @@ window.parent.document.title = document.title;
 
 function OpenHelpWindow(topic)
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
