@@ -21,8 +21,8 @@ function  LoadOrientationDefaults(orientation)
 	{
 		if (load_defaults == 1)	{
 			document.getElementById("menu_width").value = -1;
-			document.getElementById("sub_level_offset_top").value = -5;
-			document.getElementById("sub_level_offset_left").value = 80;	
+			document.getElementById("sub_level_1_offset_top").value = -5;
+			document.getElementById("sub_level_1_offset_left").value = 80;
 		}
 		document.getElementById("menu_width").disabled = true;
 		document.getElementById("menu_width_units").disabled = true;
@@ -32,8 +32,8 @@ function  LoadOrientationDefaults(orientation)
 		if (load_defaults == 1)	{
 			document.getElementById("menu_width").value = 100;
 			document.getElementById("menu_width_units").value = 1;
-			document.getElementById("sub_level_offset_top").value = 0;
-			document.getElementById("sub_level_offset_left").value = 20;
+			document.getElementById("sub_level_1_offset_top").value = 0;
+			document.getElementById("sub_level_1_offset_left").value = 20;
 		}
 		document.getElementById("menu_width").disabled = false;
 		document.getElementById("menu_width_units").disabled = false;
@@ -42,8 +42,8 @@ function  LoadOrientationDefaults(orientation)
 	{
 		if (load_defaults == 1)	{
 			document.getElementById("menu_width").value = -1;
-			document.getElementById("sub_level_offset_top").value = 0;
-			document.getElementById("sub_level_offset_left").value = 20;
+			document.getElementById("sub_level_1_offset_top").value = 0;
+			document.getElementById("sub_level_1_offset_left").value = 20;
 		}
 		document.getElementById("menu_width").disabled = true;
 		document.getElementById("menu_width_units").disabled = true;
@@ -52,7 +52,7 @@ function  LoadOrientationDefaults(orientation)
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_css_menu_params", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#edit_css_menu_params", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function PreloadLocationDefaults(location)
@@ -377,9 +377,9 @@ function CompleteSaveMenuParams(response)
 
 function TextFieldClick(el)
 {
-	if (el.value == _NOT_SET_)	{
+	if (el.value.indexOf(_NOT_SET_) > -1)	{
 		el.value = "";
-		el.className = "";
+		el.className = el.className.replace("not_set", "");
 	}
 }
 function TextFieldChange(el)
@@ -390,7 +390,10 @@ function TextFieldBlur(el)
 {
 	if (el.value == "")	{
 		el.value = _NOT_SET_;
-		el.className = "not_set";
+		if (el.className == "")
+			el.className = "not_set";
+		else
+			el.className = el.className + " not_set";
 	}
 }
 
