@@ -13,6 +13,11 @@
 // Added ability to style button down states as well as complete implementation of background and item border colors in hover and active states.
 // Revised: 9/12/2017	ELL
 // Added ability to turn on or off text shadow for any of normal, hover and down states independently selectable in all 3 levels.
+// Revised: 3/26/2018	ELL
+// Replaced font select dropdowns with custom-built select comprised of divs, JavaScript and CSS for the display of font face both upon reviewing select and after selection.
+// Added color feedback to all color selects.
+// Revised: 4/16/2018	ELL
+// Improved color text-box background and foreground color handling.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -45,7 +50,7 @@ function popupcolorpicker(form_name, field_name, top_offset)
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_css_menu_styles", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#edit_css_menu_styles", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function CheckLetterSpacing(element, letter_spacing_el_id)
@@ -254,7 +259,8 @@ function InitializeForm()
 	CheckFormatOnUnitSelect("sub_level_2_letter_spacing_down_units", "sub_level_2_letter_spacing_down", 0);
 	
 	CheckFormatOnUnitSelect("top_level_block_border_units", "top_level_block_border_width", 0);
-	CheckFormatOnUnitSelect("sub_level_block_border_units", "sub_level_block_border_width", 0);
+	CheckFormatOnUnitSelect("sub_level_1_block_border_units", "sub_level_1_block_border_width", 0);
+	CheckFormatOnUnitSelect("sub_level_2_block_border_units", "sub_level_2_block_border_width", 0);
 	CheckFormatOnUnitSelect("top_level_item_border_units", "top_level_item_border_width", 0);
 	CheckFormatOnUnitSelect("sub_level_1_item_border_units", "sub_level_1_item_border_width", 0);
 	CheckFormatOnUnitSelect("sub_level_2_item_border_units", "sub_level_2_item_border_width", 0);
@@ -462,14 +468,25 @@ function InitializeForm()
 		document.getElementById("top_level_block_border_width").className = "not_set";
 	else
 		document.getElementById("top_level_block_border_width").className = "";
-	if (document.getElementById("sub_level_block_border_color").value == _NOT_SET_)
-		document.getElementById("sub_level_block_border_color").className = "not_set";
+		
+	if (document.getElementById("sub_level_1_block_border_color").value == _NOT_SET_)
+		document.getElementById("sub_level_1_block_border_color").className = "not_set";
 	else
-		document.getElementById("sub_level_block_border_color").className = "";
-	if (document.getElementById("sub_level_block_border_width").value == _NOT_SET_)
-		document.getElementById("sub_level_block_border_width").className = "not_set";
+		document.getElementById("sub_level_1_block_border_color").className = "";
+	if (document.getElementById("sub_level_1_block_border_width").value == _NOT_SET_)
+		document.getElementById("sub_level_1_block_border_width").className = "not_set";
 	else
-		document.getElementById("sub_level_block_border_width").className = "";
+		document.getElementById("sub_level_1_block_border_width").className = "";
+		
+	if (document.getElementById("sub_level_2_block_border_color").value == _NOT_SET_)
+		document.getElementById("sub_level_2_block_border_color").className = "not_set";
+	else
+		document.getElementById("sub_level_2_block_border_color").className = "";
+	if (document.getElementById("sub_level_2_block_border_width").value == _NOT_SET_)
+		document.getElementById("sub_level_2_block_border_width").className = "not_set";
+	else
+		document.getElementById("sub_level_2_block_border_width").className = "";
+		
 	if (document.getElementById("top_level_item_border_color").value == _NOT_SET_)
 		document.getElementById("top_level_item_border_color").className = "not_set";
 	else
@@ -837,9 +854,11 @@ function CheckItemBorder(is_checked, level)
 
 function TextFieldClick(el)
 {
-	if (el.value == _NOT_SET_)	{
+	if (el.value.indexOf(_NOT_SET_) > -1)	{
 		el.value = "";
-		el.className = "";
+		el.className = el.className.replace("not_set", "");
+		el.style.color = "";
+		el.style.backgroundColor = "";
 	}
 }
 function TextFieldChange(el)
@@ -850,7 +869,12 @@ function TextFieldBlur(el)
 {
 	if (el.value == "")	{
 		el.value = _NOT_SET_;
-		el.className = "not_set";
+		if (el.className == "")
+			el.className = "not_set";
+		else
+			el.className = el.className + " not_set";
+		el.style.color = "";
+		el.style.backgroundColor = "";
 	}
 }
 
