@@ -13,8 +13,11 @@
 // Added handling of mega menus.
 // Revised: 4/13/2017	ELL
 // Added code to update HTML on every change because JavaScript ignores form entry.
+// Revised: 7/3/2019	ELL
+// Overhauled to use jQuery AJAX instead of pure JavaScript to eliminate bugs and make easier to troubleshoot.
+// Modified: 11/26/2019	ELL
+// Added visual indication of inactive pages.
 //
-
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
@@ -36,7 +39,16 @@ function Indent(level)
 ////////////////////////////////////////////////////////////////////////////////////////////
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_menu_items", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#edit_menu_items", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////
+function ElExists(el)
+{
+	if ((document.getElementById(el) != null) && (typeof document.getElementById(el) != "undefined"))
+		return true;
+	else
+		return false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////
@@ -51,11 +63,11 @@ function DeleteConfirm(item_text, ID, i)
 	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
-	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenuItem(ID); };
+	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenuItem(ID, item_text); };
 	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
-function DeleteMenuItem(IDRemove)
+function DeleteMenuItem(IDRemove, item_text)
 {
 	var params = "";
 
@@ -69,20 +81,20 @@ function DeleteMenuItem(IDRemove)
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
 	
-	var xmlhttp;
-	xmlhttp = getXmlHttpRequestObject();
-
-	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
-	{
-		xmlhttp.open("POST","delete_menu_item.php",true);
-		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "Delete");
-		
-		params = "menu=" + document.getElementById("selectMenu").value;
-		params = params + "&IDRemove=" + IDRemove;
-//		alert(params);
-		xmlhttp.send(params);
-	}
+	var menu = document.getElementById("selectMenu").value;
+	
+	$.post( "delete_menu_item.php", { menu: menu, IDRemove: IDRemove } ).done(function( data ) { CompleteDeleteMenuItem(data, item_text); } ) ;
+}
+function CompleteDeleteMenuItem(data, item_text)
+{
+	if (data > 0)
+		popup_msg.status_msg = EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG;
+	else
+		popup_msg.status_msg = EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG;
+	popup_msg.popup_timeout = 2000;
+	popup_msg.ShowPopupMsg();
+	
+	RetrieveMenuItems();
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -103,6 +115,8 @@ function UpdateMenuItem(ID, i)
 	var sort_order_ctl = "sort_order" + i;
 	var item_text = "";
 	var URL = "";
+	var menu, target, mega_menu, sort_order;
+	var level = 0;
 	
 	if (ID == -1)
 		unsaved_new_item = false;
@@ -114,32 +128,26 @@ function UpdateMenuItem(ID, i)
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
 	
-	var xmlhttp;
-	xmlhttp = getXmlHttpRequestObject();
-
-	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
-	{
-		xmlhttp.open("POST","update_menu_item.php",true);
-		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "Update");
-		
-		// Escape URL string
-		item_text = document.getElementById(item_text_ctl).value;
-		item_text = EscapeURL(item_text);
-		URL = document.getElementById(URL_ctl).value;
-		URL = EscapeURL(URL);
-		
-		params = "menu=" + document.getElementById("selectMenu").value;
-		params = params + "&ID=" + ID;
-		params = params + "&item_text=" + item_text;
-		params = params + "&level=" + document.getElementById(level_ctl).value;
-		params = params + "&URL=" + URL;
-		params = params + "&target=" + document.getElementById(target_ctl).value;
-		params = params + "&mega_menu=" + document.getElementById(mega_menu_ctl).value;
-		params = params + "&sort_order=" + document.getElementById(sort_order_ctl).value;
-		//alert(params);
-		xmlhttp.send(params);
-	}
+	menu = document.getElementById("selectMenu").value;
+	item_text = document.getElementById(item_text_ctl).value;
+	item_text = EscapeURL(item_text);
+	level = document.getElementById(level_ctl).value;
+	URL = document.getElementById(URL_ctl).value;
+	URL = EscapeURL(URL);
+	target = document.getElementById(target_ctl).value;
+	mega_menu = document.getElementById(mega_menu_ctl).value;
+	sort_order = document.getElementById(sort_order_ctl).value;
+	
+	$.post( "update_menu_item.php", { menu: menu, ID: ID, item_text: item_text, level: level, URL: URL, target: target, mega_menu: mega_menu, sort_order: sort_order  } ).done(function( data ) { CompleteUpdateMenuItem(data, item_text); } ) ;
+}
+function CompleteUpdateMenuItem(data, item_text)
+{
+	if (data == "Update complete")
+		popup_msg.status_msg = EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG;
+	else
+		popup_msg.status_msg = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG;
+	popup_msg.popup_timeout = 2000;
+	popup_msg.ShowPopupMsg();
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -155,6 +163,8 @@ function UpdateAll()
 	var sort_order_ctl;
 	var item_text;
 	var URL;
+	
+	document.getElementById("nCount").value = nCount;
 
 	popup_msg.popup_msg_type = 1;
 	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
@@ -163,105 +173,23 @@ function UpdateAll()
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
 	
-	var xmlhttp;
-	xmlhttp = getXmlHttpRequestObject();
-
-	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
-	{
-		xmlhttp.open("POST","save_menu_items.php",true);
-		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "UpdateAll");
-		
-		params = "menu=" + document.getElementById("selectMenu").value;
-		var cnt = document.getElementById("nCount").value;
-		params = params + "&cnt=" + cnt;
-		for (i = 0; i < cnt; i++)
-		{
-			ID_ctl = "ID" + i;
-			item_text_ctl = "item_text" + i;
-			level_ctl = "level" + i;
-			URL_ctl = "URL" + i;
-			target_ctl = "target" + i;
-			mega_menu_ctl = "mega_menu" + i;
-			sort_order_ctl = "sort_order" + i;
-			
-			params = params + "&ID" + i + "=" + document.getElementById(ID_ctl).value;
-			// Escape URL string
-			item_text = document.getElementById(item_text_ctl).value;
-			item_text = EscapeURL(item_text);
-			params = params + "&item_text" + i + "=" + item_text;
-			params = params + "&level" + i + "=" + document.getElementById(level_ctl).value;
-			URL = document.getElementById(URL_ctl).value;
-			URL = EscapeURL(URL);
-			params = params + "&URL" + i + "=" + URL;
-			params = params + "&target" + i + "=" + document.getElementById(target_ctl).value;
-			params = params + "&mega_menu" + i + "=" + document.getElementById(mega_menu_ctl).value;
-			params = params + "&sort_order" + i + "=" + document.getElementById(sort_order_ctl).value;
-		}
-//		alert(params);
-		xmlhttp.send(params);
-	}
-	unsaved_new_item = false;
-	window.parent.SetWorkSavedNotSaved(true);
+	$.ajax({type:'POST', url: 'save_menu_items.php', data:$('#frmMenuItems').serialize(), success: function(response) {
+		CompleteUpdateAll(response);
+	}});
 }
-
-//////////////////////////////////////////////////////////////////////////////////////
-function UpdateMessage(xmlhttp, Source)
+function CompleteUpdateAll(response)
 {
-	var query_complete_no_record = QUERY_COMPLETE_NO_RECORD_FOUND;
-	var query_complete = "<b>" + QUERY_COMPLETE + "<\/b><br/>\n";
-	var query_read_to_send = QUERY_READY_TO_SEND;
-	var query_sent = QUERY_SENT;
-	var query_starting = EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG;
-	if (Source == "Delete")
-	{
-		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG;
-		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG + "<\/b><br/>\n";
-		query_starting = EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG;
-	}
-	else if (Source == "Update")
-	{
-		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG;
-		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG + "<\/b><br/>\n";
-		query_starting = EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG;
-	}
-	else if (Source == "UpdateAll")
-	{
-		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG;
-		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG + "<\/b><br/>\n";
-		query_starting = EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG;
+	if (response == "Update all complete")	{
+		popup_msg.status_msg = EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG;
+		unsaved_new_item = false;
+		window.parent.SetWorkSavedNotSaved(true);
 	}
+	else
+		popup_msg.status_msg = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG;
+	popup_msg.popup_timeout = 2000;
+	popup_msg.ShowPopupMsg();
 	
-	xmlhttp.onreadystatechange=function()
-	{
-		if (xmlhttp.readyState==4)
-		{
-			if (xmlhttp.responseText.length > 0)
-			{
-				var rows_str = xmlhttp.responseText;
-//				alert(rows_str);
-				if (rows_str == "-no data-")
-					popup_msg.status_msg = query_complete_no_record;
-				else
-					popup_msg.status_msg = query_complete;
-				if ((Source == "Populate") || (Source == "Delete") || (Source == "UpdateAll"))
-					PopulateTable(rows_str);
-			}
-			else
-				popup_msg.status_msg = query_complete_no_record;
-
-			popup_msg.popup_timeout = 2000;
-		}
-		else if (xmlhttp.readyState==1)
-			popup_msg.status_msg = query_read_to_send;
-		else if (xmlhttp.readyState==2)
-			popup_msg.status_msg = query_sent;
-		else if (xmlhttp.readyState==3)
-			popup_msg.status_msg = query_starting;
-			
-		popup_msg.ShowPopupMsg();
-	}
-	return (xmlhttp);
+	RetrieveMenuItems();
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
@@ -282,9 +210,9 @@ function AddMenuItem(i)
 	unsaved_new_item = true;
 	
 	var html = document.getElementById("MenuItemsTable").innerHTML;
-	var cnt = parseInt(document.getElementById("nCount").value);
+	var cnt = parseInt(nCount);
 	var d = 0;
-	var srch_str;
+	var srch_str, active_str;
 	
 	if ((browser == "Explorer") && (browser_version < 9))
 		srch_str = "<TR id=row" + i;
@@ -303,10 +231,10 @@ function AddMenuItem(i)
 	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='-1'>\n";
-	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='' onchange=\"SetElementValue('item_text" + i + "', -1);\" onmouseout=\"SetElementVal('item_text" + i + "');\" onkeypress=\"SetCurrentItem('item_text" + i + "', -1);\"><\/td>\n";
+	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='' /><\/td>\n";
 		
 	new_row = new_row + "<td>\n";
-	new_row = new_row + "<input type='hidden' id='level" + i + "' value='' />\n";
+	new_row = new_row + "<input type='hidden' name='level" + i + "' id='level" + i + "' value='' />\n";
 	new_row = new_row + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_TOP_LEVEL + "<\/span>\n";
 	new_row = new_row + "<\/td>\n";
 	
@@ -315,10 +243,13 @@ function AddMenuItem(i)
 	new_row = new_row + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 	for (var k = 0; k < page_cnt; k++)
 	{
-		new_row = new_row + "<option value='" + pages[k] + "'>" + pages[k] + "<\/option>\n";
+		active_str = "";
+		if (active[k] < 1)
+			active_str = " (" + INACTIVE_WORD + ")";
+		new_row = new_row + "<option value='" + pages[k] + "'>" + pages[k] + active_str + "<\/option>\n";
 	}
 	new_row = new_row + "<\/select>\n";
-	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='' onchange=\"SetElementValue('URL" + i + "', -1);\"><\/td>\n";
+	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='' /><\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
 	new_row = new_row + "<select name='target_select" + i + "' id='target_select" + i + "' onChange=\"PopulateTarget(" + i + ");\">\n";
@@ -329,7 +260,7 @@ function AddMenuItem(i)
 	new_row = new_row + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
-	new_row = new_row + "<select name='mega_menu" + i + "' id='mega_menu" + i + "' onchange=\"SetElementValue(-1, 'mega_menu" + i + "');\">\n";
+	new_row = new_row + "<select name='mega_menu" + i + "' id='mega_menu" + i + "'>\n";
 	new_row = new_row + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 	for (var k = 0; k < mega_menu_cnt; k++)
 	{
@@ -439,8 +370,7 @@ function AddMenuItem(i)
 	}
 	html = html_top + new_row + html_bottom;
 	document.getElementById("MenuItemsTable").innerHTML = html;
-	cnt++;
-	document.getElementById("nCount").value = cnt;
+	nCount = cnt + 1;
 	
 	if (n > 0)
 	{
@@ -489,17 +419,8 @@ function RetrieveMenuItems()
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
 	
-	var xmlhttp;
-	xmlhttp = getXmlHttpRequestObject();
-
-	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
-	{
-		xmlhttp.open("POST","populate_menu_items.php",true);
-		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "Populate");
-		var params = "menu=" + document.getElementById("selectMenu").value;
-		xmlhttp.send(params);
-	}
+	var menu = document.getElementById("selectMenu").value;
+	$.post( "populate_menu_items.php", { menu: menu } ).done(function( data ) { PopulateTable(data); } ) ;
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -508,7 +429,7 @@ function PopulateTable(rows_str)
 	var rows = new Array();
 	var fields = new Array();
 	var d = 0;
-	var tmp;
+	var tmp, active_str;
 	
 	var output_str = "<table width='90%' align='center'>\n";
 	output_str = output_str + "<tr bgcolor='#CCCCCC' class='header_row'>\n";
@@ -525,10 +446,18 @@ function PopulateTable(rows_str)
 	output_str = output_str + "<\/tr>\n";
 	
 	rows = rows_str.split("@@@@@");
-	if (rows[0] == "-no data-")	// If no menu items yet (first time).
+	if (rows[0] == "-no data-")	{	// If no menu items yet (first time).
 		var i = 0;
+		popup_msg.status_msg = QUERY_COMPLETE_NO_RECORD_FOUND;
+		popup_msg.popup_timeout = 2000;
+		popup_msg.ShowPopupMsg();
+	}
 	else	// Create rows for menu items.
 	{
+		popup_msg.status_msg = QUERY_COMPLETE;
+		popup_msg.popup_timeout = 1000;
+		popup_msg.ShowPopupMsg();
+		
 		for (var i in rows)
 		{
 			var JSON_row = JSON.parse(rows[i]);
@@ -544,10 +473,10 @@ function PopulateTable(rows_str)
 			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 				
 			output_str = output_str + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='" + JSON_row.ID + "'>\n";
-			output_str = output_str + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='" + Indent(JSON_row.level) + JSON_row.item_text + "' onchange=\"SetElementValue('item_text" + i + "', -1);\" onmouseout=\"SetElementVal('item_text" + i + "');\" onkeypress=\"SetCurrentItem('item_text" + i + "', -1);\"><\/td>\n";
+			output_str = output_str + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='" + Indent(JSON_row.level) + JSON_row.item_text + "' /><\/td>\n";
 				
 			output_str = output_str + "<td>\n";
-			output_str = output_str + "<input type='hidden' id='level" + i + "' value='" + JSON_row.level + "' />\n";
+			output_str = output_str + "<input type='hidden' name='level" + i + "' id='level" + i + "' value='" + JSON_row.level + "' />\n";
 			if ((JSON_row.level == 0) || !JSON_row.level)
 				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_TOP_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 1)
@@ -568,14 +497,17 @@ function PopulateTable(rows_str)
 			
 			for (var j = 0; j < page_cnt; j++)
 			{
+				active_str = "";
+				if (active[j] < 1)
+					active_str = " (" + INACTIVE_WORD + ")";
 				if (pages_full[j] == JSON_row.URL)
-					output_str = output_str + "<option value='" + pages[j] + "' selected='selected'>" + pages[j] + "<\/option>\n";
+					output_str = output_str + "<option value='" + pages[j] + "' selected='selected'>" + pages[j] + active_str + "<\/option>\n";
 				else
-					output_str = output_str + "<option value='" + pages[j] + "'>" + pages[j] + "<\/option>\n";
+					output_str = output_str + "<option value='" + pages[j] + "'>" + pages[j] + active_str + "<\/option>\n";
 			}
 			output_str = output_str + "<\/select>\n";
 			
-			output_str = output_str + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='" + JSON_row.URL + "' onchange=\"SetElementValue('URL" + i + "', -1);\"><\/td>\n";
+			output_str = output_str + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='" + JSON_row.URL + "' /><\/td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n";
 			output_str = output_str + "<select name='target_select" + i + "' id='target_select" + i + "' onChange=\"PopulateTarget(" + i + ");\">\n";
@@ -600,7 +532,7 @@ function PopulateTable(rows_str)
 				output_str = output_str + "<input type='text' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
 				
 			output_str = output_str + "<td valign='top'>\n";
-			output_str = output_str + "<select name='mega_menu" + i + "' id='mega_menu" + i + "' onchange=\"SetElementValue(-1, 'mega_menu" + i + "');\">\n";
+			output_str = output_str + "<select name='mega_menu" + i + "' id='mega_menu" + i + "'>\n";
 			output_str = output_str + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 			for (var k = 0; k < mega_menu_cnt; k++)
 			{
@@ -639,14 +571,14 @@ function PopulateTable(rows_str)
 	else
 		bgclr = "#dddddd";
 	output_str = output_str + "<tr id=\"row" + i + "\" bgcolor='" + bgclr + "'>\n";
-	output_str = output_str + "<td colspan='7'>&nbsp;<\/td>\n";
+	output_str = output_str + "<td colspan='8'>&nbsp;<\/td>\n";
 	output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	output_str = output_str + "<td colspan='3'>&nbsp;<\/td>\n";
 	output_str = output_str + "<\/tr>\n";
 	output_str = output_str + "<\/table>\n";
 	
 	document.getElementById("MenuItemsTable").innerHTML = output_str;
-	document.getElementById("nCount").value = i;
+	nCount = i;
 	
 	if (rows[0] != "-no data-")
 	{
@@ -693,7 +625,7 @@ function MoveItem(i)
 	window.parent.SetWorkSavedNotSaved(false);
 	
 	var html = document.getElementById("MenuItemsTable").innerHTML;
-	var cnt = parseInt(document.getElementById("nCount").value);
+	var cnt = parseInt(nCount);
 	var t = i - 1;
 	var b = i + 1;
 	var srch_str_t;
@@ -882,11 +814,14 @@ function MoveItem(i)
 		document.getElementById(LastMoveDown).style.display = "none";
 		document.getElementById("MoveUp0").style.display = "none";
 		document.getElementById(NextToLastMoveDown).style.display = "table-row";
-		document.getElementById("MoveUp1").style.display = "table-row";
+		if (ElExists("MoveUp1"))
+			document.getElementById("MoveUp1").style.display = "table-row";
 		document.getElementById("Indent0").style.display = "none";
-		document.getElementById("Indent1").style.display = "table-row";
+		if (ElExists("Indent1"))
+			document.getElementById("Indent1").style.display = "table-row";
 		document.getElementById("IndentRemove0").style.display = "none";
-		document.getElementById("IndentRemove1").style.display = "table-row";
+		if (ElExists("IndentRemove1"))
+			document.getElementById("IndentRemove1").style.display = "table-row";
 	}
 }
 
@@ -976,8 +911,6 @@ function PopulatePage(i)
 	document.getElementById(URL_ctl).value = url;
 
 	window.parent.SetWorkSavedNotSaved(false);
-
-	SetElementValue(URL_ctl, pageSelect_ctl);
 }
 
 function PopulateTarget(i)
@@ -993,92 +926,8 @@ function PopulateTarget(i)
 		document.getElementById(target_ctl).type = "hidden";
 	
 	window.parent.SetWorkSavedNotSaved(false);
-	
-	SetElementValue(target_ctl, target_select_ctl);
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
-function SetElementValue(el_id, el_id_2)
-{
-	var html = document.getElementById("MenuItemsTable").innerHTML;
-
-	if (el_id != -1)	{
-		var val = document.getElementById(el_id).value;
-		var srch = "id=\"" + el_id;
-		var pos1 = html.indexOf(srch, 0);
-		if (pos1 == -1)	{
-			srch = "id='" + el_id;
-			pos1 = html.indexOf(srch, 0);
-		}
-		srch = "value=";
-		var pos2 = html.indexOf(srch, pos1);
-		srch = "\"";
-		var pos3 = html.indexOf(srch, pos2);
-		if (pos3 == -1)	{	// In case browser replaced single quotes with double quotes.
-			srch = "'";
-			pos3 = html.indexOf(srch, pos2);
-		}
-		var pos4 = html.indexOf(srch, pos3 + 1);
-		var html_start = html.substr(0, pos2);
-		var html_end = html.substr(pos4 + 1);
-		html = html_start + "value='" + val + "'" + html_end;
-	}
-
-	if (el_id_2 != -1)	{
-		var val = document.getElementById(el_id_2).value;
-		var srch = "id=\"" + el_id_2;
-		var pos1 = html.indexOf(srch, 0);
-		if (pos1 == -1)	{
-			srch = "id='" + el_id_2;
-			pos1 = html.indexOf(srch, 0);
-		}
-		// Get position of next id to compare in case nothing is selected.
-		srch = "id=";
-		var pos5 = html.indexOf(srch, pos1 + 1);
-		// First remove selected option.
-		srch = "selected="
-		var pos2 = html.indexOf(srch, pos1);
-		if ((pos2 < pos5) && (pos2 > -1))	{	// If not true, then nothing selected.
-			var html_start = html.substr(0, pos2);
-			var html_end = html.substr(pos2 + 19);
-			html = html_start + html_end;
-		}
-		// Now go ahead and insert selected option.
-		srch = "value=\"" + val;
-		pos2 = html.indexOf(srch, pos1);
-		if (pos2 == -1)	{	// In case browser replaced single quotes with double quotes.
-			srch = "value='" + val;
-			pos2 = html.indexOf(srch, pos1);
-		}
-		srch = "\"";
-		var pos3 = html.indexOf(srch, pos2 + 7);
-		if (pos3 == -1)	{
-			srch = "'";
-			pos3 = html.indexOf(srch, pos2);
-		}
-		srch = ">"
-		var pos4 = html.indexOf(srch, pos3);
-		html_start = html.substr(0, pos3 + 1);
-		html_end = html.substr(pos4);
-		html = html_start + " selected='selected'" + html_end;
-	}
-	
-	document.getElementById("MenuItemsTable").innerHTML = html;
-
-	curr_item_under_edit = "";
-}
-
-function SetElementVal(el_id)
-{
-	if (el_id == curr_item_under_edit)	{
-		SetElementValue(el_id, -1);
-	}
-}
-
-function SetCurrentItem(el_id)
-{
-	curr_item_under_edit = el_id;
-}
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
