@@ -23,6 +23,8 @@
 // Revised:	2/2/2012	ELL
 // Fixed bug with "See Site" button not updating to new file after "Save As".
 // Fixed bug of "Save As" not creating new file.
+// Revised: 5/14/2018	ELL
+// Added hooks for plugin buttons and code.
 
 var mTimer;
 var lockoutChangeCheck = true;
@@ -31,10 +33,11 @@ var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1
 var popup_msg = new PopupMsg(param_array);
 
 window.parent.document.title = document.title;
+setTimeout("window.parent.CallResizeWorkspace();", 500);
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#edit_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function OpenHelpList(plugin_cnt)
@@ -286,11 +289,14 @@ function SaveAs(name_prefix)
 {
 	var old_page_name = page_name;
 	var new_page_name = document.getElementById("popup_prompt_textbox").value;
+		
 	if ((new_page_name == null) || (new_page_name == ""))
 	{
 		alert(EDITOR_PAGE_BLANK_ERR);
 		return;
 	}
+	if (new_page_name.substr(new_page_name.length - 4) == ".php")
+		new_page_name = new_page_name.substr(0, new_page_name.length - 4);
 	
 	if (special != 1)
 		page_name = new_page_name;
@@ -405,12 +411,13 @@ function DeleteBorderArea(delete_mode)
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
-
-	var editorWidth = mainWidth - menuWidth;
-	var editorHeight = mainHeight - headerHeight - 58;
+	var editorWidth = mainWidth - menuWidth - 2;
+	var btnDivWidth = editorWidth - 2;
+	document.getElementById("btn_div").style.width = btnDivWidth.toString() + "px";
+	var btnDivHeight = document.getElementById("btn_div").clientHeight;
+	var editorHeight = mainHeight - headerHeight - btnDivHeight - 20;
 
 	CKEDITOR.instances['editorContainer'].resize(editorWidth, editorHeight);
 	
 	sEditorWidth = editorWidth.toString() + "px";
-	document.getElementById("btn_table").style.width = sEditorWidth;
 }
\ No newline at end of file
