@@ -28,6 +28,10 @@
 // Added ability to switch CSS menu tools and JS menu tools on or off.
 // Revised: 11/22/2017	ELL
 // Made "Users & Site Options" button modal switchig to "Manage My Account" when logged in as non-admin but at least user access level.
+// Revised: 4/27/2018	ELL
+// Added "Minify Files" button.
+// Revised: 11/23/2018	ELL
+// Modified to go to last selected module if session timed out and logging back in.
 // 
 // 
 var browser = BrowserDetect.browser;
@@ -75,6 +79,7 @@ else
 	
 var work_saved = true;
 var next_btn;
+var mSessionTimer;
 
 /////////////////////////////////////////////////////////////////////
 function ExpandCollapseMenus(menu_group)
@@ -607,6 +612,8 @@ function ExpandOtherFunctions()
 	{
 		if (enable_wizard == 1)
 			document.getElementById("btn_show_wizard").style.height = strHeight;;
+		if ((access_level == "admin") || (access_level == "power_user"))
+			document.getElementById("btn_minify_files").style.height = strHeight;
 		document.getElementById("btn_users_site_options").style.height = strHeight;
 	}
 	
@@ -627,6 +634,8 @@ function ExpandOtherFunctions()
 		{
 			if (enable_wizard == 1)
 				document.getElementById("btn_show_wizard").style.display = inherit;
+			if ((access_level == "admin") || (access_level == "power_user"))
+				document.getElementById("btn_minify_files").style.display = inherit;
 			document.getElementById("btn_users_site_options").style.display = inherit;
 		}
 			
@@ -659,6 +668,8 @@ function CollapseOtherFunctions()
 	{
 		if (enable_wizard == 1)
 			document.getElementById("btn_show_wizard").style.height = strHeight;
+		if ((access_level == "admin") || (access_level == "power_user"))
+			document.getElementById("btn_minify_files").style.height = strHeight;
 		document.getElementById("btn_users_site_options").style.height = strHeight;
 	}
 		
@@ -679,6 +690,8 @@ function CollapseOtherFunctions()
 		{
 			if (enable_wizard == 1)
 				document.getElementById("btn_show_wizard").style.display = "none";
+			if ((access_level == "admin") || (access_level == "power_user"))
+				document.getElementById("btn_minify_files").style.display = "none";
 			document.getElementById("btn_users_site_options").style.display = "none";
 		}
 		
@@ -907,6 +920,8 @@ function SetBtnDown(btn)
 	{
 		if (enable_wizard == 1)
 			document.getElementById("btn_show_wizard").className =	"button_top_level";
+		if ((access_level == "admin") || (access_level != "power_user"))
+			document.getElementById("btn_minify_files").className =	"button_top_level";
 		document.getElementById("btn_users_site_options").className =	"button_top_level";
 	}
 	for (i = 0; i < plugin_button_cnt; i++)
@@ -918,6 +933,15 @@ function SetBtnDown(btn)
 	btn.className = btn.className + " down";
 }
 
+function GetBtnDown()
+{
+	var down_btn = document.getElementsByClassName("button_top_level down");
+	if (down_btn.length > 0)
+		return down_btn[0];
+	else
+		return "";
+}
+
 //////////////////////////////////////////////////////////////////////////////////////
 function SetAccessLevel()
 {
@@ -946,7 +970,7 @@ function SetAccessLevel()
 //////////////////////////////////////////////////////////////////////////////////////
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#main", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#main", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -1012,10 +1036,13 @@ function SetWorkspaceLocation(module, btn)
 	xmlhttp = getXmlHttpRequestObject();
 	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
 	{
+		clearInterval(mSessionTimer);
 		xmlhttp.open("POST","check_session.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = CheckSession(xmlhttp);
+		xmlhttp = CheckSession(xmlhttp, module, btn);
 		xmlhttp.send();
+		mSessionTimer = setInterval("CheckSessionExec();", 600000);
+
 	}
 }
 
@@ -1025,7 +1052,7 @@ function DoNextClick()
 	SetBtnDown(next_btn);
 }
 
-function CheckSession(xmlhttp)
+function CheckSession(xmlhttp, module, btn)
 {
 	xmlhttp.onreadystatechange=function()
 	{
@@ -1042,14 +1069,42 @@ function CheckSession(xmlhttp)
 				popup_msg.popup_button_1_span = NO_WORD;
 				popup_msg.popup_timeout = -1;
 				popup_msg.ShowPopupMsg();
-				document.getElementById("popup_button_2_span").onclick = function () { window.location='index.php'; };
-				document.getElementById("popup_button_1_span").onclick = function () { window.location='/index.php'; };
+
+				if ((module !== null) && (typeof module !== "undefined") && (module != ""))	{
+					var module_encode = encodeURI(module);
+					var btn_id = btn.id;
+					var url = "index.php?module=" + module_encode + "&btn=" + btn_id;
+					document.getElementById("popup_button_2_span").onclick = function () { window.location = url; };
+				}
+				else
+					document.getElementById("popup_button_2_span").onclick = function () { window.location = 'index.php'; };
+				document.getElementById("popup_button_1_span").onclick = function () { window.location = '/index.php'; };
+				
+				clearInterval(mSessionTimer);
 			}
 		}
 	}
 	return (xmlhttp);
 }
 
+function CheckSessionExec()
+{
+	var module = workspace.location;
+	var btn = GetBtnDown();
+	
+	var xmlhttp;
+	xmlhttp = getXmlHttpRequestObject();
+	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
+	{
+		xmlhttp.open("POST","check_session.php",true);
+		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+		xmlhttp = CheckSession(xmlhttp, module, btn);
+		xmlhttp.send();
+	}
+}
+
+mSessionTimer = setInterval("CheckSessionExec();", 600000);
+
 /////////////////////////////////////////////////////////////////////
 window.addEventListener('resize', function(event) {
 	mTimer7 = setTimeout("CallResizeWorkspace();", 500);
@@ -1083,7 +1138,7 @@ function CallResizeWorkspace()
 		headerHeight = 135;
 		
 //	window.alert( 'Width = ' + mainWidth + ' --- Height = ' + mainHeight + ' --- Menu Width = ' + menuWidth + ' --- Header Height = ' + headerHeight );
-	if ((document.getElementById("btn_edit_content").className.indexOf("down") > -1) || (document.getElementById("btn_manage_border_areas").className.indexOf("down") > -1) || (document.getElementById("btn_manage_edit_blog").className.indexOf("down") > -1) || (document.getElementById("btn_edit_styles").className.indexOf("down") > -1) || (document.getElementById("btn_edit_head_code").className.indexOf("down") > -1))
+	if ((document.getElementById("btn_edit_content").className.indexOf("down") > -1) || (document.getElementById("btn_manage_border_areas").className.indexOf("down") > -1) || (document.getElementById("btn_manage_edit_blog").className.indexOf("down") > -1) || (document.getElementById("btn_edit_styles").className.indexOf("down") > -1) || (document.getElementById("btn_edit_head_code").className.indexOf("down") > -1) || (document.getElementById("btn_edit_file").className.indexOf("down") > -1))
 		document.getElementById("workspace").contentWindow.ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight);
 	
 	var workspaceWidth = mainWidth - menuWidth;
