@@ -14,6 +14,8 @@
 // Revised: 10/28/2016	ELL
 // Added list of pages to auto-populate suffix for new border areas to make creating border areas with meaningful names as default behavior,
 // and to allow for automatic assignment at border area creation.
+// Modified: 11/26/2019	ELL
+// Added visual indication of inactive pages.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -24,7 +26,7 @@ var area_names = new Array();
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_special", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#manage_special", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function UpdateSuffix(suffix)
@@ -187,7 +189,10 @@ function PopulateBorderAreaAssignmentTable(data)
 			var JSON_row = JSON.parse(rows[i]);
 			
 			html = html +  "<tr bgcolor='" + bgcolor + "'>\n";
-			html = html +  "<td>" + JSON_row.page_name + "</td>";
+			if (JSON_row.active < 1)
+				html = html +  "<td>" + JSON_row.page_name + " (" + INACTIVE_WORD + ")</td>";
+			else
+				html = html +  "<td>" + JSON_row.page_name + "</td>";
 			
 			/////////////////////////////////////////
 			//Test to see if file already exists.
@@ -197,6 +202,8 @@ function PopulateBorderAreaAssignmentTable(data)
 			}
 			/////////////////////////////////////////
 				
+			if (JSON_row.template.indexOf("header") < 0)
+				JSON_row.header_name = "-na-";
 			if (JSON_row.template.indexOf("top") < 0)
 				JSON_row.top_name = "-na-";
 			if (JSON_row.template.indexOf("left") < 0)
@@ -205,6 +212,8 @@ function PopulateBorderAreaAssignmentTable(data)
 				JSON_row.right_name = "-na-";
 			if (JSON_row.template.indexOf("bottom") < 0)
 				JSON_row.bottom_name = "-na-";
+			if (JSON_row.template.indexOf("footer") < 0)
+				JSON_row.footer_name = "-na-";
 				
 			html = html + "<td>\n";
 			if (JSON_row.right_name != "-na-")
@@ -466,8 +475,8 @@ function SetBtnDownState(down_btn)
 function InitializeConsole()
 {
 	GetBorderAreas();
-	GetBorderAreaAssignments();
-	setTimeout("InitializePrefix();", 500);
+	setTimeout("GetBorderAreaAssignments();", 500);
+	setTimeout("InitializePrefix();", 1000);
 	
 }
 function InitializePrefix()
