@@ -29,7 +29,7 @@ window.parent.document.title = document.title;
 
 function OpenHelpWindow(topic)
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 
@@ -913,6 +913,10 @@ function ShowHidePageBtns()
 		document.getElementById("prev_top").src = "./theme/" + theme + "/images/Previous_disabled.gif";
 		document.getElementById("first_bot").src = "./theme/" + theme + "/images/First_disabled.gif";
 		document.getElementById("prev_bot").src = "./theme/" + theme + "/images/Previous_disabled.gif";
+		document.getElementById("first_top").style.cursor = "default";
+		document.getElementById("prev_top").style.cursor = "default";
+		document.getElementById("first_bot").style.cursor = "default";
+		document.getElementById("prev_bot").style.cursor = "default";
 	}
 	else
 	{
@@ -920,6 +924,10 @@ function ShowHidePageBtns()
 		document.getElementById("prev_top").src = "./theme/" + theme + "/images/Previous.gif";
 		document.getElementById("first_bot").src = "./theme/" + theme + "/images/First.gif";
 		document.getElementById("prev_bot").src = "./theme/" + theme + "/images/Previous.gif";
+		document.getElementById("first_top").style.cursor = "pointer";
+		document.getElementById("prev_top").style.cursor = "pointer";
+		document.getElementById("first_bot").style.cursor = "pointer";
+		document.getElementById("prev_bot").style.cursor = "pointer";
 	}
 	
 	if (page == total_pages)
@@ -928,6 +936,10 @@ function ShowHidePageBtns()
 		document.getElementById("last_top").src = "./theme/" + theme + "/images/Last_disabled.gif";
 		document.getElementById("next_bot").src = "./theme/" + theme + "/images/Next_disabled.gif";
 		document.getElementById("last_bot").src = "./theme/" + theme + "/images/Last_disabled.gif";
+		document.getElementById("next_top").style.cursor = "default";
+		document.getElementById("last_top").style.cursor = "default";
+		document.getElementById("next_bot").style.cursor = "default";
+		document.getElementById("last_bot").style.cursor = "default";
 	}
 	else
 	{
@@ -935,6 +947,10 @@ function ShowHidePageBtns()
 		document.getElementById("last_top").src = "./theme/" + theme + "/images/Last.gif";
 		document.getElementById("next_bot").src = "./theme/" + theme + "/images/Next.gif";
 		document.getElementById("last_bot").src = "./theme/" + theme + "/images/Last.gif";
+		document.getElementById("next_top").style.cursor = "pointer";
+		document.getElementById("last_top").style.cursor = "pointer";
+		document.getElementById("next_bot").style.cursor = "pointer";
+		document.getElementById("last_bot").style.cursor = "pointer";
 	}
 	
 	var rcrd_start = (page * max_rec) + 1;
@@ -1087,6 +1103,8 @@ function PopulateUser(data)
 		document.getElementById("email_edit").value = JSON_row.email;
 		document.getElementById("first_name_edit").value = JSON_row.first_name;
 		document.getElementById("last_name_edit").value = JSON_row.last_name;
+		document.getElementById("selectUserNameExistingUser").value = JSON_row.UserID;
+		document.getElementById("selectUserNameDelete").value = JSON_row.UserID;
 		
 		var html = "";
 		var prop_str;
