@@ -16,6 +16,8 @@
 // without having clicked on any pages inside of Manage Page Attributes, and attributes not saving.
 // Revised: 5/26/2016	ELL
 // Added function string checking to standardize entry of function call.
+// Revised: 5/1/2018	ELL
+// Added on-the-fly minification of all content.
 // 
 //
 var browser = BrowserDetect.browser;
@@ -56,7 +58,7 @@ function LocateAttributesDiv ()
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_page_attributes", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#manage_page_attributes", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -162,6 +164,11 @@ function CompleteGetAttributes(data)
 			document.getElementById("insert_default_footer").checked = true;
 		else
 			document.getElementById("insert_default_footer").checked = false;
+			
+		if (JSON_row.minify == 1)
+			document.getElementById("minify").checked = true;
+		else
+			document.getElementById("minify").checked = false;
 	}
 }
 
