@@ -17,7 +17,7 @@ var browser_version = BrowserDetect.versio
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_style_sheet_attrib", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#manage_style_sheet_attrib", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////
