@@ -27,7 +27,7 @@ function dropdown(sel){
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#options", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#options", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
