@@ -3,6 +3,8 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 7/2/2010 ELL
+// Revised: 3/23/2021	ELL
+// Added highlighting of last row selected.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -11,7 +13,7 @@ window.parent.document.title = document.title;
 
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#restore_page_select", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#restore_page_select", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 //////////////////////////////////////////////////////////////
@@ -78,19 +80,31 @@ function DisplayArchivedContent(ID)
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
-	$.post( "preview_archive_init.php", { ID: ID } ).done(CompleteDisplayArchivedContent) ;
-	
+	$.post( "preview_archive_init.php", { ID: ID } ).done(function( data ) { CompleteDisplayArchivedContent(data, ID); } ) ;
 }
-function CompleteDisplayArchivedContent(data)
+function CompleteDisplayArchivedContent(data, ID)
 {
 	var JSON_row = JSON.parse(data);
 	var page_name = JSON_row.page_name;
 	var special = JSON_row.source;
+	
+	HighlightCurRow(ID);
 
-	var preview_page_string = "preview_page.php?page_name=" + page_name + "&special=" + special + "&mode=edit&blog_id=0";
+	var preview_page_string = "preview_page.php?page_name=" + page_name + "&special=" + special + "&mode=restore&blog_id=0&restore_id=" + ID;
 	window.open(preview_page_string, "Preview", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=900,width=1000");
 }
 
+function HighlightCurRow(ID)
+{
+	var page_rows = document.getElementsByClassName('cur_row');
+	for (var i = 0; i < page_rows.length; i++)
+	{
+		page_rows[i].className = '';
+	}
+	var row_id = 'row_' + ID;
+	document.getElementById(row_id).className = 'cur_row';
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
