@@ -1522,4 +1522,64 @@ define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "复制样式表时出错。");
 define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "来源类型");
 define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地类型未被选中。请选择目的地类型，然后重试。");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子级别2块边框颜色");
+define('MANAGE_FONTS_INSTRUCTIONS_1', "注意：除非您点击，否则更改不会被记录");
+define('MANAGE_FONTS_INSTRUCTIONS_2', "点击");
+define('MANAGE_FONTS_INSTRUCTIONS_3', "将使用新参数创建您的字体的副本。如果您只是更改字体参数，请单击");
+define('MANAGE_FONTS_INSTRUCTIONS_4', "在原始字体旁边删除它。只允许TTF，OTF，WOFF，WOFF2，SVG和EOT的文件类型。");
+define('MANAGE_FONTS_FONT_SAVED_MSG', "字体已保存。");
+define('MANAGE_FONTS_ERROR_SAVING_FONT_ERR', "保存字体时出错。");
+define('MANAGE_FONTS_ADD_BEFORE_SAVE_NEW_MSG', "您有一个尚未保存的新字体。请在添加新字体之前保存该字体。");
+define('MANAGE_FONTS_FONT_UPLOADED_MSG', "您的字体文件已上传。");
+define('MANAGE_FONTS_FONT_UPLOAD_ERR', "试图上传字体时出错。");
+define('MANAGE_FONTS_FONT_UPLOAD_CANCEL_MSG', "上传已被用户取消或浏览器断开连接。");
+define('MANAGE_FONTS_NO_FONT_ERR', "&#39;字体&#39;不能为空。");
+define('MANAGE_FONTS_NO_UPLOAD_ERR', "如果选择“上传”，则必须从您的计算机中选择要上传的文件。");
+define('MANAGE_FONTS_NO_URL_ERR', "如果选中“网址”，则“网址”不能为空。");
+define('RUN_SQL_BACK_TO_EDIT_CSS_SELECT', "返回运行SQL");
+define('RUN_SQL_QUERY_SUCCESS_MSG', "查询成功完成");
+define('MAIN_MENU_MINIFY_FILES', "缩小文件");
+define('EDIT_FILE_FILE_PUBLISHED', "该文件已发布。");
+define('EDIT_FILE_FILE_SAVED', "该文件已保存。");
+define('MANAGE_PAGE_ATTRIBUTES_MINIFY', "即时缩小所有内容");
+define('OPTIONS_MINIFY_JS_ON_SAVE', "在保存中将JavaScript缩小");
+define('OPTIONS_MINIFY_CSS_ON_SAVE', "在保存中缩小CSS");
+define('MINIFY_FILE_SELECT_HEADING', "选择JavaScript文件来缩小");
+define('MINIFY_FILE_MINIFY_CSS_BTN', "最小化所有CSS文件");
+define('MINIFY_FILE_MINIFY_JS_COMPLETE_MSG', "JavaScript文件已被缩小。");
+define('MINIFY_FILE_MINIFY_JS_COMPLETE_ERR', "有一个错误缩小了JavaScript。");
+define('MINIFY_FILE_MINIFY_CSS_COMPLETE_MSG', "所有的CSS文件都被缩小了。");
+define('MINIFY_FILE_MINIFY_CSS_COMPLETE_ERR', "有一个错误缩小了CSS。");
+define('OPTIONS_EDITOR_DESIGN_VIEW_THEME', "编辑器设计视图主题");
+define('EDIT_CSS_BOX_SIZING', "盒子大小");
+define('EDIT_CSS_CONTENT_BOX', "内容框");
+define('EDIT_CSS_BORDER_BOX', "边框");
+define('ALIGNMENT_WORD', "对准");
+define('TEXT_ALIGN', "文字对齐");
+define('CONTENT_ALIGNMENT', "内容对齐");
+define('ITEM_ALIGNMENT', "项目对齐");
+define('SELF_ALIGNMENT', "自我对齐");
+define('EDIT_CSS_MENU_STYLES_HT_WD_MHT_MWD_BW_FS', "宽度，高度，最小宽度，最小高度，最大宽度，最大高度，边框宽度，字体大小");
+define('DELETE_RECORD_1_MSG', "您确定要删除记录吗？");
+define('DELETE_RECORD_2_MSG', "？");
+define('PER_PAGE', "每页");
+define('EDIT_WORD', "编辑");
+define('STATUS_WORD', "状态");
+define('PENDING_WORD', "有待");
+define('DECLINED_WORD', "下降");
+define('EVENT_WORD', "事件");
+define('QUERYING', "查询......");
+define('RECORD_NOT_FOUND', "记录不存在");
+define('EDIT_PAGE_UPDATE_FAILED', "更新失败");
+define('EDIT_PAGE_NO_CHANGE', "没变");
+define('EDIT_CSS_ADVANCED_STYLES_BTN', "高级样式");
+define('EDIT_CSS_AVANCED_CSS_SAVED_MSG', "高级CSS已保存");
+define('EDIT_PAGE_SELECT_DEVICE_EMULATION', "设备仿真");
+define('MAIN_MENU_EDITING_SITE', "编辑网站");
+define('LOGIN_SELECT_SITE', "网站实例");
+define('OPTIONS_CREATE_PAGE_FILE_EXISTS_HANDLING', "创建页面时如何处理文件存在错误");
+define('MAIN_MENU_IS_ACTIVE', "活跃");
+define('WEBSITE_WORD', "网站");
+define('EDIT_CSS_SELECT_MENU_ITEM_STYLES_HEADING', "编辑菜单项样式");
+define('EDIT_CSS_SELECT_MENU_STYLES_HEADING', "编辑菜单样式（仅限专家级别）");
+define('INACTIVE_WORD', "不活跃");
 ?>
\ No newline at end of file
