@@ -71,6 +71,17 @@
 // Added ability to set !important based on table entries in site_css_important.
 // Revised: 8/24/2017	ELL
 // Added background gradient capability.
+// Revised: 10/12/2018	ELL
+// Changed CSS field from "align" to "text_align" to match actual CSS term.
+// Changed CSS field from "shadow" to "text_shadow" to match actual CSS term.
+// Added "auto" to width, height, top, bottom, left and right.
+// Added box-sizing.
+// Added length and length units to vertical-align.
+// Added align-content, align-items and align-self.
+// Added "inherit" and "initial" to vertical-align.
+// Revised: 10/21/2018	ELL
+// Re-engeneered width and height to use individual field sets for width, min-width and max-width, 
+// and height, min-height and max-height.
 //
 //
 function GetLengthUnitsStr($units_index)
@@ -119,6 +130,9 @@ function GetLengthUnitsStr($units_index)
 		case 13:
 			$units = "ch";
 			break;
+		case 14:
+			$units = "auto";
+			break;
 		default:
 			$units = "px";
 	}
@@ -143,7 +157,6 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 			
 		$result_style_sheet_attrib = $dbh->query($query_style_sheet_attrib);
 		$row_style_sheet_attrib = $result_style_sheet_attrib->fetch(PDO::FETCH_ASSOC);
-		$show_custom_styles = $row_style_sheet_attrib['show_custom_styles'];
 		$charset = $row_style_sheet_attrib['charset'];
 		$import = $row_style_sheet_attrib['import'];
 		$media_type = $row_style_sheet_attrib['media_type'];
@@ -176,14 +189,24 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 		}
 		//////////////////////////////////////////////////////////////////////
 	}
+	
+	$query = "SELECT @@SESSION.sql_mode;";
+	$result = $dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$sql_mode = $row["@@SESSION.sql_mode"];
+	$tmp_sql_mode = str_replace("ONLY_FULL_GROUP_BY", "", $sql_mode);
+	$tmp_sql_mode = trim($tmp_sql_mode, ",");
 		
 	$query_build_string = "SELECT * FROM " . $bwb . "site_css INNER JOIN " . $bwb . "site_classes ON " . $bwb . "site_css.class = " . $bwb . "site_classes.class WHERE " . $bwb . "site_css.style_sheet = '" . $style_sheet . "'";
 
 	if ($template_id > -1)
 		$query_build_string .= " AND " . $bwb . "site_css.template_id=" . $template_id;
-		
+	
 	$query_build_string .= " GROUP BY " . $bwb . "site_classes.class ORDER BY " . $bwb . "site_classes.sort_order ASC, " . $bwb . "site_classes.subclass_sort_order ASC";
 
+	$sql = "SET SESSION sql_mode = '" . $tmp_sql_mode . "'";
+	$result = $dbh->exec($sql);
+
 	$result_build_string = $dbh->query($query_build_string);
 	if ($result_build_string)
 	{
@@ -250,8 +273,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else $small_caps = 0;
 				if ($row_bs["no_text_decoration"]) $no_text_decoration = $row_bs["no_text_decoration"];
 				else $no_text_decoration = 0;
-				if ($row_bs["shadow"]) $shadow = $row_bs["shadow"];
-				else $shadow = 0;
+				if ($row_bs["text_shadow"]) $text_shadow = $row_bs["text_shadow"];
+				else $text_shadow = 0;
 				if ($row_bs["shadow_color"]) $shadow_color = $row_bs["shadow_color"];
 				else $shadow_color = "-not set-";
 				if ($row_bs["shadow_x_offset"]) $shadow_x_offset = $row_bs["shadow_x_offset"];
@@ -269,10 +292,15 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				if (!is_null($row_bs["text_indent_units"])) $text_indent_units = $row_bs["text_indent_units"];
 				else $text_indent_units = -1;
 				
-				if ($row_bs["align"]) $align = $row_bs["align"];
-				else $align = "-not selected-";
+				if ($row_bs["text_align"]) $text_align = $row_bs["text_align"];
+				else $text_align = "-not selected-";
 				if (!is_null($row_bs["vertical_align"])) $vertical_align = $row_bs["vertical_align"];
 				else $vertical_align = "-not selected-";
+				if (!is_null($row_bs["vertical_align_length"])) $vertical_align_length = $row_bs["vertical_align_length"];
+				else $vertical_align_length = -1000000;
+				if (!is_null($row_bs["vertical_align_length_units"])) $vertical_align_length_units = $row_bs["vertical_align_length_units"];
+				else $vertical_align_length_units = 0;
+				
 				if ($row_bs["bkgd_color"]) $bkgd_color = $row_bs["bkgd_color"];
 				else $bkgd_color = "-not set-";
 				if ($row_bs["bkgd_transparent"]) $bkgd_transparent = $row_bs["bkgd_transparent"];
@@ -293,6 +321,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else $outline_style = "-not selected-";
 				if ($row_bs["border_collapse"]) $border_collapse = $row_bs["border_collapse"];
 				else $border_collapse = "-not selected-";
+				if ($row_bs["box_sizing"]) $box_sizing = $row_bs["box_sizing"];
+				else $box_sizing = "-not selected-";
 				if (!is_null($row_bs["border_sides"])) $border_sides = $row_bs["border_sides"];
 				else $border_sides = 15;
 				
@@ -310,8 +340,10 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else $width = -1;
 				if ($row_bs["width_units"]) $width_units = $row_bs["width_units"];
 				else $width_units = 0;
-				if ($row_bs["width_prefix"]) $width_prefix = $row_bs["width_prefix"];
-				else $width_prefix = "-not selected-";
+				if (!is_null($row_bs["min_width"])) $min_width = $row_bs["min_width"];
+				else $min_width = -1;
+				if ($row_bs["min_width_units"]) $min_width_units = $row_bs["min_width_units"];
+				else $min_width_units = 0;
 				if (!is_null($row_bs["max_width"])) $max_width = $row_bs["max_width"];
 				else $max_width = -1;
 				if ($row_bs["max_width_units"]) $max_width_units = $row_bs["max_width_units"];
@@ -320,8 +352,10 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else $height = -1;
 				if ($row_bs["height_units"]) $height_units = $row_bs["height_units"];
 				else $height_units = 0;
-				if ($row_bs["height_prefix"]) $height_prefix = $row_bs["height_prefix"];
-				else $height_prefix = "-not selected-";
+				if (!is_null($row_bs["min_height"])) $min_height = $row_bs["min_height"];
+				else $min_height = -1;
+				if ($row_bs["min_height_units"]) $min_height_units = $row_bs["min_height_units"];
+				else $min_height_units = 0;
 				if (!is_null($row_bs["max_height"])) $max_height = $row_bs["max_height"];
 				else $max_height = -1;
 				if ($row_bs["max_height_units"]) $max_height_units = $row_bs["max_height_units"];
@@ -519,6 +553,13 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else $gradient_opacities = "-not set-";
 				if (!is_null($row_bs["gradient_repeat"])) $gradient_repeat = $row_bs["gradient_repeat"];
 				else $gradient_repeat = 0;
+				
+				if ($row_bs["align_content"]) $align_content = $row_bs["align_content"];
+				else $align_content = "-not selected-";
+				if ($row_bs["align_items"]) $align_items = $row_bs["align_items"];
+				else $align_items = "-not selected-";
+				if ($row_bs["align_self"]) $align_self = $row_bs["align_self"];
+				else $align_self = "-not selected-";
 			
 				///////////////// Get !important attributes list //////////////////
 				if (isset($important))
@@ -663,7 +704,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					if (in_array('text_transform', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 					
-				if ($shadow == 1)
+				if ($text_shadow == 1)
 				{
 					if ((float)$shadow_x_offset == (int)$shadow_x_offset)
 						$shadow_x_offset = intval($shadow_x_offset);
@@ -685,7 +726,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					else
 						$css_string .= "   text-shadow: " . $shadow_x_offset . "px " . $shadow_y_offset . "px " . $shadow_blur . "px";
 						
-					if (in_array('shadow', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					if (in_array('text_shadow', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 				
 				if ($line_height_units != -1)
@@ -778,13 +819,26 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					$css_string .= "   font-variant: small-caps";
 					if (in_array('small_caps', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
-				if ($align != "-not selected-")	{
-					$css_string .= "   text-align: " . $align;
-					if (in_array('align', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				if ($text_align != "-not selected-")	{
+					$css_string .= "   text-align: " . $text_align;
+					if (in_array('text_align', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 				if (($vertical_align != "-not selected-") && ($vertical_align != "") && isset($vertical_align))	{
-					$css_string .= "   vertical-align: " . $vertical_align;
-					if (in_array('vertical_align', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					if (($vertical_align == "length") && ($vertical_align_length != -1000000))	{
+						if ($vertical_align_length_units == 0)
+							$vertical_align_length = intval($vertical_align_length);
+						elseif (($vertical_align_length_units == 1) && ((float)$vertical_align_length == (int)$vertical_align_length))
+							$vertical_align_length = intval($vertical_align_length);
+						else
+							$vertical_align_length = floatval($vertical_align_length);
+						$units = GetLengthUnitsStr($vertical_align_length_units);
+						$css_string .= "   vertical-align: " . $vertical_align_length . $units;
+						if (in_array('vertical_align', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					}
+					elseif ($vertical_align != "length")	{
+						$css_string .= "   vertical-align: " . $vertical_align;
+						if (in_array('vertical_align', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					}
 				}
 					
 				if ($bkgd_transparent == 1)
@@ -955,6 +1009,11 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					$css_string .= "   border-collapse: " . $border_collapse;
 					if (in_array('border_collapse', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
+				
+				if ($box_sizing != "-not selected-")	{
+					$css_string .= "   box-sizing: " . $box_sizing;
+					if (in_array('box_sizing', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				}
 					
 				if ($margin_top_units == 0)
 					$margin_top = intval($margin_top);
@@ -1033,6 +1092,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else
 					$position_left = floatval($position_left);
 				$units = GetLengthUnitsStr($position_left_units);
+				if ($units == "auto")
+					$position_left = "";
 				if ($position_left != -1000000)	{
 					$css_string .= "   left: " . $position_left . $units;
 					if (in_array('position_left', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
@@ -1045,6 +1106,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else
 					$position_top = floatval($position_top);
 				$units = GetLengthUnitsStr($position_top_units);
+				if ($units == "auto")
+					$position_top = "";
 				if ($position_top != -1000000)	{
 					$css_string .= "   top: " . $position_top . $units;
 					if (in_array('position_top', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
@@ -1057,6 +1120,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else
 					$position_right = floatval($position_right);
 				$units = GetLengthUnitsStr($position_right_units);
+				if ($units == "auto")
+					$position_right = "";
 				if ($position_right != -1000000)	{
 					$css_string .= "   right: " . $position_right . $units;
 					if (in_array('position_right', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
@@ -1069,6 +1134,8 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				else
 					$position_bottom = floatval($position_bottom);
 				$units = GetLengthUnitsStr($position_bottom_units);
+				if ($units == "auto")
+					$position_bottom = "";
 				if ($position_bottom != -1000000)	{
 					$css_string .= "   bottom: " . $position_bottom . $units;
 					if (in_array('position_bottom', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
@@ -1098,7 +1165,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				}
 					
 				if ($white_space != "-not selected-")	{
-					$css_string .= "   white_space: " . $white_space;
+					$css_string .= "   white-space: " . $white_space;
 					if (in_array('white_space', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 				
@@ -1153,7 +1220,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					if (in_array('display', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 					
-				if ($width != -1)
+				if (($width != -1) || (GetLengthUnitsStr($width_units) == "auto"))
 				{
 					if ($width_units == 0)
 						$width = intval($width);
@@ -1162,30 +1229,43 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					else
 						$width = floatval($width);
 					$units = GetLengthUnitsStr($width_units);
+					if ($units == "auto")
+						$width = "";
 					
-					if ($width_prefix == "-not selected-")
-						$prefix = "";
-					elseif ($width_prefix == "min-max")
-						$prefix = "min-";
-					else
-						$prefix = $width_prefix . "-";
-						
-					$css_string .= "   " . $prefix . "width: " . $width . $units;
-					if (in_array('width', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
-					
-					if (($width_prefix == "min-max") && ($max_width != -1))	{
-						if ($max_width_units == 0)
-							$max_width = intval($max_width);
-						elseif (($max_width_units == 1) && ((float)$max_width == (int)$max_width))
-							$max_width = intval($max_width);
-						else
-							$max_width = floatval($max_width);
-						$units = GetLengthUnitsStr($max_width_units);
-						$css_string .= "   max-width: " . $max_width . $units;
-						if (in_array('max_width', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
-					}
+					$css_string .= "   width: " . $width . $units;
+					if (in_array('width', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";					
 				}
-				if ($height != -1)
+				if (($min_width != -1) || (GetLengthUnitsStr($min_width_units) == "auto"))
+				{
+					if ($min_width_units == 0)
+						$min_width = intval($min_width);
+					elseif (($min_width_units == 1) && ((float)$min_width == (int)$min_width))
+						$min_width = intval($min_width);
+					else
+						$min_width = floatval($min_width);
+					$units = GetLengthUnitsStr($min_width_units);
+					if ($units == "auto")
+						$min_width = "";
+					
+					$css_string .= "   min-width: " . $min_width . $units;
+					if (in_array('min_width', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";					
+				}
+				if (($max_width != -1) || (GetLengthUnitsStr($max_width_units) == "auto"))
+				{
+					if ($max_width_units == 0)
+						$max_width = intval($max_width);
+					elseif (($max_width_units == 1) && ((float)$max_width == (int)$max_width))
+						$max_width = intval($max_width);
+					else
+						$max_width = floatval($max_width);
+					$units = GetLengthUnitsStr($max_width_units);
+					if ($units == "auto")
+						$max_width = "";
+					
+					$css_string .= "   max-width: " . $max_width . $units;
+					if (in_array('max_width', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";					
+				}
+				if (($height != -1) || (GetLengthUnitsStr($height_units) == "auto"))
 				{
 					if ($height_units == 0)
 						$height = intval($height);
@@ -1194,28 +1274,41 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					else
 						$height = floatval($height);
 					$units = GetLengthUnitsStr($height_units);
+					if ($units == "auto")
+						$height = "";
 					
-					if ($height_prefix == "-not selected-")
-						$prefix = "";
-					elseif ($width_prefix == "min-max")
-						$prefix = "min-";
+					$css_string .= "   height: " . $height . $units;
+					if (in_array('height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";					
+				}
+				if (($min_height != -1) || (GetLengthUnitsStr($min_height_units) == "auto"))
+				{
+					if ($min_height_units == 0)
+						$min_height = intval($min_height);
+					elseif (($min_height_units == 1) && ((float)$min_height == (int)$min_height))
+						$min_height = intval($min_height);
 					else
-						$prefix = $height_prefix . "-";
-						
-					$css_string .= "   " . $prefix . "height: " . $height . $units;
-					if (in_array('height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+						$min_height = floatval($min_height);
+					$units = GetLengthUnitsStr($min_height_units);
+					if ($units == "auto")
+						$min_height = "";
 					
-					if (($height_prefix == "min-max") && ($max_height != -1))	{
-						if ($max_height_units == 0)
-							$max_height = intval($max_height);
-						elseif (($max_height_units == 1) && ((float)$max_height == (int)$max_height))
-							$max_height = intval($max_height);
-						else
-							$max_height = floatval($max_height);
-						$units = GetLengthUnitsStr($max_height_units);
-						$css_string .= "   max-height: " . $max_height . $units;
-						if (in_array('max_height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
-					}
+					$css_string .= "   min-height: " . $min_height . $units;
+					if (in_array('min_height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				}
+				if (($max_height != -1) || (GetLengthUnitsStr($max_height_units) == "auto"))
+				{
+					if ($max_height_units == 0)
+						$max_height = intval($max_height);
+					elseif (($max_height_units == 1) && ((float)$max_height == (int)$max_height))
+						$max_height = intval($max_height);
+					else
+						$max_height = floatval($max_height);
+					$units = GetLengthUnitsStr($max_height_units);
+					if ($units == "auto")
+						$max_height = "";
+					
+					$css_string .= "   max-height: " . $max_height . $units;
+					if (in_array('max_height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 				}
 				
 				if (($background_image != "-not set-") && ($background_image != "-not selected-") && ($background_image != ""))	{
@@ -1461,13 +1554,13 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				}
 					
 				if ($transition_duration > -1)	{
-					if (transition_duration_units == 0)	{
+					if ($transition_duration_units == 0)	{
 						$css_string .= "   -webkit-transition-duration: " . $transition_duration . "s";
 						if (in_array('transition_duration', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 						$css_string .= "   transition-duration: " . $transition_duration . "s";
 						if (in_array('transition_duration', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 					}
-					elseif (transition_duration_units == 1)	{
+					elseif ($transition_duration_units == 1)	{
 						$css_string .= "   -webkit-transition-duration: " . $transition_duration . "ms";
 						if (in_array('transition_duration', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 						$css_string .= "   transition-duration: " . $transition_duration . "ms";
@@ -1476,13 +1569,13 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 				}
 				
 				if ($transition_delay > -1)	{
-					if (transition_delay_units == 0)	{
+					if ($transition_delay_units == 0)	{
 						$css_string .= "    -webkit-transition-delay: " . $transition_delay . "s";
 						if (in_array('transition_delay', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 						$css_string .= "   transition-delay: " . $transition_delay . "s";
 						if (in_array('transition_delay', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 					}
-					elseif (transition_delay_units == 1)	{
+					elseif ($transition_delay_units == 1)	{
 						$css_string .= "    -webkit-transition-delay: " . $transition_delay . "ms";
 						if (in_array('transition_delay', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
 						$css_string .= "   transition-delay: " . $transition_delay . "ms";
@@ -1636,6 +1729,21 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					}
 					$css_string .= $gradient_str_webkit . $gradient_str_opera . $gradient_str_moz . $gradient_str_css3;
 				}
+				
+				if ($align_content != "-not selected-")	{
+					$css_string .= "   align-content: " . $align_content;
+					if (in_array('align_content', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				}
+				
+				if ($align_items != "-not selected-")	{
+					$css_string .= "   align-items: " . $align_items;
+					if (in_array('align_items', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				}
+				
+				if ($align_self != "-not selected-")	{
+					$css_string .= "   align-self: " . $align_self;
+					if (in_array('align_self', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+				}
 			
 				$css_string .= "}\n\n";
 			} // end if use table data for tag
@@ -1644,16 +1752,15 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 	
 	$custom_css_delim = "/*****Custom CSS Delimiter*****/";
 
-	if ($show_custom_styles == 1)
-	{
-		$query_build_string = "SELECT * FROM `" . $bwb . "custom_site_css` WHERE `name` = '" . $style_sheet . "'";
+	$query_build_string = "SELECT * FROM `" . $bwb . "custom_site_css` WHERE `name` = '" . $style_sheet . "'";
 
-		if ($template_id > -1)
-			$query_build_string .= " AND template_id = " . $template_id;
-		$result_build_string = $dbh->query($query_build_string);
-		$row_bs = $result_build_string->fetch(PDO::FETCH_ASSOC);
-		if ($row_bs["custom_css"])	{
-			$custom_css = $row_bs["custom_css"];
+	if ($template_id > -1)
+		$query_build_string .= " AND template_id = " . $template_id;
+	$result_build_string = $dbh->query($query_build_string);
+	$row_bs = $result_build_string->fetch(PDO::FETCH_ASSOC);
+	if ($row_bs["custom_css"])	{
+		$custom_css = $row_bs["custom_css"];
+		if (isset($custom_css) && ($custom_css != ""))	{
 			if (strpos($custom_css, $custom_css_delim) === false)
 				$css_string .= $custom_css;
 			else	{
@@ -1668,6 +1775,9 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 	// If @media rule, close with bracket.
 	if (isset($media_type) && ($media_type != ""))
 		$css_string .= "\n\n}";
+		
+	$sql = "SET SESSION sql_mode = '" . $sql_mode . "'";
+	$result = $dbh->exec($sql);
 
 	return ($css_string);
 		
