@@ -8,6 +8,8 @@
 // Revised: 1/5/2016	ELL
 // Added switch to preserve (or not) aspect ratio.
 //
+// To ingore resize to width or height dimension, set either width or height to some large value that can never be exceeded, i.e. 1000000.
+//
 function resize_image($filename, $width, $height, $destfile, $supress_message = 0, $preserve_aspect_ratio = 1)
 {
 	$type = exif_imagetype($filename);
@@ -73,7 +75,19 @@ function resize_image($filename, $width, $height, $destfile, $supress_message =
     return 1;
 }
 
-function crop_image($filename, $crop_percent, $destfile, $crop_area)
+////////////////////////////////////////////////////////////////////
+// Choices for $crop_area are:
+//	center	(default)
+//	top
+//	bottom
+//	left
+//	right
+//	left-right
+//	top-bottom
+// Cropping creates square image for center, top, bottom, left and right crop areas.  Attempting to make square is 
+// ignored for left-right and top-bottom cropping areas.
+//
+function crop_image($filename, $crop_percent, $destfile, $crop_area = "center")
 {		
 	// Create original image
 	$type = exif_imagetype($filename);
@@ -116,7 +130,7 @@ function crop_image($filename, $crop_percent, $destfile, $crop_area)
 			$cropStartY = round($height_orig/2 - $cropW/2);
 		}
 	}
-	else if ($crop_area == "top")
+	elseif ($crop_area == "top")
 	{
 		//Crop to percent of smallest dimension.
 		if ($width_orig > $height_orig)	//height dominated
@@ -134,7 +148,7 @@ function crop_image($filename, $crop_percent, $destfile, $crop_area)
 			$cropStartX = round($width_orig/2 - $cropH/2);
 		}
 	}
-	else if ($crop_area == "bottom")
+	elseif ($crop_area == "bottom")
 	{
 		//Crop to percent of smallest dimension.
 		if ($width_orig > $height_orig)	//height dominated
@@ -152,7 +166,7 @@ function crop_image($filename, $crop_percent, $destfile, $crop_area)
 			$cropStartX = round($width_orig/2 - $cropH/2);
 		}
 	}
-	else if ($crop_area == "left")
+	elseif ($crop_area == "left")
 	{
 		//Crop to percent of smallest dimension.
 		if ($width_orig > $height_orig)	//height dominated
@@ -170,7 +184,7 @@ function crop_image($filename, $crop_percent, $destfile, $crop_area)
 			$cropStartY = round($height_orig/2 - $cropW/2);
 		}
 	}
-	else if ($crop_area == "right")
+	elseif ($crop_area == "right")
 	{
 		//Crop to percent of smallest dimension.
 		if ($width_orig > $height_orig)	//height dominated
@@ -188,6 +202,21 @@ function crop_image($filename, $crop_percent, $destfile, $crop_area)
 			$cropStartY = round($height_orig/2 - $cropW/2);
 		}
 	}
+	elseif ($crop_area == "left-right")
+	{		
+		$cropW = round($width_orig * ((100 - 2 * $crop_percent)/100));
+		$cropH = $height_orig;	//rectangular crop
+		$cropStartX = round($width_orig * ($crop_percent/100));
+		$cropStartY = 0;
+	}
+	elseif ($crop_area == "top-bottom")
+	{
+		$cropH = round($height_orig * ((100 - 2 * $crop_percent)/100));
+		$cropW = $width_orig;	//rectangular crop
+		$cropStartY = round($height_orig * ($crop_percent/100));
+		$cropStartX = 0;
+	}
+//	echo "cropW: $cropW --- cropH: $cropH --- cropStartX: $cropStartX --- cropStartY: $cropStartY\n";
 	
 	// Create image to store cropped image in.
 	$cropimg = imagecreatetruecolor($cropW,$cropH);
