@@ -5,7 +5,7 @@
 // For licensing, see license.txt.
 // Created: 5/1/2015	ELL
 //
-function RunSQL($sql_string, $dbh, $table_prefix, $select = false, $show_progress = false, $rows_affected_msg = "row(s) affected.")
+function RunSQL($sql_string, $dbh, $table_prefix, $show_progress = false, $rows_affected_msg = "row(s) affected.")
 {
 //	$sql_string = stripslashes($sql_string);
 	$sql_string_arr = array();
@@ -28,6 +28,10 @@ function RunSQL($sql_string, $dbh, $table_prefix, $select = false, $show_progres
 			$first_chars = substr($curr_line, 0, 2);
 			if (($first_chars == "--") || ($first_chars == "//") || ($first_chars == "/*") || ($first_chars == ""))
 				continue;
+				
+			$got_select = false;
+			if (strtoupper(substr($curr_line, 0, 6)) == "SELECT")
+				$got_select = true;
 		}
 		$find_start = false;
 		
@@ -67,6 +71,7 @@ function RunSQL($sql_string, $dbh, $table_prefix, $select = false, $show_progres
 				$got_style = false;
 		}
 		
+		
 		// Build SQL command.
 		$sql_string_arr[$j] = $sql_string_arr[$j] . $line_arr[$i];
 		
@@ -100,33 +105,49 @@ function RunSQL($sql_string, $dbh, $table_prefix, $select = false, $show_progres
 				$sql_string_arr[$i] = str_replace("@@@var_retention@@@", "\$bwb_", $sql_string_arr[$i]);
 				$sql_string_arr[$i] = str_replace("@@@link_retention@@@", "bwb_dbh", $sql_string_arr[$i]);
 			}
-			if ($show_progress)
-				echo "SQL: " . htmlentities(substr($sql_string_arr[$i], 0, 100)) . "...<br><br>\n";
+			if ($show_progress)	{
+				echo "SQL: " . htmlentities(substr($sql_string_arr[$i], 0, 100));
+				if (strlen($sql_string_arr[$i]) > 100)
+					echo "...";
+				echo "<br /><br />\n";
+			}
 
 			try	{
-				if ($select === true)
+				if (($got_select == true) || ($got_select == 1))
 					$result = $dbh->query($sql_string_arr[$i]);
 				else
 					$result = $dbh->exec($sql_string_arr[$i]);
 			} catch (Exception $e) {
-				echo $e->getMessage() . "<br>\n";
+				echo $e->getMessage() . "<br />\n";
 			}
-			
+
 			if ($show_progress)
 			{
-				if (is_array($result))
-				{
+				if (is_array($result))	{
 					echo "<pre>\n";
 					print_r($result);
-					echo "</pre>\n";
+					echo "\n</pre>\n";
+				}
+				elseif (is_object($result))	{
+					while($row = $result->fetch(PDO::FETCH_ASSOC))
+					{
+						foreach($row as $field => $val)
+						{
+							echo "<b>" . $field . "</b> = " . htmlentities($val) . "<br />\n";
+						}
+					}
 				}
 				elseif ($result > 0)
-					echo $result . " " . $rows_affected_msg . "<br>\n";
-				else
-					echo $dbh->errorInfo() . "<br>\n";
+					echo $result . " " . $rows_affected_msg . "<br />\n";
+				elseif ($result === 0)
+					echo RUN_SQL_QUERY_SUCCESS_MSG . "<br />\n";
+				else	{
+					$err_arr = $dbh->errorInfo();
+					echo $err_arr[2] . " (SQL error: " . $err_arr[0] . ", PDO error: " . $err_arr[1] . ")<br />\n";
+				}
 					
 				if ($i < (count($sql_string_arr) - 1))
-					echo "<br>-------------------------------------------------------------------------------<br>\n";
+					echo "<br />-------------------------------------------------------------------------------<br />\n";
 			}
 		}
 	}
