@@ -36,6 +36,10 @@
 // Moved 'deployed' field to new table plugins_deployed.
 // Revised: 11/22/2017	ELL
 // Made "Users & Site Options" button modal switchig to "Manage My Account" when logged in as non-admin but at least user access level.
+// Revised: 4/27/2018	ELL
+// Added "Minify Files" button.
+// Revised: 11/23/2018	ELL
+// Modified to go to last selected module if session timed out and logging back in.
 	
 	include ("check_session.php");
 	
@@ -57,79 +61,24 @@
 		$website_file_path = "/" . BWB_BASE_DIR . "/";
 	else
 		$website_file_path = "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/";
+
+	if (isset($_SESSION['module']) && ($_SESSION['module'] != ""))	{
+		$_GET['module'] = $_SESSION['module'];
+		unset($_SESSION['module']);
+	}
+	elseif ($_SESSION['module'] === "")
+		unset($_SESSION['module']);
+		
+	if (isset($_SESSION['btn']) && ($_SESSION['btn'] != ""))	{
+		$_GET['btn'] = $_SESSION['btn'];
+		unset($_SESSION['btn']);
+	}
+	elseif ($_SESSION['btn'] === "")
+		unset($_SESSION['btn']);
 		
 	/////////// Determine Plugin Buttons ///////////////////////////
-	function custom_inArray($needle, $haystack) {
-	// $needle is string, but elements of array $haystack are also arrays.  If any element in array element
-	// matches string, return true, otherwise false.
-		foreach ($haystack as $value) {
-			if (in_array($needle, $value)) {
-				return true;
-			}
-		}
-		return false;
-	}
-
-	if ($access_level == "blogger")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE (T1.AccessLevel='blogger') AND (T2.deployed=1) ORDER BY T1.sort_order";
-	elseif ($access_level == "restricted")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted')) AND (T2.deployed=1) ORDER BY T1.sort_order";
-	elseif ($access_level == "user")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='') OR (T1.AccessLevel IS NULL)) AND (T2.deployed=1) ORDER BY T1.sort_order";
-	elseif ($access_level == "power_user")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='power_user') OR (T1.AccessLevel='') OR (T1.AccessLevel IS NULL)) AND (T2.deployed=1) ORDER BY T1.sort_order";
-	elseif ($access_level == "admin")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T2.deployed=1 ORDER BY T1.sort_order";
-		
-	$plugin_buttons = array();
-	$plugin_css = array();
-	$result = $bwb_dbh->query($query);
-	if (($result->rowCount() < 1) && (($access_level == "restricted") || ($access_level == "blogger")))
-		$show_other = false;
-	else
-		$show_other = true;
-	$i = 0;
-	$document_root = $_SERVER['DOCUMENT_ROOT'];
-	while ($row = $result->fetch(PDO::FETCH_ASSOC))
-	{
-		$console_path = $row['console_path'];
-		if (isset($console_path) && ($console_path != ""))
-		{
-			$console_link_text = $row['console_link_text'];
-			$console_link_image = $row['console_link_image'];
-			$console_link_image_mo = $row['console_link_image_mo'];
-			$console_link_image_down = $row['console_link_image_down'];
-			$language_folder = $row['language_folder'];
-			$console_link_text_define = $row['console_link_text_define'];
-			if (isset($row['menu_group']) && !is_null($row['menu_group']))
-				$menu_group = $row['menu_group'];
-			else
-				$menu_group = "";
-			if (isset($language_folder) && isset($console_link_text_define) && ($console_link_text_define != ""))
-			{
-				if (file_exists($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php"))
-					include_once ($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php");
-				else
-					include_once ($document_root . "/" . $language_folder . "/en.php");
-				if (defined($console_link_text_define) && (constant($console_link_text_define) != ""))
-					$console_link_text = constant($console_link_text_define);
-			}
-
-			if (!custom_inArray($console_path, $plugin_buttons))
-			{
-				$button_string = "<div class=\"button_top_level\" id=\"btn_custom_" . $i . "\" title=\"" . $console_link_text . "\" onClick=\"SetWorkspaceLocation('" . $console_path . "', this);\"><span class=\"button_text_top_level\">" . $console_link_text . "</span></div>\n";
-				
-				$css_string = "#btn_custom_" . $i . "	{	background-image:url(" . $console_link_image . ");	}\n";
-				$css_string .= "#btn_custom_" . $i . ":hover	{	background-image:url(" . $console_link_image_mo . ");	}\n";
-				$css_string .= "#btn_custom_" . $i . ".down	{	background-image:url(" . $console_link_image_down . ");	}\n";
-				
-				$plugin_buttons[$console_link_text] = array($console_path, $button_string, $menu_group, "$i");
-				$plugin_css[$console_link_text] = array($console_path, $css_string);
-				$i++;
-			}
-		}
-	}
-	$plugin_button_cnt = count($plugin_buttons);
+	$location = "main";
+	include ("generate_plugin_buttons.php");
 ?>
 <!doctype html>
 <html>
@@ -282,6 +231,7 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 		$i++;
 	}
 	
+	echo "	var http = '$http';\n";
 ?>
 
 </script>
@@ -404,11 +354,17 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 				echo "<div class=\"button_top_level\" id=\"btn_show_wizard\" title=\"" . MAIN_MENU_UPLOAD_TEMPLATE_BTN . "\" onClick=\"SetWorkspaceLocation('upload_template_confirm.php', this);\"><span class=\"button_text_top_level\">" . MAIN_MENU_UPLOAD_TEMPLATE_BTN . "</span></div>\n";
 		}
 ?>
+<?php if (($access_level == "admin") || ($access_level == "power_user"))	{	?>
+<div class="button_top_level" id="btn_minify_files" title="<?php echo MAIN_MENU_MINIFY_FILES; ?>" onClick="SetWorkspaceLocation('minify_file_select.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_MINIFY_FILES; ?></span></div>
+<?php	}	?>
 <div class="button_top_level" id="btn_users_site_options" title="<?php if ($access_level == "admin") echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT; else echo MAIN_MENU_MANAGE_MY_ACCOUNT_BTN; ?>" onClick="SetWorkspaceLocation('<?php if ($access_level == "admin") echo "admin_function_select.php"; else echo "users.php"; ?>', this);"><span class="button_text_top_level"><?php if ($access_level == "admin") echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN; else echo MAIN_MENU_MANAGE_MY_ACCOUNT_BTN; ?></span></div>
 </div>
 <?php } // access_level > restricted and blogger ?>
 </div>
 
+<?php if (defined('BWB_SITE_CNT') && (BWB_SITE_CNT > 1))	{	?>
+<div id="website_instance"><?php echo MAIN_MENU_EDITING_SITE . " " . $site_under_edit . " " . OF_WORD . " " . BWB_SITE_CNT; ?><span id="active_website"><?php echo WEBSITE_WORD . " " . BWB_ACTIVE_SITE . " " . MAIN_MENU_IS_ACTIVE; ?></span></div>
+<?php }	?>
 <div id="access_level"><?php echo ACCESS_LEVEL_WORD; ?>: <span class="access_level"><?php echo $access_level; ?></span></div>
 <div id="username"> <?php echo WELCOME_WORD . " "; if (($first_name != "") || ($last_name != "")) echo $first_name . " " . $last_name; else echo $userid; ?></div>
 
