@@ -17,11 +17,11 @@ else
 	$http = "http://";
 //////////////////// Breeze Website Builder modification ///////////////////////////
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<!DOCTYPE html>
 <html>
 <head>
 <title>KFM-maintenance</title>
-<script type="text/javascript" src="<?php echo $http; ?>://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
+<script type="text/javascript" src="<?php echo $http; ?>ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
 <script type="text/javascript">
 	var $j = jQuery.noConflict();
 	$j(document).ready(function(){
