@@ -24,6 +24,8 @@
 // Revised: 10/28/2016	ELL
 // Added list of pages to auto-populate suffix for new border areas to make creating border areas with meaningful names as default behavior,
 // and to allow for automatic assignment at border area creation.
+// Modified: 11/26/2019	ELL
+// Added visual indication of inactive pages.
 	
 	include ("check_session.php");
 ?>
@@ -55,6 +57,11 @@
 	width:220px;
 	margin-top:5px;
 }
+
+.button_heading_sub_level_1	{
+	margin-left: 5%;
+	margin-bottom: 3px;
+}
 </style>
 
 <script type="text/javascript" src="js/mouse_position.js"></script>
@@ -91,6 +98,9 @@
 	echo "	var TO_WORD = \"" . TO_WORD . "\";\n";
 	echo "	var MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR = \"" . MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR . "\";\n";
 	echo "	var MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR = \"" . MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR . "\";\n";
+	echo "	var INACTIVE_WORD = \"" . INACTIVE_WORD . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -100,9 +110,7 @@
 
 <div class='button_console_go_back' style="width:250px; position:absolute; right:40px; top:0px;" onClick="window.location.href='manage_border_area_select.php'"><span class='button_console_text_w_icon'><?php echo MANAGE_CUSTOM_BORDER_AREA_BACK_BTN; ?></span></div>
 
-<table width="90%" border="0" align="center"><tr><td>
 <div class="button_heading_sub_level_1" id="manage_custom_border_areas_heading"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_CUSTOM_BORDER_AREA_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
 
 <table width="90%" align="center" class="group_box_table"><tr>
   <td>
@@ -144,12 +152,17 @@
 <select id="new_suffix" name="new_suffix" onChange="UpdateSuffix(this.value);">
   <option value=""><?php echo _NOT_SELECTED_; ?></option>
 <?php
-	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
+	$query = "SELECT page_name, active FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
 	$result = $bwb_dbh->query($query);
 	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$page_name = $row['page_name'];
-		echo "	<option value='$page_name'>$page_name</option>\n";
+		$active = $row['active'];
+		if  ($active < 1)
+			$active_str = " (" . INACTIVE_WORD . ")";
+		else
+			$active_str = "";
+		echo "	<option value='$page_name'>$page_name$active_str</option>\n";
 	}
 ?>
   </select>
