@@ -14,6 +14,8 @@
 // Revised: 10/28/2016	ELL
 // Added list of pages to auto-populate suffix for new head content to make creating head content with meaningful names as default behavior,
 // and to allow for automatic assignment at head content creation.
+// Modified: 11/26/2019	ELL
+// Added visual indication of inactive pages.
 	
 	include ("check_session.php");
 	
@@ -40,6 +42,11 @@
 #add_head_btn	{	width:230px;	}
 #rename_head_btn	{	width:110px;	}
 #delete_head_btn	{	width:110px;	}
+
+.button_heading_sub_level_1	{
+	margin-left: 5%;
+	margin-bottom: 3px;
+}
 </style>
 
 <script type="text/javascript" src="js/mouse_position.js"></script>
@@ -80,6 +87,9 @@
 	echo "	var MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR = \"" . MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR . "\";\n";
 	echo "	var MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR = \"" . MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR . "\";\n";
 	echo "	var MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR = \"" . MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR . "\";\n";
+	echo "	var INACTIVE_WORD = \"" . INACTIVE_WORD . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -89,9 +99,7 @@
 
 <div class='button_console_go_back' style="width:220px; position:absolute; right:40px; top:0px;" onClick="window.location.href='edit_head_select.php'"><span class='button_console_text_w_icon'><?php echo MANAGE_HEAD_BACK_BTN; ?></span></div>
 
-<table width="90%" align="center"><tr><td>
 <div class="button_heading_sub_level_1" id="manage_users_site_options_heading"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_HEAD_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
 
 <table width="90%" align="center" class="group_box_table"><tr><td>
 <span class="sub_title"><?php echo MANAGE_HEAD_ADD_HEAD_CONTENT; ?></span>
@@ -102,12 +110,17 @@
   <select id="new_head_suffix" name="new_head_suffix" onChange="UpdateSuffix(this.value);">
   <option value=""><?php echo _NOT_SELECTED_; ?></option>
 <?php
-	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
+	$query = "SELECT page_name, active FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
 	$result = $bwb_dbh->query($query);
 	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$page_name = $row['page_name'];
-		echo "	<option value='$page_name'>$page_name</option>\n";
+		$active = $row['active'];
+		if  ($active < 1)
+			$active_str = " (" . INACTIVE_WORD . ")";
+		else
+			$active_str = "";
+		echo "	<option value='$page_name'>$page_name$active_str</option>\n";
 	}
 ?>
   </select>
@@ -177,7 +190,7 @@
 
 <?php include("lib/popup_msg.html"); ?>
 
-<script language="javascript" type="text/javascript">
+<script>
 	popup_msg.HidePopupMsg();
 </script>
 </body>
