@@ -71,6 +71,11 @@
 }
 
 #additional_user_fields	{	display:none;	}
+
+.button_heading_sub_level_1	{	
+	margin-left: 2.5%;
+	margin-bottom: 3px;
+}
 </style>
 
 <script type="text/javascript" src="js/json2.js"></script>
@@ -152,6 +157,8 @@
 	echo "	var MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR = \"" . MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR . "\";\n";
 	echo "	var FIRST_NAME = \"" . FIRST_NAME . "\";\n";
 	echo "	var LAST_NAME = \"" . LAST_NAME . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 
 var pages = new Array();
@@ -261,12 +268,10 @@ var access_level_remove = "-not set-";
 
 <body id="workspace_body">
 <br>
-<div align="center">
-<table width="95%" border="0"><tr>
-<td>
+
 <div class="button_heading_sub_level_1" id="manage_restricted_pages_users_heading"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_PAGE_ACCESS_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow('manage_page_access');">&nbsp;</div></div>
-</td>
-</tr></table>
+
+<div align="center">
 
 <table width="95%" border="1" cellspacing="0" cellpadding="5"><tr><td>
   <div id="PageRestrictionsTable">
@@ -304,10 +309,10 @@ var access_level_remove = "-not set-";
      <table border="0" width="95%" align="center">
       <tr id="user_nav_row_top">
         <td style="width:5%; text-align:center;">
-         <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_top" border="0" onClick="moveFirst();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+         <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_top" border="0" onClick="moveFirst();" style="cursor:pointer;" />
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_top" border="0" onClick="movePrev();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_top" border="0" onClick="movePrev();" style="cursor:pointer;" />
         </td>
         <td style="width:40%; text-align:center;" class="small_message">
             <?php echo SHOWING_RECORDS; ?> <span id="rcrd_start_top">&nbsp;</span> <?php echo THRU_WORD; ?> <span id="rcrd_end_top">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_rcrds_top">&nbsp;</span>
@@ -316,10 +321,10 @@ var access_level_remove = "-not set-";
         	<?php echo PAGE_1ST_CAP_WORD; ?> <span id="page_num_top">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_pages_top">&nbsp;</span>
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_top" border="0" onClick="moveNext();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_top" border="0" onClick="moveNext();" style="cursor:pointer;" />
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_top" border="0" onClick="moveLast();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_top" border="0" onClick="moveLast();" style="cursor:pointer;" />
         </td>
       </tr>
     </table>
@@ -335,10 +340,10 @@ var access_level_remove = "-not set-";
      <table border="0" width="95%" align="center">
       <tr id="user_nav_row_bot">
         <td style="width:5%; text-align:center;">
-         <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_bot" border="0" onClick="moveFirst();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+         <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_bot" border="0" onClick="moveFirst();" style="cursor:pointer;" />
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_bot" border="0" onClick="movePrev();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_bot" border="0" onClick="movePrev();" style="cursor:pointer;" />
         </td>
         <td style="width:40%; text-align:center;" class="small_message">
             <?php echo SHOWING_RECORDS; ?> <span id="rcrd_start_bot">&nbsp;</span> <?php echo THRU_WORD; ?> <span id="rcrd_end_bot">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_rcrds_bot">&nbsp;</span>
@@ -347,10 +352,10 @@ var access_level_remove = "-not set-";
         	<?php echo PAGE_1ST_CAP_WORD; ?> <span id="page_num_bot">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_pages_bot">&nbsp;</span>
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_bot" border="0" onClick="moveNext();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_bot" border="0" onClick="moveNext();" style="cursor:pointer;" />
         </td>
         <td style="width:5%; text-align:center;">
-          <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_bot" border="0" onClick="moveLast();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
+          <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_bot" border="0" onClick="moveLast();" style="cursor:pointer;" />
         </td>
       </tr>
     </table>
