@@ -14,6 +14,8 @@
 // Moved attribute setting to new column to accomodate longer layout template list.
 // Revised: 5/26/2016	ELL
 // Added function string checking to standardize entry of function call.
+// Revised: 5/1/2018	ELL
+// Added on-the-fly minification of all content.
 // 
 
 	include ("check_session.php");
@@ -61,6 +63,8 @@
 	$row2 = $result2->fetch(PDO::FETCH_ASSOC);
 	$option_value_selected = $row2["option_value"];
 	echo "\nvar option_value_selected = '$option_value_selected';\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 </script>
 
@@ -183,6 +187,8 @@
         <?php echo MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_BOTTOM; ?><br />
         <input type="checkbox" id="insert_default_footer" name="insert_default_footer" />
         <?php echo MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_FOOTER; ?><br />
+        <input type="checkbox" id="minify" name="minify" />
+        <?php echo MANAGE_PAGE_ATTRIBUTES_MINIFY; ?><br />
         
         <div class='button_console_save' onClick="SavePageAttributes();" id="save_attributes_btn"><span class='button_console_text_w_icon'><?php echo UPDATE_WORD; ?></span></div>
         
