@@ -26,10 +26,15 @@
 // Revised: 3/14/2017	BAK
 // Added additional classes for down state.
 // Revised: 8/18/2017	ELL
-// Added ability to to top-level item in down state if sub-level item is down.
+// Added ability to top-level item in down state if sub-level item is down.
 // Revised: 10/3/2017	ELL
 // Modified down-state testing to compare to base URL to page name instead of full URL to handle possibility of parameters being passed
 // that cause page name to be otherwise obscurred.
+// Modified: 7/12/2018	ELL
+// Abandoned techniche of replacing <a> with <span> in the event that URL is blank, and adopting making URL = #! instead.
+// This was done to keep the HTML uniform such that styles are applied consistantly.
+// Modified: 11/26/2019	ELL
+// Added supression of inactive pages.
 // 
 
 	$default_menu_width = 900;
@@ -248,6 +253,16 @@
 					{
 						if ($row2['level'] > 0)	{
 							$URL = $row2['URL'];
+							//----- Check to make sure page is active. -----//
+							$page_name = str_replace(".php", "", $URL);
+							$query = "SELECT `active` FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name` = '" . $page_name . "'";
+							$result3 = $bwb_dbh->query($query);
+							if ($result3->rowCount() > 0)	{
+								$row3 = $result3->fetch(PDO::FETCH_ASSOC);
+								if ($row3['active'] < 1)
+									continue;
+							}
+							//----- Check to make sure page is active. -----//
 							if ((SEF_URL == 1) && isset($URL) && ($URL != ""))
 							{
 								if (stripos($URL, "http") === false)
@@ -281,10 +296,15 @@
 		
 		// Initialize navigation HTML.
 		$last_level = 0;
-		echo "\n<div class='menu_div" . $suffix . "' id='menu_div" . $suffix . "'>\n";
+		$n = "\n";
 		$one_indent = "   ";
+		if ($minify == 1)	{
+			$n = "";
+			$one_indent = "";
+		}
 		$indent = $one_indent;
-		echo $indent . "<ul class='top_level_ul" . $suffix . " nav" . $suffix . "'>\n";
+		echo $n."<div class='menu_div" . $suffix . "' id='menu_div" . $suffix . "'>".$n;
+		echo $indent . "<ul class='top_level_ul" . $suffix . " nav" . $suffix . "'>".$n;
 		
 		// Get items and build navigation HTML.
 		$list_item_not_closed = 0;
@@ -295,6 +315,16 @@
 			$item_text = stripslashes($row['item_text']);
 			$level = $row['level'];
 			$URL = $row['URL'];
+			//----- Check to make sure page is active. -----//
+			$page_name = str_replace(".php", "", $URL);
+			$query = "SELECT `active` FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name` = '" . $page_name . "'";
+			$result3 = $bwb_dbh->query($query);
+			if ($result3->rowCount() > 0)	{
+				$row3 = $result3->fetch(PDO::FETCH_ASSOC);
+				if ($row3['active'] < 1)
+					continue;
+			}
+			//----- Check to make sure page is active. -----//
 			if ((SEF_URL == 1) && isset($URL) && ($URL != ""))
 			{
 				if (stripos($URL, "http") === false)
@@ -458,16 +488,14 @@
 				$down_class_span = "";
 			}
 			
-			if (isset($URL) && ($URL != ""))
-				$a = "a";
-			else
-				$a = "span";
+			if (!isset($URL) || ($URL == ""))
+				$URL = "#!";
 				
 			if ($level == $last_level)
 			{
 				if ($list_item_not_closed > 0)
 				{
-					echo "</li>\n";	// No change in levels, close off list item.
+					echo "</li>".$n;	// No change in levels, close off list item.
 					$list_item_not_closed--;
 				}
 				$item_class = "menu" . $suffix . "_item" . $item;
@@ -477,8 +505,8 @@
 						$width_prefix = "min-";
 					else
 						$width_prefix = "";
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='"
-					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='"
+					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -488,8 +516,8 @@
 					}
 				}
 				else	{
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='" . $URL 
-					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='" . $URL 
+					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -504,7 +532,7 @@
 			elseif ($level > $last_level)	// Going deeper into sub levels, nest next ul inside of li.
 			{
 				$indent .= $one_indent;
-				echo "\n" . $indent . "<ul class='" . $class_ul . "'>\n";
+				echo $n . $indent . "<ul class='" . $class_ul . "'>".$n;
 				$item_class = "menu" . $suffix . "_item" . $item;
 				$item_li_class = "menu" . $suffix . "_item" . $item . "_li";
 				if((($proportional == 1) && ($level == 0)) || (($proportional_sub == 1) && ($level > 0)))	{
@@ -512,8 +540,8 @@
 						$width_prefix = "min-";
 					else
 						$width_prefix = "";
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='"
-					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='"
+					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -523,8 +551,8 @@
 					}
 				}
 				else	{
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='" . $URL 
-					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='" . $URL 
+					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -538,15 +566,15 @@
 			}
 			elseif ($level < $last_level)
 			{
-				echo "</li>\n";	// Coming out of sub level, close off this list item and one ul is nested in.
+				echo "</li>".$n;	// Coming out of sub level, close off this list item and one ul is nested in.
 				$level_diff = $last_level - $level;
 				while ($level_diff > 0)
 				{
-					echo $indent . "</ul>\n";
+					echo $indent . "</ul>".$n;
 					$indent = substr($indent, 3);
 					if ($list_item_not_closed > 0)
 					{
-						echo $indent . $one_indent . "</li>\n";
+						echo $indent . $one_indent . "</li>".$n;
 						$list_item_not_closed--;
 					}
 					$level_diff--;
@@ -558,8 +586,8 @@
 						$width_prefix = "min-";
 					else
 						$width_prefix = "";
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='"
-					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='"
+					. $URL . "' target='" . $target . "' class='" . $class_a . "' style='" . $width_prefix . "width:" . $item_width . "px;'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -569,8 +597,8 @@
 					}
 				}
 				else	{
-					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><$a href='" . $URL 
-					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</$a></span>";
+					echo $indent . $one_indent . "<li class='" . $class_li . " " . $item_li_class . "'><span class='" . $item_class . "'><a href='" . $URL 
+					. "' target='" . $target . "' class='" . $class_a . "'>" . $down_class_span . $item_text . $down_class_span_end . "</a></span>";
 					if (isset($mega_menu) && ($mega_menu != ""))	{
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $mega_menu . "'";
 						$result2 = $bwb_dbh->query($query);
@@ -586,21 +614,21 @@
 			$last_level = $level;
 		}
 		
-		echo "</li>\n";		// Close last list item.
+		echo "</li>".$n;		// Close last list item.
 		$list_item_not_closed--;
 		
 		while ($last_level > 0)
 		{
-			echo $indent . "</ul>\n";
+			echo $indent . "</ul>".$n;
 			if ($list_item_not_closed > 0)
 			{
-				echo $indent . "</li>\n";	// If list item open then close it.
+				echo $indent . "</li>".$n;	// If list item open then close it.
 				$list_item_not_closed--;
 			}
 			$indent = substr($indent, 3);
 			$last_level--;
 		}
-		echo $indent . "</ul>\n";
-		echo "</div>\n";
+		echo $indent . "</ul>".$n;
+		echo "</div>".$n;
 	}
 ?>
\ No newline at end of file
