@@ -6,6 +6,8 @@
 // Created:	3/10/2013	ELL
 // Revised: 6/11/2015	ELL
 // Added ability to handle GIF and PNG images is additon to JPG images.
+// Revised: 8/3/2016	ELL
+// Fixed bugs when no dimensions specified for image.
 
 	include ("check_session.php");
 	include ("lib/image_processing.php");
@@ -32,59 +34,76 @@
 			mkdir($orig_image_path, 0755);
 		
 		$bad_chars = array("\"", "px", "%");
+		$img_ext = array("jpg", "jpeg", "png", "gif");
 		$last_img_tag_pos = 0;
 		while ((strpos($sValue, "<img ", $last_img_tag_pos)) > 1)
 		{
 			$img_tag_pos = strpos($sValue, "<img ", $last_img_tag_pos);
 			$last_img_tag_pos = $img_tag_pos + strlen("<img ");
+			$next_img_tag_pos = strpos($sValue, "<img ", $last_img_tag_pos);
+			if ($next_img_tag_pos === false)
+				$next_img_tag_pos = strlen($sValue);
 			
 			$src_att_pos = strpos($sValue, "src=", $img_tag_pos);
 			$end_src_pos = strpos($sValue, "\"", $src_att_pos + strlen("src=") + 2);
 			$start_src_pos = $src_att_pos + strlen("src=") + 1;
 			$src = substr($sValue, $start_src_pos, $end_src_pos - $start_src_pos);
-			$tmp = substr($src, strlen($src) - strlen("jpg"));	//jpg, jpeg
-			$img_ext = array("jpg", "peg", "JPG", "PEG", "Jpg", "png", "PNG", "Png", "gif", "GIF", "Gif");
+			$src_parts = explode(".", $src);
+			$tmp = strtolower($src_parts[count($src_parts) - 1]);
 			if (!in_array($tmp, $img_ext))
 				continue;			//jpeg, gif or png not found, can't process
+				
+			$src = str_replace("%20", " ", $src);	// The %20 substitution for spaces break it.
+			if (substr($src, 0, 1) != "/")
+				$src = "/" . $src;
+			$image_path = $doc_root . $src;
+			$image_file = basename($src);
+			$orig_image_path_file = $orig_image_path . "/" . $image_file;
+			list($width_orig, $height_orig) = getimagesize($image_path);
 			
 			$height_att_pos = strpos($sValue, "height", $img_tag_pos);
-			$end_height_pos_1 = strpos($sValue, "\"", $height_att_pos + strlen("height") + 2);
-			$end_height_pos_2 = strpos($sValue, ";", $height_att_pos + strlen("height") + 2);
-			if (($end_height_pos_1 === false))
-				$end_height_pos = $end_height_pos_2;
-			elseif (($end_height_pos_2 === false))
-				$end_height_pos = $end_height_pos_1;
-			elseif ($end_height_pos_1 <  $end_height_pos_2)
+			if (($height_att_pos < $img_tag_pos) || ($height_att_pos > $next_img_tag_pos))	{
+				// Height attribute not found, use actual image height.
+				$height = $height_orig;
+			}
+			else	{
+				$end_height_pos_1 = strpos($sValue, "\"", $height_att_pos + strlen("height") + 2);
+				$end_height_pos_2 = strpos($sValue, ";", $height_att_pos + strlen("height") + 2);
+				if (($end_height_pos_1 === false))
+					$end_height_pos = $end_height_pos_2;
+				elseif (($end_height_pos_2 === false))
 					$end_height_pos = $end_height_pos_1;
-			else
-				$end_height_pos = $end_height_pos_2;
-			
-			$start_height_pos = $height_att_pos + strlen("height") + 1;
-			$height = substr($sValue, $start_height_pos, $end_height_pos - $start_height_pos);
-			$height = str_replace($bad_chars, "", $height);
+				elseif ($end_height_pos_1 <  $end_height_pos_2)
+						$end_height_pos = $end_height_pos_1;
+				else
+					$end_height_pos = $end_height_pos_2;
+				
+				$start_height_pos = $height_att_pos + strlen("height") + 1;
+				$height = substr($sValue, $start_height_pos, $end_height_pos - $start_height_pos);
+				$height = str_replace($bad_chars, "", $height);
+			}
 			
 			$width_att_pos = strpos($sValue, "width", $img_tag_pos);
-			$end_width_pos_1 = strpos($sValue, "\"", $width_att_pos + strlen("width") + 2);
-			$end_width_pos_2 = strpos($sValue, ";", $width_att_pos + strlen("width") + 2);
-			if (($end_width_pos_1 === false))
-				$end_width_pos = $end_width_pos_2;
-			elseif (($end_width_pos_2 === false))
-				$end_width_pos = $end_width_pos_1;
-			elseif ($end_width_pos_1 <  $end_width_pos_2)
+			if (($width_att_pos < $img_tag_pos) || ($width_att_pos > $next_img_tag_pos))	{
+				// width attribute not found, use actual image width.
+				$width = $width_orig;
+			}
+			else	{
+				$end_width_pos_1 = strpos($sValue, "\"", $width_att_pos + strlen("width") + 2);
+				$end_width_pos_2 = strpos($sValue, ";", $width_att_pos + strlen("width") + 2);
+				if (($end_width_pos_1 === false))
+					$end_width_pos = $end_width_pos_2;
+				elseif (($end_width_pos_2 === false))
 					$end_width_pos = $end_width_pos_1;
-			else
-				$end_width_pos = $end_width_pos_2;
-				
-			$start_width_pos = $width_att_pos + strlen("width") + 1;
-			$width = substr($sValue, $start_width_pos, $end_width_pos - $start_width_pos);
-			$width = str_replace($bad_chars, "", $width);
-			
-			$src = str_replace("%20", " ", $src);	// The %20 substitution for spaces break it.
-			$image_path = $doc_root . $src;
-			$image_file = substr($src, strrpos($src, "/") + 1);
-			$orig_image_path_file = $orig_image_path . "/" . $image_file;
-			
-			list($width_orig, $height_orig) = getimagesize($image_path);
+				elseif ($end_width_pos_1 <  $end_width_pos_2)
+						$end_width_pos = $end_width_pos_1;
+				else
+					$end_width_pos = $end_width_pos_2;
+					
+				$start_width_pos = $width_att_pos + strlen("width") + 1;
+				$width = substr($sValue, $start_width_pos, $end_width_pos - $start_width_pos);
+				$width = str_replace($bad_chars, "", $width);
+			}
 			
 			if (!file_exists($orig_image_path_file))
 			{
@@ -122,6 +141,7 @@
 		$success = 0;
 		$fail = 0;
 		$last_img_tag_pos = 0;
+		$img_ext = array("jpg", "jpeg", "png", "gif");
 		while ((strpos($sValue, "<img ", $last_img_tag_pos)) > 1)
 		{
 			$img_tag_pos = strpos($sValue, "<img ", $last_img_tag_pos);
@@ -131,14 +151,16 @@
 			$end_src_pos = strpos($sValue, "\"", $src_att_pos + strlen("src=") + 2);
 			$start_src_pos = $src_att_pos + strlen("src=") + 1;
 			$src = substr($sValue, $start_src_pos, $end_src_pos - $start_src_pos);
-			$tmp = substr($src, strlen($src) - strlen("jpg"));	//jpg, jpeg
-			$img_ext = array("jpg", "peg", "JPG", "PEG", "Jpg", "png", "PNG", "Png", "gif", "GIF", "Gif");
+			$src_parts = explode(".", $src);
+			$tmp = strtolower($src_parts[count($src_parts) - 1]);
 			if (!in_array($tmp, $img_ext))
 				continue;			//jpeg, gif or png not found, image was never optimized.
 			
 			$src = str_replace("%20", " ", $src);	// The %20 substitution for spaces break it.
+			if (substr($src, 0, 1) != "/")
+				$src = "/" . $src;
 			$image_path = $doc_root . $src;
-			$image_file = substr($src, strrpos($src, "/") + 1);
+			$image_file = basename($src);
 			$orig_image_path_file = $orig_image_path . "/" . $image_file;
 			
 			if (file_exists($orig_image_path_file))
