@@ -38,17 +38,24 @@
 
 <style type="text/css">
 #save_options_btn	{	width:110px;	}
+
+.button_heading_sub_level_1	{
+	margin-left: 10%;
+	margin-bottom: 3px;
+}
 </style>
 
-<script type="text/javascript" src="js/jquery.min.js"></script>
-<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
-<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
-<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
-<script language="javascript" type="text/javascript" src="js/options.js"></script>
+<script src="js/jquery.min.js"></script>
+<script src="js/browser_detect.js"></script>
+<script src="js/mouse_position.js"></script>
+<script src="js/popup_msg.js"></script>
+<script src="js/options.js"></script>
 <script>
 <?php
 	echo "	var MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG = \"" . MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG . "\";\n";
 	echo "	var MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR = \"" . MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR . "\";\n";
+	
+	echo "	var http = '$http';\n";
 ?>
 
 	var option_image = 
@@ -89,12 +96,11 @@
 <body>
 <br>
 <form name="frmChangeOptions" id="frmChangeOptions" method="post" action="save_options.php">
+
+	<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_SITE_OPTIONS_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
+    
 <div align="center">
 
-	<table width="80%" border="0"><tr><td>
-	<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_SITE_OPTIONS_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
-    </td></tr></table>
-    
 	<table width="80%" class="layout_box_table">
 	<tr bgcolor='#CCCCCC'><td class="sub_title"><?php echo OPTION_WORD; ?></td><td class="sub_title"><?php echo VALUE_WORD; ?></td><td>&nbsp;</td></tr>
 <?php
