@@ -6,6 +6,9 @@
 // Created: 12/13/2013	ELL
 // Revised: 6/19/2017	ELL
 // Moved 'deployed' field to new table plugins_deployed.
+// Revised: 4/29/2019	ELL
+// Converted referenceing of deployed plugins from using 'plugin_id' to 'name'. This is because the SQL REPLACE command used to update aftermarket plugin records 
+// causes the id field to increment in the 'plugins' table only, making it out-of-sync with the 'plugins_deployed' table.
 // 
 //
 	include ("check_session.php");
@@ -24,11 +27,11 @@
 	if ($access_level != "restricted")
 	{
 		if ($access_level == "user")
-			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='restricted') OR (T1.AccessLevel='user')) AND (T2.deployed=1)";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.name = T2.name WHERE ((T1.AccessLevel='restricted') OR (T1.AccessLevel='user')) AND (T2.deployed=1)";
 		elseif ($access_level == "power_user")
-			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='power_user')) AND (T2.deployed=1)";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.name = T2.name WHERE ((T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='power_user')) AND (T2.deployed=1)";
 		elseif ($access_level == "admin")
-			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T2.deployed=1";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.name = T2.name WHERE T2.deployed=1";
 			
 		$plugin_buttons = array();
 		$plugin_css = array();
