@@ -384,17 +384,20 @@ function MoveItemDown(i)
 function SaveSortOrder()
 {
 	var cnt = parseInt(document.getElementById("nCount").value);
-	var image_ctl;
+	var image_ctl, title_ctl;
 	var image_arr = new Array();
+	var title_arr = new Array();
 	for (var i = 0; i < cnt; i++)
 	{
 		image_ctl = "image" + i;
+		title_ctl = "title" + i;
 		image_arr[i] = document.getElementById(image_ctl).value;
+		title_arr[i] = document.getElementById(title_ctl).value;
 	}
-	$.post( "save_gallery_sort_order.php", { 'images[]': image_arr } ).done(CompleteSaveSortOrder) ;
+	$.post( "save_gallery_sort_order.php", { 'images[]': image_arr, 'titles[]': title_arr } ).done(CompleteSaveSortOrder) ;
 }
 function CompleteSaveSortOrder(data)
-{	
+{
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 1;
