@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "vorm Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Jy kan meer as een ontvanger ingestel deur die skeiding van die e-pos met kommas.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "ontvanger spaar ...");
+define('VIEW_FORM_TABLES_HEADING', "View Form Tables");
+define('VIEW_FORM_TABLES_BTN', "View Form Tables");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Kies &#39;n tafels om te sien");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter lees boodskappe");
 ?>
\ No newline at end of file
