@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "شكل الصفحة");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "قد قمت بتعيين أكثر من مستلم عن طريق الفصل بين رسائل البريد الإلكتروني مع الفواصل.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "إنقاذ المتلقي ...");
+define('VIEW_FORM_TABLES_HEADING', "عرض جداول النموذج");
+define('VIEW_FORM_TABLES_BTN', "عرض جداول النموذج");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "حدد جداول للعرض");
+define('VIEW_FORM_TABLES_FILTER_READ', "تصفية قراءة الرسائل");
 ?>
\ No newline at end of file
