@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form səhifə");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Siz virgülle ilə e-poçt ayıraraq bir çox alıcı müəyyən edə bilər.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "alan Saving ...");
+define('VIEW_FORM_TABLES_HEADING', "Form Tablolarını Baxın");
+define('VIEW_FORM_TABLES_BTN', "Form Tablolarını Baxın");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Baxmaq üçün bir masa seçin");
+define('VIEW_FORM_TABLES_FILTER_READ', "Mesajları oxuyun");
 ?>
\ No newline at end of file
