@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "форма старонкі");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Вы можаце ўсталяваць больш аднаго атрымальніка, падзяляючы лісты з коскамі.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Захаванне атрымальніка ...");
+define('VIEW_FORM_TABLES_HEADING', "Прагляд Форма табліцы");
+define('VIEW_FORM_TABLES_BTN', "Прагляд Форма табліцы");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Выберыце табліцы для прагляду");
+define('VIEW_FORM_TABLES_FILTER_READ', "Фільтр Чытанне паведамленняў");
 ?>
\ No newline at end of file
