@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Форма Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Може да зададете повече от един получател чрез отделяне на имейли със запетаи.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Запазване на получател ...");
+define('VIEW_FORM_TABLES_HEADING', "Преглед на таблици с формуляри");
+define('VIEW_FORM_TABLES_BTN', "Преглед на таблици с формуляри");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Изберете таблици, които да видите");
+define('VIEW_FORM_TABLES_FILTER_READ', "Филтриране на четене на съобщения");
 ?>
\ No newline at end of file
