@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "ফরম পাতা");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "আপনি কমা দিয়ে ইমেল পৃথক একাধিক প্রাপকের সেট করতে পারেন.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "প্রাপক সংরক্ষণ করা হচ্ছে ...");
+define('VIEW_FORM_TABLES_HEADING', "ফরম টেবিল দেখুন");
+define('VIEW_FORM_TABLES_BTN', "ফরম টেবিল দেখুন");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "দেখতে একটি টেবিল নির্বাচন করুন");
+define('VIEW_FORM_TABLES_FILTER_READ', "ফিল্টার পড়ুন বার্তা");
 ?>
\ No newline at end of file
