@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "forma Pàgina");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Vostè pot configurar més d&#39;un destinatari mitjançant la separació dels missatges de correu electrònic amb comes.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Estalvi de receptor ...");
+define('VIEW_FORM_TABLES_HEADING', "Vegeu Taules de formularis");
+define('VIEW_FORM_TABLES_BTN', "Vegeu Taules de formularis");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Seleccioneu les taules a visualitzar");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtra els missatges de lectura");
 ?>
\ No newline at end of file
