@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formulář Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Můžete nastavit více než jednoho příjemce oddělením e-maily s čárkami.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ukládání příjemce ...");
+define('VIEW_FORM_TABLES_HEADING', "Zobrazit tabulky formulářů");
+define('VIEW_FORM_TABLES_BTN', "Zobrazit tabulky formulářů");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Vyberte tabulky, které chcete zobrazit");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtr čtení zpráv");
 ?>
\ No newline at end of file
