@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "ffurflen Tudalen");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Efallai y byddwch yn gosod mwy nag un derbynnydd drwy wahanu y negeseuon e-bost gyda atalnodau.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Arbed derbynnydd ...");
+define('VIEW_FORM_TABLES_HEADING', "Gweld Tablau Ffurflen");
+define('VIEW_FORM_TABLES_BTN', "Gweld Tablau Ffurflen");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Dewis Tablau i View");
+define('VIEW_FORM_TABLES_FILTER_READ', "Negeseuon Read Filter");
 ?>
\ No newline at end of file
