@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Side");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Du kan indstille mere end én modtager ved at adskille e-mails med komma.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Gemmer modtager ...");
+define('VIEW_FORM_TABLES_HEADING', "Se formularer");
+define('VIEW_FORM_TABLES_BTN', "Se formularer");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Vælg en tabel til visning");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Læs meddelelser");
 ?>
\ No newline at end of file
