@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Formularseite");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Sie können mehr als einen Empfänger festgelegt durch die E-Mails durch Komma trennen.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Speichern Empfänger ...");
+define('VIEW_FORM_TABLES_HEADING', "Formulartabellen anzeigen");
+define('VIEW_FORM_TABLES_BTN', "Formulartabellen anzeigen");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Wählen Sie eine Tabelle zum Anzeigen aus");
+define('VIEW_FORM_TABLES_FILTER_READ', "Lesen Sie die Nachrichten");
 ?>
\ No newline at end of file
