@@ -9,9 +9,13 @@
 // Buttons:
 define('FORM_RECIPIENTS_HEADING', "Edit Form Recipients");
 define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Form Recipients");
+define('VIEW_FORM_TABLES_HEADING', "View Form Tables");
+define('VIEW_FORM_TABLES_BTN', "View Form Tables");
 // Console Text:
 define('FORM_RECIPIENTS_FORM_PAGE', "Form Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "You may set more than one recipient by separating the emails with commas.");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Select a Tables to View");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Saving recipient...");
 ?>
\ No newline at end of file
