@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formo Paĝo");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Vi povas agordi pli ol unu adresaton disigante la retpoŝtoj kun komoj.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ŝparante ricevonto ...");
+define('VIEW_FORM_TABLES_HEADING', "View Form Tables");
+define('VIEW_FORM_TABLES_BTN', "View Form Tables");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Select a Tables to View");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
 ?>
\ No newline at end of file
