@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "forma Página");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Usted puede configurar más de un destinatario mediante la separación de los mensajes de correo electrónico con comas.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ahorro de receptor ...");
+define('VIEW_FORM_TABLES_HEADING', "Ver tablas de formularios");
+define('VIEW_FORM_TABLES_BTN', "Ver tablas de formularios");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Seleccione una tabla para ver");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrar leer mensajes");
 ?>
\ No newline at end of file
