@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Vorm Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Sul võib määrata rohkem kui ühele saajale, eraldades kirju komadega.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvestamine saaja ...");
+define('VIEW_FORM_TABLES_HEADING', "Kuva vormide tabelid");
+define('VIEW_FORM_TABLES_BTN', "Kuva vormide tabelid");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Valige tabelid vaatamiseks");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtreeri sõnumite lugemist");
 ?>
\ No newline at end of file
