@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Formulario Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Hartzaile bat baino gehiago ezar ditzakezu komaz emailak bereiztuz.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "hartzaile gordetzen ...");
+define('VIEW_FORM_TABLES_HEADING', "Ikusi formularioa taulak");
+define('VIEW_FORM_TABLES_BTN', "Ikusi formularioa taulak");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Hautatu Ikusi taulak");
+define('VIEW_FORM_TABLES_FILTER_READ', "Iragazi irakurri mezuak");
 ?>
\ No newline at end of file
