@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "فرم صفحه");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "شما ممکن است بیش از یک گیرنده با جدا کردن ایمیل با کاما از هم تنظیم شده است.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "صرفه جویی در گیرنده ...");
+define('VIEW_FORM_TABLES_HEADING', "نمایش جداول فرم");
+define('VIEW_FORM_TABLES_BTN', "نمایش جداول فرم");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "جداول نمایش را انتخاب کنید");
+define('VIEW_FORM_TABLES_FILTER_READ', "فیلتر پیام های خوانده شده را فیلتر کنید");
 ?>
\ No newline at end of file
