@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Voit määrittää useamman kuin yhden vastaanottajan erottamalla sähköpostit pilkulla.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Tallennetaan vastaanottaja ...");
+define('VIEW_FORM_TABLES_HEADING', "Näytä lomaketjut");
+define('VIEW_FORM_TABLES_BTN', "Näytä lomaketjut");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Valitse näytettävät taulukot");
+define('VIEW_FORM_TABLES_FILTER_READ', "Suodata lukea viestejä");
 ?>
\ No newline at end of file
