@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Vous pouvez définir plusieurs destinataires en séparant les e-mails par des virgules.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Enregistrement destinataire ...");
+define('VIEW_FORM_TABLES_HEADING', "Voir les tableaux de formulaire");
+define('VIEW_FORM_TABLES_BTN', "Voir les tableaux de formulaire");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Sélectionner une table à afficher");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrer les messages lus");
 ?>
\ No newline at end of file
