@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "foirm");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Is féidir leat a leagtar faighteoir níos mó ná aon trí scaradh na ríomhphoist le camóga.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Shábháil faighteoir ...");
+define('VIEW_FORM_TABLES_HEADING', "Féach Táblaí Foirme");
+define('VIEW_FORM_TABLES_BTN', "Féach Táblaí Foirme");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Roghnaigh Táblaí le Seiceáil");
+define('VIEW_FORM_TABLES_FILTER_READ', "Scagadh Teachtaireachtaí");
 ?>
\ No newline at end of file
