@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Formulario de Páxina");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Podes establecer máis dun destinatario, separando os correos con comas.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvando destinatario ...");
+define('VIEW_FORM_TABLES_HEADING', "Ver táboas de formularios");
+define('VIEW_FORM_TABLES_BTN', "Ver táboas de formularios");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Seleccione unha táboa para ver");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtro de mensaxes de lectura");
 ?>
\ No newline at end of file
