@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "ફોર્મ પેજમાં");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "તમે અલ્પવિરામ સાથે ઇમેઇલ્સ અલગ કરીને એક કરતાં વધુ મેળવનાર સેટ કરી શકે છે.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "પ્રાપ્તકર્તા સાચવી ...");
+define('VIEW_FORM_TABLES_HEADING', "ફોર્મ કોષ્ટકો જુઓ");
+define('VIEW_FORM_TABLES_BTN', "ફોર્મ કોષ્ટકો જુઓ");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "જોવા માટે કોષ્ટકો પસંદ કરો");
+define('VIEW_FORM_TABLES_FILTER_READ', "ફિલ્ટર વાંચો સંદેશાઓ");
 ?>
\ No newline at end of file
