@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "पर्चा पृष्ठ");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "आप अल्पविराम के साथ ईमेल को अलग करके एक से अधिक प्राप्तकर्ता सेट कर सकते हैं।");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "प्राप्तकर्ता की बचत ...");
+define('VIEW_FORM_TABLES_HEADING', "फॉर्म टेबल्स देखें");
+define('VIEW_FORM_TABLES_BTN', "फॉर्म टेबल्स देखें");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "देखने के लिए एक सारणी का चयन करें");
+define('VIEW_FORM_TABLES_FILTER_READ', "फ़िल्टर पढ़ें संदेश");
 ?>
\ No newline at end of file
