@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Obrazac stranice");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Možete postaviti više od jednog primatelja odvajanjem e-pošte zarezima.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Spremanje primatelja ...");
+define('VIEW_FORM_TABLES_HEADING', "Pogledajte tablice obrasca");
+define('VIEW_FORM_TABLES_BTN', "Pogledajte tablice obrasca");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Odaberite tablice za prikaz");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtriranje poruka za čitanje");
 ?>
\ No newline at end of file
