@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form oldal");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Be lehet állítani egynél több fogadó elválasztva az e-maileket vesszővel.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Mentése címzett ...");
+define('VIEW_FORM_TABLES_HEADING', "Táblázatok megtekintése");
+define('VIEW_FORM_TABLES_BTN', "Táblázatok megtekintése");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Válassza ki a megtekinteni kívánt táblázatokat");
+define('VIEW_FORM_TABLES_FILTER_READ', "Szűrő Olvasott üzenetek");
 ?>
\ No newline at end of file
