@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Halaman");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Anda dapat menetapkan lebih dari satu penerima dengan memisahkan email dengan koma.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Menyimpan penerima ...");
+define('VIEW_FORM_TABLES_HEADING', "Lihat Tabel Formulir");
+define('VIEW_FORM_TABLES_BTN', "Lihat Tabel Formulir");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Pilih Tabel untuk Lihat");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Baca Pesan");
 ?>
\ No newline at end of file
