@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "form Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Þú getur sett fleiri en einn viðtakanda með því að aðgreina tölvupóst með kommum.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Saving viðtakanda ...");
+define('VIEW_FORM_TABLES_HEADING', "Skoða form töflur");
+define('VIEW_FORM_TABLES_BTN', "Skoða form töflur");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Veldu töflur til að skoða");
+define('VIEW_FORM_TABLES_FILTER_READ', "Sía Lesa Skilaboð");
 ?>
\ No newline at end of file
