@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "modulo Pagina");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "È possibile impostare più di un destinatario separando le e-mail con una virgola.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvataggio destinatario ...");
+define('VIEW_FORM_TABLES_HEADING', "Visualizza tabelle form");
+define('VIEW_FORM_TABLES_BTN', "Visualizza tabelle form");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Seleziona una tabella da visualizzare");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtra i messaggi letti");
 ?>
\ No newline at end of file
