@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "עמוד טופס");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "אתה יכול להגדיר ליותר מנמען אחד על ידי הפרדת המיילים עם פסיקים.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "שמירת הנמען ...");
+define('VIEW_FORM_TABLES_HEADING', "הצג טבלאות טופס");
+define('VIEW_FORM_TABLES_BTN', "הצג טבלאות טופס");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "בחר טבלאות לתצוגה");
+define('VIEW_FORM_TABLES_FILTER_READ', "מסנן קרא הודעות");
 ?>
\ No newline at end of file
