@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "フォームページ");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "あなたは、カンマでメールを分離することにより、複数の受信者を設定することができます。");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "受信者を保存しています...");
+define('VIEW_FORM_TABLES_HEADING', "フォームテーブルを表示する");
+define('VIEW_FORM_TABLES_BTN', "フォームテーブルを表示する");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "表示する表を選択する");
+define('VIEW_FORM_TABLES_FILTER_READ', "フィルタ読取りメッセージ");
 ?>
\ No newline at end of file
