@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "ಫಾರ್ಮ್ ಪುಟ");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "ನೀವು ಅಲ್ಪವಿರಾಮಗಳಿಂದ ಇಮೇಲ್ಗಳನ್ನು ಬೇರ್ಪಡಿಸುವ ಮೂಲಕ ಒಂದಕ್ಕಿಂತ ಹೆಚ್ಚು ಸ್ವೀಕರಿಸುವವರ ಹೊಂದಿಸಬಹುದು.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "ಸ್ವೀಕರಿಸುವವರ ಉಳಿಸಲಾಗುತ್ತಿದೆ ...");
+define('VIEW_FORM_TABLES_HEADING', "ಫಾರ್ಮ್ ಟೇಬಲ್ಸ್ ವೀಕ್ಷಿಸಿ");
+define('VIEW_FORM_TABLES_BTN', "ಫಾರ್ಮ್ ಟೇಬಲ್ಸ್ ವೀಕ್ಷಿಸಿ");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "ವೀಕ್ಷಿಸಲು ಒಂದು ಕೋಷ್ಟಕಗಳನ್ನು ಆಯ್ಕೆಮಾಡಿ");
+define('VIEW_FORM_TABLES_FILTER_READ', "ಫಿಲ್ಟರ್ ಓದಿ ಸಂದೇಶಗಳು");
 ?>
\ No newline at end of file
