@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "양식 페이지");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "쉼표로 이메일을 분리하여 하나 이상의 수신자를 설정할 수 있습니다.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "받는 사람 저장 중 ...");
+define('VIEW_FORM_TABLES_HEADING', "양식 표보기");
+define('VIEW_FORM_TABLES_BTN', "양식 표보기");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "볼 테이블 선택");
+define('VIEW_FORM_TABLES_FILTER_READ', "메일 읽기 필터링");
 ?>
\ No newline at end of file
