@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "forma Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Securus licet plures fuere separando per commata recipientis.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvis recipientis ...");
+define('VIEW_FORM_TABLES_HEADING', "View formandae sunt tabulae");
+define('VIEW_FORM_TABLES_BTN', "View formandae sunt tabulae");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "View Select a Traba");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
 ?>
\ No newline at end of file
