@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "forma tinklalapis");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Galite nustatyti daugiau nei vieną gavėją atskiriant laiškus su kableliais.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Taupymo gavėją ...");
+define('VIEW_FORM_TABLES_HEADING', "Peržiūrėti formos lenteles");
+define('VIEW_FORM_TABLES_BTN', "Peržiūrėti formos lenteles");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Pasirinkite tabulas, kad pamatytumėte");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtras skaityti pranešimus");
 ?>
\ No newline at end of file
