@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Page forma");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Jūs varat iestatīt vairākus adresātus, atdalot e-pastus ar komatu.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Saglabāšana adresātu ...");
+define('VIEW_FORM_TABLES_HEADING', "Skatīt veidlapu tabulas");
+define('VIEW_FORM_TABLES_BTN', "Skatīt veidlapu tabulas");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Atlasiet tabulas, lai skatītu");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrs izlasīt ziņojumus");
 ?>
\ No newline at end of file
