@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "страница форма");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Може да поставите повеќе од еден примател со одвојување на пораките со запирки.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Заштеда на примачот ...");
+define('VIEW_FORM_TABLES_HEADING', "Прикажи ги табелите за формите");
+define('VIEW_FORM_TABLES_BTN', "Прикажи ги табелите за формите");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Изберете табели за прегледување");
+define('VIEW_FORM_TABLES_FILTER_READ', "Филтрирај ги пораките за читање");
 ?>
\ No newline at end of file
