@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "borang Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Anda boleh menetapkan lebih daripada satu penerima dengan mengasingkan e-mel dengan koma.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Menyimpan penerima ...");
+define('VIEW_FORM_TABLES_HEADING', "Lihat Borang Jadual");
+define('VIEW_FORM_TABLES_BTN', "Lihat Borang Jadual");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Pilih jadual untuk Lihat");
+define('VIEW_FORM_TABLES_FILTER_READ', "Penapis Baca Mesej");
 ?>
\ No newline at end of file
