@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formola Paġna");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Inti tista &#39;tistabbilixxi aktar minn persuna waħda minn tissepara l-emails ma virgoli.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Iffrankar riċevitur ...");
+define('VIEW_FORM_TABLES_HEADING', "Ara Tabelli tal-Formola");
+define('VIEW_FORM_TABLES_BTN', "Ara Tabelli tal-Formola");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Agħżel Tabelli biex Jaraw");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtru Aqra Messaġġi");
 ?>
\ No newline at end of file
