@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "vorm Pagina");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "U kunt meer dan één ontvanger instellen door het scheiden van de e-mails met komma&#39;s.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "ontvanger opslaan ...");
+define('VIEW_FORM_TABLES_HEADING', "Formetabellen weergeven");
+define('VIEW_FORM_TABLES_BTN', "Formetabellen weergeven");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Selecteer een te bekijken tabellen");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter lees berichten");
 ?>
\ No newline at end of file
