@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Side");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Du kan angi mer enn én mottaker ved å skille e-post med komma.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Lagrer mottaker ...");
+define('VIEW_FORM_TABLES_HEADING', "Se skjemaer");
+define('VIEW_FORM_TABLES_BTN', "Se skjemaer");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Velg et tabeller til visning");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filter Les meldinger");
 ?>
\ No newline at end of file
