@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formularz Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Możesz ustawić więcej niż jednego odbiorcy, oddzielając e-maile przecinkami.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Zapisywanie odbiorcy ...");
+define('VIEW_FORM_TABLES_HEADING', "Zobacz tabele formularzy");
+define('VIEW_FORM_TABLES_BTN', "Zobacz tabele formularzy");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Wybierz tabele do wyświetlenia");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtruj przeczytane wiadomości");
 ?>
\ No newline at end of file
