@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formulário de Página");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Você pode definir mais de um destinatário, separando os e-mails com vírgulas.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvando destinatário ...");
+define('VIEW_FORM_TABLES_HEADING', "Visualizar tabelas de formulário");
+define('VIEW_FORM_TABLES_BTN', "Visualizar tabelas de formulário");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Selecione uma tabela para visualizar");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrar mensagens de leitura");
 ?>
\ No newline at end of file
