@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formularul Pagina");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "S-ar putea stabili mai mult de un destinatar prin separarea e-mailuri cu virgulă.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Se salvează ... destinatar");
+define('VIEW_FORM_TABLES_HEADING', "Vizualizați tabelele de formular");
+define('VIEW_FORM_TABLES_BTN', "Vizualizați tabelele de formular");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Selectați o tabelă pentru vizualizare");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrați citirea mesajelor");
 ?>
\ No newline at end of file
