@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Форма страницы");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Вы можете установить более одного получателя, разделяя письма с запятыми.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Сохранение получателя ...");
+define('VIEW_FORM_TABLES_HEADING', "Просмотр таблиц формы");
+define('VIEW_FORM_TABLES_BTN', "Просмотр таблиц формы");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Выберите таблицы для просмотра");
+define('VIEW_FORM_TABLES_FILTER_READ', "Фильтровать сообщения для чтения");
 ?>
\ No newline at end of file
