@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "formulár Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Môžete nastaviť viac ako jedného príjemcu oddelením e-maily s čiarkami.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ukladanie príjemcu ...");
+define('VIEW_FORM_TABLES_HEADING', "Zobraziť tabuľky formulárov");
+define('VIEW_FORM_TABLES_BTN', "Zobraziť tabuľky formulárov");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Vyberte tabuľky na zobrazenie");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrovať správy");
 ?>
\ No newline at end of file
