@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "obrazec Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "lahko nastavite več kot enega prejemnika z ločitvijo e-pošto z vejicami.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Shranjevanje prejemnika ...");
+define('VIEW_FORM_TABLES_HEADING', "Ogled tabele obrazcev");
+define('VIEW_FORM_TABLES_BTN', "Ogled tabele obrazcev");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Izberite tabele za ogled");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtriraj branje sporočil");
 ?>
\ No newline at end of file
