@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Forma Faqe");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Ju mund të caktojë më shumë se një marrës duke i ndarë email me presje.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ruajtja e marrësit ...");
+define('VIEW_FORM_TABLES_HEADING', "Shikoni tabelat e formularëve");
+define('VIEW_FORM_TABLES_BTN', "Shikoni tabelat e formularëve");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Zgjidh një tabelë për të parë");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtroni mesazhet e lexuara");
 ?>
\ No newline at end of file
