@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "obrazac Страница");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Можете подесити више од једног примаоца одвајањем е-поруке са зарезима.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Чување примаоца ...");
+define('VIEW_FORM_TABLES_HEADING', "Преглед табеле табеле");
+define('VIEW_FORM_TABLES_BTN', "Преглед табеле табеле");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Изаберите табеле за приказ");
+define('VIEW_FORM_TABLES_FILTER_READ', "Филтрирај читање порука");
 ?>
\ No newline at end of file
