@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Page");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Du kan ställa in mer än en mottagare genom att separera e-post med kommatecken.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Sparar mottagaren ...");
+define('VIEW_FORM_TABLES_HEADING', "Visa formulärtabeller");
+define('VIEW_FORM_TABLES_BTN', "Visa formulärtabeller");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Välj ett tabeller att visa");
+define('VIEW_FORM_TABLES_FILTER_READ', "Filtrera läsmeddelanden");
 ?>
\ No newline at end of file
