@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "fomu Kwanza");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Unaweza kuweka mpokeaji zaidi ya moja kwa kutenganisha barua pepe na koma.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Kuokoa mpokeaji ...");
+define('VIEW_FORM_TABLES_HEADING', "Tazama Fomu za Fomu");
+define('VIEW_FORM_TABLES_BTN', "Tazama Fomu za Fomu");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Chagua Majedwali ya Kuangalia");
+define('VIEW_FORM_TABLES_FILTER_READ', "Futa Soma Ujumbe");
 ?>
\ No newline at end of file
