@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "படிவம் பக்கம்");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "நீங்கள் அரைப்புள்ளியால் மின்னஞ்சல்கள் பிரிப்பதன் மூலம் ஒன்றுக்கு மேற்பட்ட பெறுநர் அமைக்கலாம்.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "பெறுநர் சேமிக்கிறது ...");
+define('VIEW_FORM_TABLES_HEADING', "படிவம் அட்டவணைகள் காண்க");
+define('VIEW_FORM_TABLES_BTN', "படிவம் அட்டவணைகள் காண்க");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "பார்க்க ஒரு அட்டவணையைத் தேர்ந்தெடுக்கவும்");
+define('VIEW_FORM_TABLES_FILTER_READ', "வடிகட்டி படிக்கவும் செய்திகள்");
 ?>
\ No newline at end of file
