@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "ఫారం పేజీ");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "మీరు కామాలు ఇమెయిల్ వేరు ఒకటి కన్నా ఎక్కువ గ్రహీత సెట్ చేయవచ్చు.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "గ్రహీత సేవ్ చేస్తోంది ...");
+define('VIEW_FORM_TABLES_HEADING', "ఫారమ్ పట్టికలు చూడండి");
+define('VIEW_FORM_TABLES_BTN', "ఫారమ్ పట్టికలు చూడండి");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "వీక్షించడానికి ఒక పట్టికలను ఎంచుకోండి");
+define('VIEW_FORM_TABLES_FILTER_READ', "ఫిల్డ్ రీడ్ సందేశాలు");
 ?>
\ No newline at end of file
