@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "หน้าแบบฟอร์ม");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "คุณอาจจะตั้งผู้รับมากกว่าหนึ่งโดยการแยกอีเมลด้วยเครื่องหมายจุลภาค");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "ออมทรัพย์ผู้รับ ...");
+define('VIEW_FORM_TABLES_HEADING', "ดูตารางแบบฟอร์ม");
+define('VIEW_FORM_TABLES_BTN', "ดูตารางแบบฟอร์ม");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "เลือกตารางเพื่อดู");
+define('VIEW_FORM_TABLES_FILTER_READ', "กรองข้อความอ่าน");
 ?>
\ No newline at end of file
