@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Form Sayfası");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Sen virgül ile e-postalar ayırarak birden fazla alıcı ayarlayabilirsiniz.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "alıcı kaydediliyor ...");
+define('VIEW_FORM_TABLES_HEADING', "Form Tablolarını Görüntüle");
+define('VIEW_FORM_TABLES_BTN', "Form Tablolarını Görüntüle");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Görüntülemek için bir Tablo seçin");
+define('VIEW_FORM_TABLES_FILTER_READ', "Okuma Mesajlarını Süz");
 ?>
\ No newline at end of file
