@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "форма сторінки");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Ви можете встановити більш одного одержувача, розділяючи листи з запитом.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Збереження одержувача ...");
+define('VIEW_FORM_TABLES_HEADING', "Переглянути таблиці форм");
+define('VIEW_FORM_TABLES_BTN', "Переглянути таблиці форм");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Виберіть таблиці для перегляду");
+define('VIEW_FORM_TABLES_FILTER_READ', "Фільтр прочитати повідомлення");
 ?>
\ No newline at end of file
