@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "فارم پیج");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "تم کوما سے ای میلز الگ کرکے ایک سے زائد وصول کنندہ مقرر کر سکتے ہیں.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "وصول کنندہ محفوظ کر رہا ہے ...");
+define('VIEW_FORM_TABLES_HEADING', "فارم میزیں دیکھیں");
+define('VIEW_FORM_TABLES_BTN', "فارم میزیں دیکھیں");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "ملاحظہ کرنے کیلئے میزیں منتخب کریں");
+define('VIEW_FORM_TABLES_FILTER_READ', "پیغامات پڑھیں فلٹر");
 ?>
\ No newline at end of file
