@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "Mẫu trang");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Bạn có thể cài đặt nhiều hơn một người nhận bằng cách tách các email bằng dấu phẩy.");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Tiết kiệm nhận ...");
+define('VIEW_FORM_TABLES_HEADING', "Xem bảng biểu mẫu");
+define('VIEW_FORM_TABLES_BTN', "Xem bảng biểu mẫu");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "Chọn một bảng để xem");
+define('VIEW_FORM_TABLES_FILTER_READ', "Lọc tin nhắn đã đọc");
 ?>
\ No newline at end of file
