@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "表单页面");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "您可以用逗号分隔的电子邮件设置多个收件人。");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "保存收件人...");
+define('VIEW_FORM_TABLES_HEADING', "查看表单表");
+define('VIEW_FORM_TABLES_BTN', "查看表单表");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "选择要查看的表");
+define('VIEW_FORM_TABLES_FILTER_READ', "过滤读取消息");
 ?>
\ No newline at end of file
