@@ -14,4 +14,8 @@ define('FORM_RECIPIENTS_FORM_PAGE', "表單頁面");
 define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "您可以用逗號分隔的電子郵件設置多個收件人。");
 // Popup Messages:
 define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "保存收件人...");
+define('VIEW_FORM_TABLES_HEADING', "查看表單表");
+define('VIEW_FORM_TABLES_BTN', "查看表單表");
+define('VIEW_FORM_TABLES_SELECT_TABLE', "選擇要查看的表");
+define('VIEW_FORM_TABLES_FILTER_READ', "過濾讀取消息");
 ?>
\ No newline at end of file
