@@ -102,6 +102,10 @@ textarea	{
 	width:220px;
 	height:20px;
 }
+
+.button_heading_sub_level_1	{
+	margin-left: 10%;
+}
 </style>
 
 <script src="../js/ajax.js"> </script>
@@ -149,9 +153,7 @@ textarea	{
 
 <body onLoad="GetGalleryImages();">
 
-<table width="80%" align="center" border="0"><tr><td>
 <div class="button_heading_sub_level_1" id="manage_gallery_params_heading"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_GALLERY_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
 
 <table align="center" class="dimensions_table">
 <tr><td><?php echo MANAGE_GALLERY_FULL_WIDTH; ?>:</td><td><input type="text" name="full_width" id="full_width" value="<?php echo $full_width; ?>" class="dim_input" /> px</td></tr>
@@ -191,7 +193,7 @@ textarea	{
 		echo "	popup_msg.top_offset = 0;\n";
 		echo "	popup_msg.left_offset = 300;\n";
 		echo "	popup_msg.popup_msg_type = 1;\n";
-		echo "	popup_msg.status_msg = '" . MANAGE_GALLERY_UPLOAD_SUCCESS_MSG . "';\n";
+		echo "	popup_msg.status_msg = \"" . MANAGE_GALLERY_UPLOAD_SUCCESS_MSG . "\";\n";
 		echo "	popup_msg.popup_timeout = 3000;\n";
 		echo "	popup_msg.ShowPopupMsg();\n";
 	}
@@ -201,11 +203,13 @@ textarea	{
 		echo "	popup_msg.left_offset = 300;\n";
 		echo "	popup_msg.popup_msg_type = 1;\n";
 		if ($_GET['result'] == -1)
-			echo "	popup_msg.status_msg = '" . MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR . "';\n";
+			echo "	popup_msg.status_msg = \"" . MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR . "\";\n";
 		elseif ($_GET['result'] == -2)
-			echo "	popup_msg.status_msg = '" . MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR . "';\n";
+			echo "	popup_msg.status_msg = \"" . MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR . "\";\n";
 		elseif ($_GET['result'] == -3)
-			echo "	popup_msg.status_msg = '" . MANAGE_GALLERY_UPLOAD_FAIL_ERR . "';\n";
+			echo "	popup_msg.status_msg = \"" . MANAGE_GALLERY_UPLOAD_FAIL_ERR . "\";\n";
+		elseif ($_GET['result'] == -4)
+			echo "	popup_msg.status_msg = \"" . MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR . "\";\n";
 		echo "	popup_msg.popup_timeout = 5000;\n";
 		echo "	popup_msg.ShowPopupMsg();\n";
 	}
