@@ -8,11 +8,12 @@
 include ("check_session.php");
 
 $images = $_REQUEST['images'];
+$titles = $_REQUEST['titles'];
 
 $used_sort = array();
 foreach ($images as $sort_order => $image)
 {
-	while (in_array($sort_order, $used_sort))	// Must prevent same sort order used for more that one image.
+	while (in_array($sort_order, $used_sort))	// Must prevent same sort order used for more than one image.
 	{
 		$sort_order = time();
 	}
@@ -22,8 +23,11 @@ foreach ($images as $sort_order => $image)
 	$result = $bwb_dbh->query($query);
 	if ($result->rowCount() > 0)
 		$query = "UPDATE `gallery_titles` SET `sort_order` = '" . $sort_order . "' WHERE `image` = '" . $image . "'";
-	else
-		$query = "INSERT INTO `gallery_titles` SET `image` = '" . $image . "', `sort_order` = '" . $sort_order . "'";
+	else	{
+		$titles[$sort_order] = str_replace("'", "&#39;", $titles[$sort_order]);
+		$titles[$sort_order] = str_replace('"', "&#34;", $titles[$sort_order]);
+		$query = "INSERT INTO `gallery_titles` SET `image` = '" . $image . "', `sort_order` = '" . $sort_order . "', `title`  = '" . $titles[$sort_order] . "'";
+	}
 	
 	$cnt = $bwb_dbh->exec($query);
 }
