@@ -15,7 +15,7 @@
 	$ext = strrev($ext);
 	
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
-	$website = "http://" . $_SERVER['SERVER_NAME'];
+	$website = $http . $_SERVER['SERVER_NAME'];
 	if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))	{
 		$path = $document_root;
 		$web_path = $website;
