@@ -10,6 +10,8 @@
 // Revised: 1/19/2016	ELL
 // Added preview of style sheets. (special = 3)
 // Added preview of menu styles. (special = 4)
+// Revised: 4/25/2019	ELL
+// Added device emulation.
 // 
 
 	include ("check_session.php");
@@ -19,6 +21,9 @@
 	$mode = $_REQUEST['mode'];
 	$blog_id = $_REQUEST['blog_id'];
 	$style_sheet = $_REQUEST['style_sheet'];
+	$device_emulation = $_SESSION['device_emulation'];
+	if (isset($_REQUEST['restore_id']))
+		$restore_id = $_REQUEST['restore_id'];
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_cache WHERE id = 1";
 	$result = $bwb_dbh->query($query);
@@ -93,6 +98,13 @@
 		top:1px;
 		cursor:pointer;
 	}
+	#preview_device_emulation	{
+		display:block;
+		position:absolute;
+		left:70%;
+		top:5px;
+		cursor:pointer;
+	}
 	#preview_close_button	{
 		display:block;
 		position:absolute;
@@ -134,17 +146,49 @@ window.addEventListener('resize', function(event) {
 
 function CallPreview()
 {
+<?php if ($mode != "restore")   {   ?>
 	document.getElementById("preview_refresh_img").src = "theme/<?php echo $theme; ?>/images/refresh.gif";
 	window.opener.Preview('<?php echo $page_name; ?>', 1);
+<?php }	else	{	?>
+	window.opener.DisplayArchivedContent(<?php echo $restore_id; ?>);
+<?php   }   ?>
+}
+
+function ChangeDeviceEmulation(device_emulation)
+{
+	$.post( "set_device_emulation.php", { device_emulation: device_emulation  } ).done(function( data ) { CompleteChangeDeviceEmulation(data); } ) ;
+}
+function CompleteChangeDeviceEmulation(data)
+{
+	CallPreview();
+}
+
+function ClosePreview()
+{
+	$.post( "set_device_emulation.php", { device_emulation: "unset_device_emulation" } ).done(function( data ) { CompleteClosePreview(data); } ) ;
+}
+function CompleteClosePreview(data)
+{
+	window.close();
 }
 </script>
+<script src="js/jquery.min.js"> </script>
 </head>
 
 <body onLoad="ResizeWorkspace();">
 	<div id="preview_toolbar">
 	<div id="preview_title"><?php	echo EDITOR_PAGE_NAME . ": $page_name";	?></div>
+<?php if ($mode != "restore")   {   ?>
 	<div id="preview_refresh_button"><img src="theme/<?php echo $theme; ?>/images/icon_Reset.png" alt="<?php echo REFRESH_WORD;  ?>" id="preview_refresh_img" onClick="CallPreview();" /></div>
-    <div id="preview_close_button"><img src="theme/<?php echo $theme; ?>/images/close-button.png" alt="<?php echo CLOSE_WORD; ?>" onClick="window.close();" /></div>
+<?php   }   ?>
+    <div id="preview_device_emulation">
+    	<select name="device_emulation" id="device_emulation" onChange="ChangeDeviceEmulation(this.value);">
+        	<option value="desktop"<?php if ($device_emulation == "desktop") echo "selected='selected'"; ?>)><?php echo DESKTOP_WORD;  ?></option>
+            <option value="mobile"<?php if ($device_emulation == "mobile") echo "selected='selected'"; ?>><?php echo MOBILE_WORD;  ?></option>
+            <option value="touchscreen"<?php if ($device_emulation == "touchscreen") echo "selected='selected'"; ?>><?php echo TOUCHSCREEN_WORD;  ?></option>
+        </select>
+    </div>
+    <div id="preview_close_button"><img src="theme/<?php echo $theme; ?>/images/close-button.png" alt="<?php echo CLOSE_WORD; ?>" onClick="ClosePreview();" /></div>
 </div>
 <?php
 	// If head content, then get index page.
@@ -272,6 +316,6 @@ function CallPreview()
 ?>
 
 	<iframe width="978" scrolling="auto" src="<?php echo $website_path . "/" . $preview_file; ?>" id="preview_frame" ></iframe>
-	
+
 </body>
 </html>
\ No newline at end of file
