@@ -13,29 +13,14 @@ $server_name = $_SERVER['SERVER_NAME'];
 $server_name_www = "www." . $server_name;
 $referers = array($server_name_www, $server_name);
 
-
 // Module for performaing actual email operation.
 include("mime_mail.inc");
 // DB connection for retrieving HTML message format for message back to inquirer, etc.
-$doc_root = $_SERVER['DOCUMENT_ROOT'];
-if (file_exists("../connect/config.php"))	// Default installation
-	$connect_path = "../connect/";
-elseif (file_exists($doc_root . "/connect/config.php"))	// Custom userfile folders
-	$connect_path = $doc_root . "/connect/";
-else	{	// Must be installeed in sub domain or sub folder with non-standard userfile folders.
-	$php_self = $_SERVER["PHP_SELF"];
-	$self_parts = explode('/', $php_self);
-	$this_script = $self_parts[count($self_parts) - 1];
-	$sub_dir = str_replace(array($doc_root, $this_script), "", $php_self);
-	$sub_dir_parts = explode('/', $sub_dir);
-	$connect_path = $doc_root . '/' . $sub_dir_parts[0] . "/connect/";
-}
-include($connect_path . "config.php");
-include($connect_path . "db_connect.php");
-include("generate_password.php");
-include($connect_path . "captchakeys.php");
-include("clean_var.php");
-include("ignore_fields.php");
+include_once("connect_finder.php");
+include ("generate_password.php");
+include ($connect_path . $connect_dir . "/captchakeys.php");
+include ("clean_var.php");
+include ("ignore_fields.php");
 
 // If alternate go back specified, then use that if any errors.  This is usefule if sending page session expires if back button is used.
 if ($_POST['alt_go_back'])
@@ -109,7 +94,7 @@ if ($_POST['use_captcha'])
 	elseif ($_POST['captcha_type'] == "mollom")	// Requires acquisition of public and private keys from http://mollom.com
 	{
 		require_once("mollom.php");
-		include($connect_path . "captchakeys.php");
+		include($connect_path . $connect_dir . "/captchakeys.php");
 		
 		$captcha_response_field = $_POST['captcha_response_field'];
 		$mollom_session = $_POST['mollom_session'];
@@ -308,7 +293,7 @@ function check_referer($referers)
 		if (getenv('HTTP_REFERER')) {
 			$temp = explode('/', getenv('HTTP_REFERER'));
 			$found = false;
-			while (list(,$stored_referer) = each($referers)) {
+			foreach ($referers as $stored_referer)	{
 				if (preg_match('/^' . $stored_referer . '$/i', $temp[2]))
 					$found = true;
 			}
@@ -337,6 +322,7 @@ function doEncrypt($Data, $Key)
 // k[] = key of truly random gibberish
 // e[] = encrypted data
 
+	$Key = strtolower($Key);
 	for( $i = 0; $i < strlen($Data); $i++)
 	{
 		$c = substr($Data, $i, 1);
