@@ -7,14 +7,14 @@
 	
 	include ("check_session.php");
 
-	$custom_site_css_table = $_POST['custom_site_css_table'];
+	$style_sheet = $_POST['style_sheet'];
 	
-	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$custom_site_css_table' AND `source`=3";
+	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$style_sheet' AND `source`=3";
 	$cnt = $bwb_dbh->exec($query);
 
 	if ($cnt > 0)
 	{
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $custom_site_css_table;
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "custom_site_css WHERE style_sheet ='" . $style_sheet . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$custom_css = $row["custom_css"];
