@@ -13,6 +13,7 @@
 		
 	$sql_string = $_POST['sql_string'];
 	
+	$_SESSION['update_breeze_mode'] = time() + 600;
 ?>
 <!DOCTYPE html>
 <html>
@@ -26,16 +27,16 @@
 </head>
 
 <body>
-<table align="center" width="80%">
- <tr>
- 	<td>
+
+<div style="text_align:center; width:80%; margin-left:auto; margin-right:auto;">
 <?php
 	include("lib/run_sql.php");
 	
-	$result = RunSQL($sql_string, $bwb_dbh, BWB_TABLE_PREFIX, false, true, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+	$result = RunSQL($sql_string, $bwb_dbh, BWB_TABLE_PREFIX, true, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 ?>	
-	</td>
-  </tr>
- </table>
+</div>
+
+<div class='button_console_go_back' style="width:220px; margin-left:auto; margin-right:auto;" onClick="window.location.href='input_sql.php'"><span class='button_console_text_w_icon'><?php echo RUN_SQL_BACK_TO_EDIT_CSS_SELECT; ?></span></div>
+
 </body>
 </html>
\ No newline at end of file
