@@ -392,23 +392,22 @@ if ($disable_site_styles != 1)
 	
 	$page_name = addslashes($page_name);
 	$sValue = addslashes($sValue);
-	$today = date("Y-m-d H:i:s");
 	
 	if ($mode == "blog")
 	{
 		$query = "SELECT blog_id FROM " . BWB_TABLE_PREFIX . "blogs_draft WHERE blog_id='$blog_id'";
 		$result = $bwb_dbh->query($query);
 		if ($result->rowCount() > 0)	
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "blogs_draft SET post='$sValue', revised='$today' WHERE blog_id='$blog_id'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "blogs_draft SET post='$sValue' WHERE blog_id='$blog_id'";
 		else
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs_draft SET blog_id='$blog_id', post='$sValue', revised='$today'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs_draft SET blog_id='$blog_id', post='$sValue'";
 
 		$cnt = $bwb_dbh->exec($query);
 		
 		$query = "TRUNCATE " . BWB_TABLE_PREFIX . "page_data_draft";
 		$count = $bwb_dbh->exec($query);
 		
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs_bkup SET blog_id='$blog_id', page_name='$page_name', post='$sValue', `owner`='$userid', revised='$today'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs_bkup SET blog_id='$blog_id', page_name='$page_name', post='$sValue', `owner`='$userid'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	else
@@ -416,12 +415,12 @@ if ($disable_site_styles != 1)
 		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$page_name'";
 		$result = $bwb_dbh->query($query);
 		if ($result->rowCount() > 0)	
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$sValue', revised='$today', `source`=$special WHERE page_name='$page_name'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$sValue', `source`=$special WHERE page_name='$page_name'";
 		else
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$sValue', revised='$today', `source`=$special";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$page_name', page_content='$sValue', `source`=$special";
 		$cnt = $bwb_dbh->exec($query);
 		
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$page_name', page_content='$sValue', revised='$today', `source`=$special";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$page_name', page_content='$sValue', `source`=$special";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -430,16 +429,15 @@ if ($disable_site_styles != 1)
 	{
 		$page_name = addslashes($page_name);
 		$sValue = addslashes($sValue);
-		$today = date("Y-m-d H:i:s");
 		
 		if ($special == 1)
 		{
 			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name='$page_name'";
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() > 0)
-				$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content='$sValue', revised='$today' WHERE page_name='$page_name'";
+				$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content='$sValue' WHERE page_name='$page_name'";
 			else
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='$page_name', page_content='$sValue', revised='$today'";
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='$page_name', page_content='$sValue'";
 		}
 		elseif ($mode == "blog")
 		{
@@ -449,13 +447,13 @@ if ($disable_site_styles != 1)
 			
 			if ($row_cnt > 0)
 			{
-				$query = "UPDATE " . BWB_TABLE_PREFIX . "blogs SET post='$sValue', revised='$today' WHERE id='$blog_id'";
+				$query = "UPDATE " . BWB_TABLE_PREFIX . "blogs SET post='$sValue' WHERE id='$blog_id'";
 				$cnt = $bwb_dbh->exec($query);
 			}
 			else
 			{
 				echo "ERROR: Did not find existing blog with ID $blog_id.  Inserting new blog.<br>";
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs SET post='$sValue', page_name='$page_name', owner='$userid', revised='$today'";
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "blogs SET post='$sValue', page_name='$page_name', owner='$userid'";
 				$cnt = $bwb_dbh->exec($query);
 			}
 			$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='" . $page_name . "'";
@@ -491,16 +489,16 @@ if ($disable_site_styles != 1)
 			}
 			else
 				$page_content_w_blog = $page_content_prepend . $blog_encap_delim . $sValue . $page_content_append;	// Prepend page with new post and publish.
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content_w_blog', revised='$today' WHERE page_name='$page_name'";	
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content_w_blog' WHERE page_name='$page_name'";	
 		}
 		else
 		{
 			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() > 0)
-				$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$sValue', revised='$today' WHERE page_name='$page_name'";
+				$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$sValue' WHERE page_name='$page_name'";
 			else
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$sValue', revised='$today'";
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$sValue'";
 		}
 			
 		$cnt = $bwb_dbh->exec($query);
@@ -508,8 +506,10 @@ if ($disable_site_styles != 1)
 	
 	
 	if ($cnt > 0)
-		echo "Update complete";
+		echo EDIT_CSS_UPDATE_COMPLETE_MSG;
+	elseif ($cnt == 0)
+		echo EDIT_PAGE_NO_CHANGE;
 	else
-		echo "Update failed";
+		echo EDIT_PAGE_UPDATE_FAILED;
 	
 ?>
