@@ -25,12 +25,20 @@
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$version = $row['VERSION()'];
+	if (strpos($version, "MariaDB") !== false)	{
+		$logo = "MariaDB_Logo.png";
+		$db_type = "MariaDB";
+	}
+	else	{
+		$logo = "logo-mysql-110x57.png";
+		$db_type = "MySQL";
+	}
 ?>
 
 	<center>
-    <div style='width:600px; height:40px; background-color:#9999CC; padding-top:18px; border:thin black solid; font-size:20px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;'>MySQL Version:
+    <div style='width:600px; height:40px; background-color:#9999CC; padding-top:18px; border:thin black solid; font-size:20px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;'><?php echo $db_type; ?> Version:
     <?php echo $version; ?>
-    <img src="images/logo-mysql-110x57.png" style="margin-top:-18px;" alt="MySQL" />
+    <img src="images/<?php echo $logo; ?>" style="margin-top:-18px;" alt="MySQL" />
     </div>
     </center><br />
 
