@@ -12,8 +12,10 @@ include ("check_session.php");
 if (isset($_REQUEST['editor_mode']))
 	$_SESSION['editor_mode'] = $_REQUEST['editor_mode'];
 	
-if (isset($_REQUEST['style_mode']))
+if (isset($_REQUEST['style_mode']))	{
 	$_SESSION['style_mode'] = $_REQUEST['style_mode'];
+	$_SESSION['device_emulation'] = $_REQUEST['style_mode'];
+}
 	
 if (isset($_REQUEST['site_styles']) && ($_REQUEST['site_styles'] != -1))
 	$_SESSION['site_styles'] = $_REQUEST['site_styles'];
