@@ -46,6 +46,10 @@
 	width:100px;
 	position:inherit;
 }
+
+.button_heading_sub_level_1	{
+	margin-left: 10%;
+}
 </style>
 
 <script language="javascript" src="js/hash.js" type="text/javascript"> </script>
@@ -53,7 +57,7 @@
 <script language="javascript" type="text/javascript">
 function OpenHelpWindow()
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#install_plugin", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open("<?php echo $http; ?>breezewebsitebuilder.com/docs/cms/help.html#install_plugin", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 function SubmitLogin()
@@ -147,9 +151,7 @@ function checkForEnter(e) {
 		{
 ?>
 
-<table width="80%" align="center" border="0"><tr><td>
 <div class="button_heading_sub_level_1" id="install_plugin_heading"><div class="button_heading_text_sub_level_1"><?php echo INSTALL_PLUGIN_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
-</td></tr></table>
 
 <form name="frmUploadPlugin" id="frmUploadPlugin" action="install_plugin.php" method="post" enctype="multipart/form-data">
 <table width="80%" align="center">
